"""Wrapper for https://raw.githubusercontent.com/KhronosGroup/OpenGL-Registry/master/xml/gl.xml
Generated by tools/gengl.py.
Do not modify this file.
"""
from __future__ import annotations

from ctypes import (
    CFUNCTYPE, POINTER, Structure, c_byte, c_char, c_double, c_float,
    c_int, c_int64, c_short, c_ubyte, c_uint, c_uint64, c_ushort
)
from _ctypes import _Pointer
from pyglet.gl.lib import c_ptrdiff_t
from typing import Any

class struct___GLsync(Structure): ...

# END OF gl_stub.template

# GL type definitions
GLenum = c_uint
GLboolean = c_ubyte
GLbitfield = c_uint
GLvoid = None
GLbyte = c_byte
GLubyte = c_ubyte
GLshort = c_short
GLushort = c_ushort
GLint = c_int
GLuint = c_uint
GLclampx = c_uint
GLsizei = c_int
GLfloat = c_float
GLclampf = c_float
GLdouble = c_double
GLclampd = c_double
GLchar = c_char
GLintptr = c_ptrdiff_t
GLsizeiptr = c_ptrdiff_t
GLint64 = c_int64
GLuint64 = c_uint64
GLuint64EXT = c_uint64
GLsync = POINTER(struct___GLsync)
GLDEBUGPROC = CFUNCTYPE(None, GLenum, GLenum, GLuint, GLenum, GLsizei, POINTER(GLchar), POINTER(GLvoid))

# GL enumerant (token) definitions
GL_FALSE: int
GL_POINTS: int
GL_ZERO: int
GL_NONE: int
GL_NO_ERROR: int
GL_TRUE: int
GL_LINES: int
GL_ONE: int
GL_CURRENT_BIT: int
GL_CLIENT_PIXEL_STORE_BIT: int
GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT: int
GL_MAP_READ_BIT: int
GL_CONTEXT_CORE_PROFILE_BIT: int
GL_SYNC_FLUSH_COMMANDS_BIT: int
GL_VERTEX_SHADER_BIT: int
GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT: int
GL_LINE_LOOP: int
GL_POINT_BIT: int
GL_CLIENT_VERTEX_ARRAY_BIT: int
GL_MAP_WRITE_BIT: int
GL_CONTEXT_COMPATIBILITY_PROFILE_BIT: int
GL_FRAGMENT_SHADER_BIT: int
GL_ELEMENT_ARRAY_BARRIER_BIT: int
GL_CONTEXT_FLAG_DEBUG_BIT: int
GL_LINE_STRIP: int
GL_TRIANGLES: int
GL_LINE_BIT: int
GL_MAP_INVALIDATE_RANGE_BIT: int
GL_GEOMETRY_SHADER_BIT: int
GL_UNIFORM_BARRIER_BIT: int
GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT: int
GL_TRIANGLE_STRIP: int
GL_TRIANGLE_FAN: int
GL_QUADS: int
GL_POLYGON_BIT: int
GL_QUAD_STRIP: int
GL_MAP_INVALIDATE_BUFFER_BIT: int
GL_TESS_CONTROL_SHADER_BIT: int
GL_TEXTURE_FETCH_BARRIER_BIT: int
GL_CONTEXT_FLAG_NO_ERROR_BIT: int
GL_POLYGON: int
GL_LINES_ADJACENCY: int
GL_LINE_STRIP_ADJACENCY: int
GL_TRIANGLES_ADJACENCY: int
GL_TRIANGLE_STRIP_ADJACENCY: int
GL_PATCHES: int
GL_POLYGON_STIPPLE_BIT: int
GL_MAP_FLUSH_EXPLICIT_BIT: int
GL_TESS_EVALUATION_SHADER_BIT: int
GL_PIXEL_MODE_BIT: int
GL_MAP_UNSYNCHRONIZED_BIT: int
GL_SHADER_IMAGE_ACCESS_BARRIER_BIT: int
GL_COMPUTE_SHADER_BIT: int
GL_LIGHTING_BIT: int
GL_COMMAND_BARRIER_BIT: int
GL_MAP_PERSISTENT_BIT: int
GL_MESH_SHADER_BIT_NV: int
GL_FOG_BIT: int
GL_PIXEL_BUFFER_BARRIER_BIT: int
GL_MAP_COHERENT_BIT: int
GL_TASK_SHADER_BIT_NV: int
GL_DEPTH_BUFFER_BIT: int
GL_ACCUM: int
GL_TEXTURE_UPDATE_BARRIER_BIT: int
GL_DYNAMIC_STORAGE_BIT: int
GL_LOAD: int
GL_RETURN: int
GL_MULT: int
GL_ADD: int
GL_NEVER: int
GL_ACCUM_BUFFER_BIT: int
GL_BUFFER_UPDATE_BARRIER_BIT: int
GL_CLIENT_STORAGE_BIT: int
GL_LESS: int
GL_EQUAL: int
GL_LEQUAL: int
GL_GREATER: int
GL_NOTEQUAL: int
GL_GEQUAL: int
GL_ALWAYS: int
GL_SRC_COLOR: int
GL_ONE_MINUS_SRC_COLOR: int
GL_SRC_ALPHA: int
GL_ONE_MINUS_SRC_ALPHA: int
GL_DST_ALPHA: int
GL_ONE_MINUS_DST_ALPHA: int
GL_DST_COLOR: int
GL_ONE_MINUS_DST_COLOR: int
GL_SRC_ALPHA_SATURATE: int
GL_STENCIL_BUFFER_BIT: int
GL_FRONT_LEFT: int
GL_FRAMEBUFFER_BARRIER_BIT: int
GL_FRONT_RIGHT: int
GL_BACK_LEFT: int
GL_BACK_RIGHT: int
GL_FRONT: int
GL_BACK: int
GL_LEFT: int
GL_RIGHT: int
GL_FRONT_AND_BACK: int
GL_AUX0: int
GL_AUX1: int
GL_AUX2: int
GL_AUX3: int
GL_INVALID_ENUM: int
GL_INVALID_VALUE: int
GL_INVALID_OPERATION: int
GL_STACK_OVERFLOW: int
GL_STACK_UNDERFLOW: int
GL_OUT_OF_MEMORY: int
GL_INVALID_FRAMEBUFFER_OPERATION: int
GL_INVALID_FRAMEBUFFER_OPERATION_EXT: int
GL_CONTEXT_LOST: int
GL_2D: int
GL_3D: int
GL_3D_COLOR: int
GL_3D_COLOR_TEXTURE: int
GL_4D_COLOR_TEXTURE: int
GL_PASS_THROUGH_TOKEN: int
GL_POINT_TOKEN: int
GL_LINE_TOKEN: int
GL_POLYGON_TOKEN: int
GL_BITMAP_TOKEN: int
GL_DRAW_PIXEL_TOKEN: int
GL_COPY_PIXEL_TOKEN: int
GL_LINE_RESET_TOKEN: int
GL_VIEWPORT_BIT: int
GL_EXP: int
GL_TRANSFORM_FEEDBACK_BARRIER_BIT: int
GL_EXP2: int
GL_CW: int
GL_CCW: int
GL_COEFF: int
GL_ORDER: int
GL_DOMAIN: int
GL_CURRENT_COLOR: int
GL_CURRENT_INDEX: int
GL_CURRENT_NORMAL: int
GL_CURRENT_TEXTURE_COORDS: int
GL_CURRENT_RASTER_COLOR: int
GL_CURRENT_RASTER_INDEX: int
GL_CURRENT_RASTER_TEXTURE_COORDS: int
GL_CURRENT_RASTER_POSITION: int
GL_CURRENT_RASTER_POSITION_VALID: int
GL_CURRENT_RASTER_DISTANCE: int
GL_POINT_SMOOTH: int
GL_POINT_SIZE: int
GL_POINT_SIZE_RANGE: int
GL_SMOOTH_POINT_SIZE_RANGE: int
GL_POINT_SIZE_GRANULARITY: int
GL_SMOOTH_POINT_SIZE_GRANULARITY: int
GL_LINE_SMOOTH: int
GL_LINE_WIDTH: int
GL_LINE_WIDTH_RANGE: int
GL_SMOOTH_LINE_WIDTH_RANGE: int
GL_LINE_WIDTH_GRANULARITY: int
GL_SMOOTH_LINE_WIDTH_GRANULARITY: int
GL_LINE_STIPPLE: int
GL_LINE_STIPPLE_PATTERN: int
GL_LINE_STIPPLE_REPEAT: int
GL_LIST_MODE: int
GL_MAX_LIST_NESTING: int
GL_LIST_BASE: int
GL_LIST_INDEX: int
GL_POLYGON_MODE: int
GL_POLYGON_SMOOTH: int
GL_POLYGON_STIPPLE: int
GL_EDGE_FLAG: int
GL_CULL_FACE: int
GL_CULL_FACE_MODE: int
GL_FRONT_FACE: int
GL_LIGHTING: int
GL_LIGHT_MODEL_LOCAL_VIEWER: int
GL_LIGHT_MODEL_TWO_SIDE: int
GL_LIGHT_MODEL_AMBIENT: int
GL_SHADE_MODEL: int
GL_COLOR_MATERIAL_FACE: int
GL_COLOR_MATERIAL_PARAMETER: int
GL_COLOR_MATERIAL: int
GL_FOG: int
GL_FOG_INDEX: int
GL_FOG_DENSITY: int
GL_FOG_START: int
GL_FOG_END: int
GL_FOG_MODE: int
GL_FOG_COLOR: int
GL_DEPTH_RANGE: int
GL_DEPTH_TEST: int
GL_DEPTH_WRITEMASK: int
GL_DEPTH_CLEAR_VALUE: int
GL_DEPTH_FUNC: int
GL_ACCUM_CLEAR_VALUE: int
GL_STENCIL_TEST: int
GL_STENCIL_CLEAR_VALUE: int
GL_STENCIL_FUNC: int
GL_STENCIL_VALUE_MASK: int
GL_STENCIL_FAIL: int
GL_STENCIL_PASS_DEPTH_FAIL: int
GL_STENCIL_PASS_DEPTH_PASS: int
GL_STENCIL_REF: int
GL_STENCIL_WRITEMASK: int
GL_MATRIX_MODE: int
GL_NORMALIZE: int
GL_VIEWPORT: int
GL_MODELVIEW_STACK_DEPTH: int
GL_PROJECTION_STACK_DEPTH: int
GL_TEXTURE_STACK_DEPTH: int
GL_MODELVIEW_MATRIX: int
GL_PROJECTION_MATRIX: int
GL_TEXTURE_MATRIX: int
GL_ATTRIB_STACK_DEPTH: int
GL_CLIENT_ATTRIB_STACK_DEPTH: int
GL_ALPHA_TEST: int
GL_ALPHA_TEST_FUNC: int
GL_ALPHA_TEST_REF: int
GL_DITHER: int
GL_BLEND_DST: int
GL_BLEND_SRC: int
GL_BLEND: int
GL_LOGIC_OP_MODE: int
GL_LOGIC_OP: int
GL_INDEX_LOGIC_OP: int
GL_COLOR_LOGIC_OP: int
GL_AUX_BUFFERS: int
GL_DRAW_BUFFER: int
GL_READ_BUFFER: int
GL_SCISSOR_BOX: int
GL_SCISSOR_TEST: int
GL_INDEX_CLEAR_VALUE: int
GL_INDEX_WRITEMASK: int
GL_COLOR_CLEAR_VALUE: int
GL_COLOR_WRITEMASK: int
GL_INDEX_MODE: int
GL_RGBA_MODE: int
GL_DOUBLEBUFFER: int
GL_STEREO: int
GL_RENDER_MODE: int
GL_PERSPECTIVE_CORRECTION_HINT: int
GL_POINT_SMOOTH_HINT: int
GL_LINE_SMOOTH_HINT: int
GL_POLYGON_SMOOTH_HINT: int
GL_FOG_HINT: int
GL_TEXTURE_GEN_S: int
GL_TEXTURE_GEN_T: int
GL_TEXTURE_GEN_R: int
GL_TEXTURE_GEN_Q: int
GL_PIXEL_MAP_I_TO_I: int
GL_PIXEL_MAP_S_TO_S: int
GL_PIXEL_MAP_I_TO_R: int
GL_PIXEL_MAP_I_TO_G: int
GL_PIXEL_MAP_I_TO_B: int
GL_PIXEL_MAP_I_TO_A: int
GL_PIXEL_MAP_R_TO_R: int
GL_PIXEL_MAP_G_TO_G: int
GL_PIXEL_MAP_B_TO_B: int
GL_PIXEL_MAP_A_TO_A: int
GL_PIXEL_MAP_I_TO_I_SIZE: int
GL_PIXEL_MAP_S_TO_S_SIZE: int
GL_PIXEL_MAP_I_TO_R_SIZE: int
GL_PIXEL_MAP_I_TO_G_SIZE: int
GL_PIXEL_MAP_I_TO_B_SIZE: int
GL_PIXEL_MAP_I_TO_A_SIZE: int
GL_PIXEL_MAP_R_TO_R_SIZE: int
GL_PIXEL_MAP_G_TO_G_SIZE: int
GL_PIXEL_MAP_B_TO_B_SIZE: int
GL_PIXEL_MAP_A_TO_A_SIZE: int
GL_UNPACK_SWAP_BYTES: int
GL_UNPACK_LSB_FIRST: int
GL_UNPACK_ROW_LENGTH: int
GL_UNPACK_SKIP_ROWS: int
GL_UNPACK_SKIP_PIXELS: int
GL_UNPACK_ALIGNMENT: int
GL_PACK_SWAP_BYTES: int
GL_PACK_LSB_FIRST: int
GL_PACK_ROW_LENGTH: int
GL_PACK_SKIP_ROWS: int
GL_PACK_SKIP_PIXELS: int
GL_PACK_ALIGNMENT: int
GL_MAP_COLOR: int
GL_MAP_STENCIL: int
GL_INDEX_SHIFT: int
GL_INDEX_OFFSET: int
GL_RED_SCALE: int
GL_RED_BIAS: int
GL_ZOOM_X: int
GL_ZOOM_Y: int
GL_GREEN_SCALE: int
GL_GREEN_BIAS: int
GL_BLUE_SCALE: int
GL_BLUE_BIAS: int
GL_ALPHA_SCALE: int
GL_ALPHA_BIAS: int
GL_DEPTH_SCALE: int
GL_DEPTH_BIAS: int
GL_MAX_EVAL_ORDER: int
GL_MAX_LIGHTS: int
GL_MAX_CLIP_PLANES: int
GL_MAX_CLIP_DISTANCES: int
GL_MAX_TEXTURE_SIZE: int
GL_MAX_PIXEL_MAP_TABLE: int
GL_MAX_ATTRIB_STACK_DEPTH: int
GL_MAX_MODELVIEW_STACK_DEPTH: int
GL_MAX_NAME_STACK_DEPTH: int
GL_MAX_PROJECTION_STACK_DEPTH: int
GL_MAX_TEXTURE_STACK_DEPTH: int
GL_MAX_VIEWPORT_DIMS: int
GL_MAX_CLIENT_ATTRIB_STACK_DEPTH: int
GL_SUBPIXEL_BITS: int
GL_INDEX_BITS: int
GL_RED_BITS: int
GL_GREEN_BITS: int
GL_BLUE_BITS: int
GL_ALPHA_BITS: int
GL_DEPTH_BITS: int
GL_STENCIL_BITS: int
GL_ACCUM_RED_BITS: int
GL_ACCUM_GREEN_BITS: int
GL_ACCUM_BLUE_BITS: int
GL_ACCUM_ALPHA_BITS: int
GL_NAME_STACK_DEPTH: int
GL_AUTO_NORMAL: int
GL_MAP1_COLOR_4: int
GL_MAP1_INDEX: int
GL_MAP1_NORMAL: int
GL_MAP1_TEXTURE_COORD_1: int
GL_MAP1_TEXTURE_COORD_2: int
GL_MAP1_TEXTURE_COORD_3: int
GL_MAP1_TEXTURE_COORD_4: int
GL_MAP1_VERTEX_3: int
GL_MAP1_VERTEX_4: int
GL_MAP2_COLOR_4: int
GL_MAP2_INDEX: int
GL_MAP2_NORMAL: int
GL_MAP2_TEXTURE_COORD_1: int
GL_MAP2_TEXTURE_COORD_2: int
GL_MAP2_TEXTURE_COORD_3: int
GL_MAP2_TEXTURE_COORD_4: int
GL_MAP2_VERTEX_3: int
GL_MAP2_VERTEX_4: int
GL_MAP1_GRID_DOMAIN: int
GL_MAP1_GRID_SEGMENTS: int
GL_MAP2_GRID_DOMAIN: int
GL_MAP2_GRID_SEGMENTS: int
GL_TEXTURE_1D: int
GL_TEXTURE_2D: int
GL_FEEDBACK_BUFFER_POINTER: int
GL_FEEDBACK_BUFFER_SIZE: int
GL_FEEDBACK_BUFFER_TYPE: int
GL_SELECTION_BUFFER_POINTER: int
GL_SELECTION_BUFFER_SIZE: int
GL_TEXTURE_WIDTH: int
GL_TRANSFORM_BIT: int
GL_ATOMIC_COUNTER_BARRIER_BIT: int
GL_TEXTURE_HEIGHT: int
GL_TEXTURE_COMPONENTS: int
GL_TEXTURE_INTERNAL_FORMAT: int
GL_TEXTURE_BORDER_COLOR: int
GL_TEXTURE_BORDER: int
GL_TEXTURE_TARGET: int
GL_DONT_CARE: int
GL_FASTEST: int
GL_NICEST: int
GL_AMBIENT: int
GL_DIFFUSE: int
GL_SPECULAR: int
GL_POSITION: int
GL_SPOT_DIRECTION: int
GL_SPOT_EXPONENT: int
GL_SPOT_CUTOFF: int
GL_CONSTANT_ATTENUATION: int
GL_LINEAR_ATTENUATION: int
GL_QUADRATIC_ATTENUATION: int
GL_COMPILE: int
GL_COMPILE_AND_EXECUTE: int
GL_BYTE: int
GL_UNSIGNED_BYTE: int
GL_SHORT: int
GL_UNSIGNED_SHORT: int
GL_INT: int
GL_UNSIGNED_INT: int
GL_FLOAT: int
GL_2_BYTES: int
GL_3_BYTES: int
GL_4_BYTES: int
GL_DOUBLE: int
GL_HALF_FLOAT: int
GL_FIXED: int
GL_INT64_ARB: int
GL_UNSIGNED_INT64_ARB: int
GL_CLEAR: int
GL_AND: int
GL_AND_REVERSE: int
GL_COPY: int
GL_AND_INVERTED: int
GL_NOOP: int
GL_XOR: int
GL_OR: int
GL_NOR: int
GL_EQUIV: int
GL_INVERT: int
GL_OR_REVERSE: int
GL_COPY_INVERTED: int
GL_OR_INVERTED: int
GL_NAND: int
GL_SET: int
GL_EMISSION: int
GL_SHININESS: int
GL_AMBIENT_AND_DIFFUSE: int
GL_COLOR_INDEXES: int
GL_MODELVIEW: int
GL_PROJECTION: int
GL_TEXTURE: int
GL_COLOR: int
GL_DEPTH: int
GL_STENCIL: int
GL_COLOR_INDEX: int
GL_STENCIL_INDEX: int
GL_DEPTH_COMPONENT: int
GL_RED: int
GL_GREEN: int
GL_BLUE: int
GL_ALPHA: int
GL_RGB: int
GL_RGBA: int
GL_LUMINANCE: int
GL_LUMINANCE_ALPHA: int
GL_BITMAP: int
GL_POINT: int
GL_LINE: int
GL_FILL: int
GL_RENDER: int
GL_FEEDBACK: int
GL_SELECT: int
GL_FLAT: int
GL_SMOOTH: int
GL_KEEP: int
GL_REPLACE: int
GL_INCR: int
GL_DECR: int
GL_VENDOR: int
GL_RENDERER: int
GL_VERSION: int
GL_EXTENSIONS: int
GL_ENABLE_BIT: int
GL_S: int
GL_SHADER_STORAGE_BARRIER_BIT: int
GL_T: int
GL_R: int
GL_Q: int
GL_MODULATE: int
GL_DECAL: int
GL_TEXTURE_ENV_MODE: int
GL_TEXTURE_ENV_COLOR: int
GL_TEXTURE_ENV: int
GL_EYE_LINEAR: int
GL_OBJECT_LINEAR: int
GL_SPHERE_MAP: int
GL_TEXTURE_GEN_MODE: int
GL_OBJECT_PLANE: int
GL_EYE_PLANE: int
GL_NEAREST: int
GL_LINEAR: int
GL_NEAREST_MIPMAP_NEAREST: int
GL_LINEAR_MIPMAP_NEAREST: int
GL_NEAREST_MIPMAP_LINEAR: int
GL_LINEAR_MIPMAP_LINEAR: int
GL_TEXTURE_MAG_FILTER: int
GL_TEXTURE_MIN_FILTER: int
GL_TEXTURE_WRAP_S: int
GL_TEXTURE_WRAP_T: int
GL_CLAMP: int
GL_REPEAT: int
GL_POLYGON_OFFSET_UNITS: int
GL_POLYGON_OFFSET_POINT: int
GL_POLYGON_OFFSET_LINE: int
GL_R3_G3_B2: int
GL_V2F: int
GL_V3F: int
GL_C4UB_V2F: int
GL_C4UB_V3F: int
GL_C3F_V3F: int
GL_N3F_V3F: int
GL_C4F_N3F_V3F: int
GL_T2F_V3F: int
GL_T4F_V4F: int
GL_T2F_C4UB_V3F: int
GL_T2F_C3F_V3F: int
GL_T2F_N3F_V3F: int
GL_T2F_C4F_N3F_V3F: int
GL_T4F_C4F_N3F_V4F: int
GL_CLIP_PLANE0: int
GL_CLIP_DISTANCE0: int
GL_CLIP_PLANE1: int
GL_CLIP_DISTANCE1: int
GL_CLIP_PLANE2: int
GL_CLIP_DISTANCE2: int
GL_CLIP_PLANE3: int
GL_CLIP_DISTANCE3: int
GL_CLIP_PLANE4: int
GL_CLIP_DISTANCE4: int
GL_CLIP_PLANE5: int
GL_CLIP_DISTANCE5: int
GL_CLIP_DISTANCE6: int
GL_CLIP_DISTANCE7: int
GL_COLOR_BUFFER_BIT: int
GL_LIGHT0: int
GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT: int
GL_LIGHT1: int
GL_LIGHT2: int
GL_LIGHT3: int
GL_LIGHT4: int
GL_LIGHT5: int
GL_LIGHT6: int
GL_LIGHT7: int
GL_HINT_BIT: int
GL_QUERY_BUFFER_BARRIER_BIT: int
GL_CONSTANT_COLOR: int
GL_ONE_MINUS_CONSTANT_COLOR: int
GL_CONSTANT_ALPHA: int
GL_ONE_MINUS_CONSTANT_ALPHA: int
GL_BLEND_COLOR: int
GL_FUNC_ADD: int
GL_MIN: int
GL_MAX: int
GL_BLEND_EQUATION: int
GL_BLEND_EQUATION_RGB: int
GL_FUNC_SUBTRACT: int
GL_FUNC_REVERSE_SUBTRACT: int
GL_CONVOLUTION_1D: int
GL_CONVOLUTION_2D: int
GL_SEPARABLE_2D: int
GL_HISTOGRAM: int
GL_PROXY_HISTOGRAM: int
GL_MINMAX: int
GL_UNSIGNED_BYTE_3_3_2: int
GL_UNSIGNED_SHORT_4_4_4_4: int
GL_UNSIGNED_SHORT_5_5_5_1: int
GL_UNSIGNED_INT_8_8_8_8: int
GL_UNSIGNED_INT_10_10_10_2: int
GL_POLYGON_OFFSET_FILL: int
GL_POLYGON_OFFSET_FACTOR: int
GL_RESCALE_NORMAL: int
GL_ALPHA4: int
GL_ALPHA8: int
GL_ALPHA12: int
GL_ALPHA16: int
GL_LUMINANCE4: int
GL_LUMINANCE8: int
GL_LUMINANCE12: int
GL_LUMINANCE16: int
GL_LUMINANCE4_ALPHA4: int
GL_LUMINANCE6_ALPHA2: int
GL_LUMINANCE8_ALPHA8: int
GL_LUMINANCE12_ALPHA4: int
GL_LUMINANCE12_ALPHA12: int
GL_LUMINANCE16_ALPHA16: int
GL_INTENSITY: int
GL_INTENSITY4: int
GL_INTENSITY8: int
GL_INTENSITY12: int
GL_INTENSITY16: int
GL_RGB4: int
GL_RGB5: int
GL_RGB8: int
GL_RGB10: int
GL_RGB12: int
GL_RGB16: int
GL_RGBA2: int
GL_RGBA4: int
GL_RGB5_A1: int
GL_RGBA8: int
GL_RGB10_A2: int
GL_RGBA12: int
GL_RGBA16: int
GL_TEXTURE_RED_SIZE: int
GL_TEXTURE_GREEN_SIZE: int
GL_TEXTURE_BLUE_SIZE: int
GL_TEXTURE_ALPHA_SIZE: int
GL_TEXTURE_LUMINANCE_SIZE: int
GL_TEXTURE_INTENSITY_SIZE: int
GL_PROXY_TEXTURE_1D: int
GL_PROXY_TEXTURE_2D: int
GL_TEXTURE_PRIORITY: int
GL_TEXTURE_RESIDENT: int
GL_TEXTURE_BINDING_1D: int
GL_TEXTURE_BINDING_2D: int
GL_TEXTURE_BINDING_3D: int
GL_PACK_SKIP_IMAGES: int
GL_PACK_IMAGE_HEIGHT: int
GL_UNPACK_SKIP_IMAGES: int
GL_UNPACK_IMAGE_HEIGHT: int
GL_TEXTURE_3D: int
GL_PROXY_TEXTURE_3D: int
GL_TEXTURE_DEPTH: int
GL_TEXTURE_WRAP_R: int
GL_MAX_3D_TEXTURE_SIZE: int
GL_VERTEX_ARRAY: int
GL_NORMAL_ARRAY: int
GL_COLOR_ARRAY: int
GL_INDEX_ARRAY: int
GL_TEXTURE_COORD_ARRAY: int
GL_EDGE_FLAG_ARRAY: int
GL_VERTEX_ARRAY_SIZE: int
GL_VERTEX_ARRAY_TYPE: int
GL_VERTEX_ARRAY_STRIDE: int
GL_NORMAL_ARRAY_TYPE: int
GL_NORMAL_ARRAY_STRIDE: int
GL_COLOR_ARRAY_SIZE: int
GL_COLOR_ARRAY_TYPE: int
GL_COLOR_ARRAY_STRIDE: int
GL_INDEX_ARRAY_TYPE: int
GL_INDEX_ARRAY_STRIDE: int
GL_TEXTURE_COORD_ARRAY_SIZE: int
GL_TEXTURE_COORD_ARRAY_TYPE: int
GL_TEXTURE_COORD_ARRAY_STRIDE: int
GL_EDGE_FLAG_ARRAY_STRIDE: int
GL_VERTEX_ARRAY_POINTER: int
GL_NORMAL_ARRAY_POINTER: int
GL_COLOR_ARRAY_POINTER: int
GL_INDEX_ARRAY_POINTER: int
GL_TEXTURE_COORD_ARRAY_POINTER: int
GL_EDGE_FLAG_ARRAY_POINTER: int
GL_MULTISAMPLE: int
GL_MULTISAMPLE_ARB: int
GL_SAMPLE_ALPHA_TO_COVERAGE: int
GL_SAMPLE_ALPHA_TO_COVERAGE_ARB: int
GL_SAMPLE_ALPHA_TO_ONE: int
GL_SAMPLE_ALPHA_TO_ONE_ARB: int
GL_SAMPLE_COVERAGE: int
GL_SAMPLE_COVERAGE_ARB: int
GL_SAMPLE_BUFFERS: int
GL_SAMPLE_BUFFERS_ARB: int
GL_SAMPLES: int
GL_SAMPLES_ARB: int
GL_SAMPLE_COVERAGE_VALUE: int
GL_SAMPLE_COVERAGE_VALUE_ARB: int
GL_SAMPLE_COVERAGE_INVERT: int
GL_SAMPLE_COVERAGE_INVERT_ARB: int
GL_BLEND_DST_RGB: int
GL_BLEND_SRC_RGB: int
GL_BLEND_DST_ALPHA: int
GL_BLEND_SRC_ALPHA: int
GL_COLOR_TABLE: int
GL_POST_CONVOLUTION_COLOR_TABLE: int
GL_POST_COLOR_MATRIX_COLOR_TABLE: int
GL_PROXY_COLOR_TABLE: int
GL_PROXY_POST_CONVOLUTION_COLOR_TABLE: int
GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE: int
GL_BGR: int
GL_BGRA: int
GL_MAX_ELEMENTS_VERTICES: int
GL_MAX_ELEMENTS_INDICES: int
GL_PARAMETER_BUFFER: int
GL_PARAMETER_BUFFER_BINDING: int
GL_POINT_SIZE_MIN: int
GL_POINT_SIZE_MAX: int
GL_POINT_FADE_THRESHOLD_SIZE: int
GL_POINT_DISTANCE_ATTENUATION: int
GL_CLAMP_TO_BORDER: int
GL_CLAMP_TO_EDGE: int
GL_TEXTURE_MIN_LOD: int
GL_TEXTURE_MAX_LOD: int
GL_TEXTURE_BASE_LEVEL: int
GL_TEXTURE_MAX_LEVEL: int
GL_GENERATE_MIPMAP: int
GL_GENERATE_MIPMAP_HINT: int
GL_DEPTH_COMPONENT16: int
GL_DEPTH_COMPONENT24: int
GL_DEPTH_COMPONENT32: int
GL_LIGHT_MODEL_COLOR_CONTROL: int
GL_SINGLE_COLOR: int
GL_SEPARATE_SPECULAR_COLOR: int
GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING: int
GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE: int
GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE: int
GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE: int
GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE: int
GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE: int
GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE: int
GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE: int
GL_FRAMEBUFFER_DEFAULT: int
GL_FRAMEBUFFER_UNDEFINED: int
GL_DEPTH_STENCIL_ATTACHMENT: int
GL_MAJOR_VERSION: int
GL_MINOR_VERSION: int
GL_NUM_EXTENSIONS: int
GL_CONTEXT_FLAGS: int
GL_BUFFER_IMMUTABLE_STORAGE: int
GL_BUFFER_STORAGE_FLAGS: int
GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED: int
GL_INDEX: int
GL_COMPRESSED_RED: int
GL_COMPRESSED_RG: int
GL_RG: int
GL_RG_INTEGER: int
GL_R8: int
GL_R16: int
GL_RG8: int
GL_RG16: int
GL_R16F: int
GL_R32F: int
GL_RG16F: int
GL_RG32F: int
GL_R8I: int
GL_R8UI: int
GL_R16I: int
GL_R16UI: int
GL_R32I: int
GL_R32UI: int
GL_RG8I: int
GL_RG8UI: int
GL_RG16I: int
GL_RG16UI: int
GL_RG32I: int
GL_RG32UI: int
GL_DEBUG_OUTPUT_SYNCHRONOUS: int
GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH: int
GL_DEBUG_CALLBACK_FUNCTION: int
GL_DEBUG_CALLBACK_USER_PARAM: int
GL_DEBUG_SOURCE_API: int
GL_DEBUG_SOURCE_WINDOW_SYSTEM: int
GL_DEBUG_SOURCE_SHADER_COMPILER: int
GL_DEBUG_SOURCE_THIRD_PARTY: int
GL_DEBUG_SOURCE_APPLICATION: int
GL_DEBUG_SOURCE_OTHER: int
GL_DEBUG_TYPE_ERROR: int
GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR: int
GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR: int
GL_DEBUG_TYPE_PORTABILITY: int
GL_DEBUG_TYPE_PERFORMANCE: int
GL_DEBUG_TYPE_OTHER: int
GL_LOSE_CONTEXT_ON_RESET: int
GL_GUILTY_CONTEXT_RESET: int
GL_INNOCENT_CONTEXT_RESET: int
GL_UNKNOWN_CONTEXT_RESET: int
GL_RESET_NOTIFICATION_STRATEGY: int
GL_PROGRAM_BINARY_RETRIEVABLE_HINT: int
GL_PROGRAM_SEPARABLE: int
GL_ACTIVE_PROGRAM: int
GL_PROGRAM_PIPELINE_BINDING: int
GL_MAX_VIEWPORTS: int
GL_VIEWPORT_SUBPIXEL_BITS: int
GL_VIEWPORT_BOUNDS_RANGE: int
GL_LAYER_PROVOKING_VERTEX: int
GL_VIEWPORT_INDEX_PROVOKING_VERTEX: int
GL_UNDEFINED_VERTEX: int
GL_NO_RESET_NOTIFICATION: int
GL_MAX_COMPUTE_SHARED_MEMORY_SIZE: int
GL_MAX_COMPUTE_UNIFORM_COMPONENTS: int
GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS: int
GL_MAX_COMPUTE_ATOMIC_COUNTERS: int
GL_MAX_COMBINED_COMPUTE_UNIFORM_COMPONENTS: int
GL_COMPUTE_WORK_GROUP_SIZE: int
GL_DEBUG_TYPE_MARKER: int
GL_DEBUG_TYPE_PUSH_GROUP: int
GL_DEBUG_TYPE_POP_GROUP: int
GL_DEBUG_SEVERITY_NOTIFICATION: int
GL_MAX_DEBUG_GROUP_STACK_DEPTH: int
GL_DEBUG_GROUP_STACK_DEPTH: int
GL_MAX_UNIFORM_LOCATIONS: int
GL_INTERNALFORMAT_SUPPORTED: int
GL_INTERNALFORMAT_PREFERRED: int
GL_INTERNALFORMAT_RED_SIZE: int
GL_INTERNALFORMAT_GREEN_SIZE: int
GL_INTERNALFORMAT_BLUE_SIZE: int
GL_INTERNALFORMAT_ALPHA_SIZE: int
GL_INTERNALFORMAT_DEPTH_SIZE: int
GL_INTERNALFORMAT_STENCIL_SIZE: int
GL_INTERNALFORMAT_SHARED_SIZE: int
GL_INTERNALFORMAT_RED_TYPE: int
GL_INTERNALFORMAT_GREEN_TYPE: int
GL_INTERNALFORMAT_BLUE_TYPE: int
GL_INTERNALFORMAT_ALPHA_TYPE: int
GL_INTERNALFORMAT_DEPTH_TYPE: int
GL_INTERNALFORMAT_STENCIL_TYPE: int
GL_MAX_WIDTH: int
GL_MAX_HEIGHT: int
GL_MAX_DEPTH: int
GL_MAX_LAYERS: int
GL_MAX_COMBINED_DIMENSIONS: int
GL_COLOR_COMPONENTS: int
GL_DEPTH_COMPONENTS: int
GL_STENCIL_COMPONENTS: int
GL_COLOR_RENDERABLE: int
GL_DEPTH_RENDERABLE: int
GL_STENCIL_RENDERABLE: int
GL_FRAMEBUFFER_RENDERABLE: int
GL_FRAMEBUFFER_RENDERABLE_LAYERED: int
GL_FRAMEBUFFER_BLEND: int
GL_READ_PIXELS: int
GL_READ_PIXELS_FORMAT: int
GL_READ_PIXELS_TYPE: int
GL_TEXTURE_IMAGE_FORMAT: int
GL_TEXTURE_IMAGE_TYPE: int
GL_GET_TEXTURE_IMAGE_FORMAT: int
GL_GET_TEXTURE_IMAGE_TYPE: int
GL_MIPMAP: int
GL_MANUAL_GENERATE_MIPMAP: int
GL_AUTO_GENERATE_MIPMAP: int
GL_COLOR_ENCODING: int
GL_SRGB_READ: int
GL_SRGB_WRITE: int
GL_FILTER: int
GL_VERTEX_TEXTURE: int
GL_TESS_CONTROL_TEXTURE: int
GL_TESS_EVALUATION_TEXTURE: int
GL_GEOMETRY_TEXTURE: int
GL_FRAGMENT_TEXTURE: int
GL_COMPUTE_TEXTURE: int
GL_TEXTURE_SHADOW: int
GL_TEXTURE_GATHER: int
GL_TEXTURE_GATHER_SHADOW: int
GL_SHADER_IMAGE_LOAD: int
GL_SHADER_IMAGE_STORE: int
GL_SHADER_IMAGE_ATOMIC: int
GL_IMAGE_TEXEL_SIZE: int
GL_IMAGE_COMPATIBILITY_CLASS: int
GL_IMAGE_PIXEL_FORMAT: int
GL_IMAGE_PIXEL_TYPE: int
GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_TEST: int
GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_TEST: int
GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_WRITE: int
GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_WRITE: int
GL_TEXTURE_COMPRESSED_BLOCK_WIDTH: int
GL_TEXTURE_COMPRESSED_BLOCK_HEIGHT: int
GL_TEXTURE_COMPRESSED_BLOCK_SIZE: int
GL_CLEAR_BUFFER: int
GL_TEXTURE_VIEW: int
GL_VIEW_COMPATIBILITY_CLASS: int
GL_FULL_SUPPORT: int
GL_CAVEAT_SUPPORT: int
GL_IMAGE_CLASS_4_X_32: int
GL_IMAGE_CLASS_2_X_32: int
GL_IMAGE_CLASS_1_X_32: int
GL_IMAGE_CLASS_4_X_16: int
GL_IMAGE_CLASS_2_X_16: int
GL_IMAGE_CLASS_1_X_16: int
GL_IMAGE_CLASS_4_X_8: int
GL_IMAGE_CLASS_2_X_8: int
GL_IMAGE_CLASS_1_X_8: int
GL_IMAGE_CLASS_11_11_10: int
GL_IMAGE_CLASS_10_10_10_2: int
GL_VIEW_CLASS_128_BITS: int
GL_VIEW_CLASS_96_BITS: int
GL_VIEW_CLASS_64_BITS: int
GL_VIEW_CLASS_48_BITS: int
GL_VIEW_CLASS_32_BITS: int
GL_VIEW_CLASS_24_BITS: int
GL_VIEW_CLASS_16_BITS: int
GL_VIEW_CLASS_8_BITS: int
GL_VIEW_CLASS_S3TC_DXT1_RGB: int
GL_VIEW_CLASS_S3TC_DXT1_RGBA: int
GL_VIEW_CLASS_S3TC_DXT3_RGBA: int
GL_VIEW_CLASS_S3TC_DXT5_RGBA: int
GL_VIEW_CLASS_RGTC1_RED: int
GL_VIEW_CLASS_RGTC2_RG: int
GL_VIEW_CLASS_BPTC_UNORM: int
GL_VIEW_CLASS_BPTC_FLOAT: int
GL_VERTEX_ATTRIB_BINDING: int
GL_VERTEX_ATTRIB_RELATIVE_OFFSET: int
GL_VERTEX_BINDING_DIVISOR: int
GL_VERTEX_BINDING_OFFSET: int
GL_VERTEX_BINDING_STRIDE: int
GL_MAX_VERTEX_ATTRIB_RELATIVE_OFFSET: int
GL_MAX_VERTEX_ATTRIB_BINDINGS: int
GL_TEXTURE_VIEW_MIN_LEVEL: int
GL_TEXTURE_VIEW_NUM_LEVELS: int
GL_TEXTURE_VIEW_MIN_LAYER: int
GL_TEXTURE_VIEW_NUM_LAYERS: int
GL_TEXTURE_IMMUTABLE_LEVELS: int
GL_BUFFER: int
GL_SHADER: int
GL_PROGRAM: int
GL_QUERY: int
GL_PROGRAM_PIPELINE: int
GL_MAX_VERTEX_ATTRIB_STRIDE: int
GL_SAMPLER: int
GL_DISPLAY_LIST: int
GL_MAX_LABEL_LENGTH: int
GL_NUM_SHADING_LANGUAGE_VERSIONS: int
GL_QUERY_TARGET: int
GL_TRANSFORM_FEEDBACK_OVERFLOW: int
GL_TRANSFORM_FEEDBACK_STREAM_OVERFLOW: int
GL_VERTICES_SUBMITTED: int
GL_PRIMITIVES_SUBMITTED: int
GL_VERTEX_SHADER_INVOCATIONS: int
GL_TESS_CONTROL_SHADER_PATCHES: int
GL_TESS_EVALUATION_SHADER_INVOCATIONS: int
GL_GEOMETRY_SHADER_PRIMITIVES_EMITTED: int
GL_FRAGMENT_SHADER_INVOCATIONS: int
GL_COMPUTE_SHADER_INVOCATIONS: int
GL_CLIPPING_INPUT_PRIMITIVES: int
GL_CLIPPING_OUTPUT_PRIMITIVES: int
GL_MAX_CULL_DISTANCES: int
GL_MAX_COMBINED_CLIP_AND_CULL_DISTANCES: int
GL_CONTEXT_RELEASE_BEHAVIOR: int
GL_CONTEXT_RELEASE_BEHAVIOR_FLUSH: int
GL_UNSIGNED_BYTE_2_3_3_REV: int
GL_UNSIGNED_SHORT_5_6_5: int
GL_UNSIGNED_SHORT_5_6_5_REV: int
GL_UNSIGNED_SHORT_4_4_4_4_REV: int
GL_UNSIGNED_SHORT_1_5_5_5_REV: int
GL_UNSIGNED_INT_8_8_8_8_REV: int
GL_UNSIGNED_INT_2_10_10_10_REV: int
GL_MIRRORED_REPEAT: int
GL_COMPRESSED_RGB_S3TC_DXT1_EXT: int
GL_COMPRESSED_RGBA_S3TC_DXT1_EXT: int
GL_COMPRESSED_RGBA_S3TC_DXT3_EXT: int
GL_COMPRESSED_RGBA_S3TC_DXT5_EXT: int
GL_FOG_COORDINATE_SOURCE: int
GL_FOG_COORD_SRC: int
GL_FOG_COORDINATE: int
GL_FOG_COORD: int
GL_FRAGMENT_DEPTH: int
GL_CURRENT_FOG_COORDINATE: int
GL_CURRENT_FOG_COORD: int
GL_FOG_COORDINATE_ARRAY_TYPE: int
GL_FOG_COORD_ARRAY_TYPE: int
GL_FOG_COORDINATE_ARRAY_STRIDE: int
GL_FOG_COORD_ARRAY_STRIDE: int
GL_FOG_COORDINATE_ARRAY_POINTER: int
GL_FOG_COORD_ARRAY_POINTER: int
GL_FOG_COORDINATE_ARRAY: int
GL_FOG_COORD_ARRAY: int
GL_COLOR_SUM: int
GL_CURRENT_SECONDARY_COLOR: int
GL_SECONDARY_COLOR_ARRAY_SIZE: int
GL_SECONDARY_COLOR_ARRAY_TYPE: int
GL_SECONDARY_COLOR_ARRAY_STRIDE: int
GL_SECONDARY_COLOR_ARRAY_POINTER: int
GL_SECONDARY_COLOR_ARRAY: int
GL_CURRENT_RASTER_SECONDARY_COLOR: int
GL_ALIASED_POINT_SIZE_RANGE: int
GL_ALIASED_LINE_WIDTH_RANGE: int
GL_TEXTURE0: int
GL_TEXTURE1: int
GL_TEXTURE2: int
GL_TEXTURE3: int
GL_TEXTURE4: int
GL_TEXTURE5: int
GL_TEXTURE6: int
GL_TEXTURE7: int
GL_TEXTURE8: int
GL_TEXTURE9: int
GL_TEXTURE10: int
GL_TEXTURE11: int
GL_TEXTURE12: int
GL_TEXTURE13: int
GL_TEXTURE14: int
GL_TEXTURE15: int
GL_TEXTURE16: int
GL_TEXTURE17: int
GL_TEXTURE18: int
GL_TEXTURE19: int
GL_TEXTURE20: int
GL_TEXTURE21: int
GL_TEXTURE22: int
GL_TEXTURE23: int
GL_TEXTURE24: int
GL_TEXTURE25: int
GL_TEXTURE26: int
GL_TEXTURE27: int
GL_TEXTURE28: int
GL_TEXTURE29: int
GL_TEXTURE30: int
GL_TEXTURE31: int
GL_ACTIVE_TEXTURE: int
GL_CLIENT_ACTIVE_TEXTURE: int
GL_MAX_TEXTURE_UNITS: int
GL_TRANSPOSE_MODELVIEW_MATRIX: int
GL_TRANSPOSE_PROJECTION_MATRIX: int
GL_TRANSPOSE_TEXTURE_MATRIX: int
GL_TRANSPOSE_COLOR_MATRIX: int
GL_SUBTRACT: int
GL_MAX_RENDERBUFFER_SIZE: int
GL_MAX_RENDERBUFFER_SIZE_EXT: int
GL_COMPRESSED_ALPHA: int
GL_COMPRESSED_LUMINANCE: int
GL_COMPRESSED_LUMINANCE_ALPHA: int
GL_COMPRESSED_INTENSITY: int
GL_COMPRESSED_RGB: int
GL_COMPRESSED_RGBA: int
GL_TEXTURE_COMPRESSION_HINT: int
GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_CONTROL_SHADER: int
GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_EVALUATION_SHADER: int
GL_TEXTURE_RECTANGLE: int
GL_TEXTURE_BINDING_RECTANGLE: int
GL_PROXY_TEXTURE_RECTANGLE: int
GL_MAX_RECTANGLE_TEXTURE_SIZE: int
GL_DEPTH_STENCIL: int
GL_UNSIGNED_INT_24_8: int
GL_MAX_TEXTURE_LOD_BIAS: int
GL_TEXTURE_MAX_ANISOTROPY: int
GL_MAX_TEXTURE_MAX_ANISOTROPY: int
GL_TEXTURE_FILTER_CONTROL: int
GL_TEXTURE_LOD_BIAS: int
GL_INCR_WRAP: int
GL_DECR_WRAP: int
GL_NORMAL_MAP: int
GL_REFLECTION_MAP: int
GL_TEXTURE_CUBE_MAP: int
GL_TEXTURE_BINDING_CUBE_MAP: int
GL_TEXTURE_CUBE_MAP_POSITIVE_X: int
GL_TEXTURE_CUBE_MAP_NEGATIVE_X: int
GL_TEXTURE_CUBE_MAP_POSITIVE_Y: int
GL_TEXTURE_CUBE_MAP_NEGATIVE_Y: int
GL_TEXTURE_CUBE_MAP_POSITIVE_Z: int
GL_TEXTURE_CUBE_MAP_NEGATIVE_Z: int
GL_PROXY_TEXTURE_CUBE_MAP: int
GL_MAX_CUBE_MAP_TEXTURE_SIZE: int
GL_COMBINE: int
GL_COMBINE_RGB: int
GL_COMBINE_ALPHA: int
GL_RGB_SCALE: int
GL_ADD_SIGNED: int
GL_INTERPOLATE: int
GL_CONSTANT: int
GL_PRIMARY_COLOR: int
GL_PREVIOUS: int
GL_SOURCE0_RGB: int
GL_SRC0_RGB: int
GL_SOURCE1_RGB: int
GL_SRC1_RGB: int
GL_SOURCE2_RGB: int
GL_SRC2_RGB: int
GL_SOURCE0_ALPHA: int
GL_SRC0_ALPHA: int
GL_SOURCE1_ALPHA: int
GL_SRC1_ALPHA: int
GL_SOURCE2_ALPHA: int
GL_SRC2_ALPHA: int
GL_OPERAND0_RGB: int
GL_OPERAND1_RGB: int
GL_OPERAND2_RGB: int
GL_OPERAND0_ALPHA: int
GL_OPERAND1_ALPHA: int
GL_OPERAND2_ALPHA: int
GL_VERTEX_ARRAY_BINDING: int
GL_VERTEX_ATTRIB_ARRAY_ENABLED: int
GL_VERTEX_ATTRIB_ARRAY_SIZE: int
GL_VERTEX_ATTRIB_ARRAY_STRIDE: int
GL_VERTEX_ATTRIB_ARRAY_TYPE: int
GL_CURRENT_VERTEX_ATTRIB: int
GL_VERTEX_PROGRAM_POINT_SIZE: int
GL_PROGRAM_POINT_SIZE: int
GL_VERTEX_PROGRAM_TWO_SIDE: int
GL_VERTEX_ATTRIB_ARRAY_POINTER: int
GL_DEPTH_CLAMP: int
GL_TEXTURE_COMPRESSED_IMAGE_SIZE: int
GL_TEXTURE_COMPRESSED: int
GL_NUM_COMPRESSED_TEXTURE_FORMATS: int
GL_COMPRESSED_TEXTURE_FORMATS: int
GL_DOT3_RGB: int
GL_DOT3_RGBA: int
GL_PROGRAM_BINARY_LENGTH: int
GL_MIRROR_CLAMP_TO_EDGE: int
GL_VERTEX_ATTRIB_ARRAY_LONG: int
GL_BUFFER_SIZE: int
GL_BUFFER_USAGE: int
GL_NUM_PROGRAM_BINARY_FORMATS: int
GL_PROGRAM_BINARY_FORMATS: int
GL_STENCIL_BACK_FUNC: int
GL_STENCIL_BACK_FAIL: int
GL_STENCIL_BACK_PASS_DEPTH_FAIL: int
GL_STENCIL_BACK_PASS_DEPTH_PASS: int
GL_RGBA32F: int
GL_RGB32F: int
GL_RGBA16F: int
GL_RGB16F: int
GL_MAX_DRAW_BUFFERS: int
GL_DRAW_BUFFER0: int
GL_DRAW_BUFFER1: int
GL_DRAW_BUFFER2: int
GL_DRAW_BUFFER3: int
GL_DRAW_BUFFER4: int
GL_DRAW_BUFFER5: int
GL_DRAW_BUFFER6: int
GL_DRAW_BUFFER7: int
GL_DRAW_BUFFER8: int
GL_DRAW_BUFFER9: int
GL_DRAW_BUFFER10: int
GL_DRAW_BUFFER11: int
GL_DRAW_BUFFER12: int
GL_DRAW_BUFFER13: int
GL_DRAW_BUFFER14: int
GL_DRAW_BUFFER15: int
GL_BLEND_EQUATION_ALPHA: int
GL_TEXTURE_DEPTH_SIZE: int
GL_DEPTH_TEXTURE_MODE: int
GL_TEXTURE_COMPARE_MODE: int
GL_TEXTURE_COMPARE_FUNC: int
GL_COMPARE_R_TO_TEXTURE: int
GL_COMPARE_REF_TO_TEXTURE: int
GL_TEXTURE_CUBE_MAP_SEAMLESS: int
GL_POINT_SPRITE: int
GL_COORD_REPLACE: int
GL_QUERY_COUNTER_BITS: int
GL_CURRENT_QUERY: int
GL_QUERY_RESULT: int
GL_QUERY_RESULT_AVAILABLE: int
GL_MAX_VERTEX_ATTRIBS: int
GL_VERTEX_ATTRIB_ARRAY_NORMALIZED: int
GL_MAX_TESS_CONTROL_INPUT_COMPONENTS: int
GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS: int
GL_MAX_TEXTURE_COORDS: int
GL_MAX_TEXTURE_IMAGE_UNITS: int
GL_GEOMETRY_SHADER_INVOCATIONS: int
GL_ARRAY_BUFFER: int
GL_ELEMENT_ARRAY_BUFFER: int
GL_ARRAY_BUFFER_BINDING: int
GL_ELEMENT_ARRAY_BUFFER_BINDING: int
GL_VERTEX_ARRAY_BUFFER_BINDING: int
GL_NORMAL_ARRAY_BUFFER_BINDING: int
GL_COLOR_ARRAY_BUFFER_BINDING: int
GL_INDEX_ARRAY_BUFFER_BINDING: int
GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING: int
GL_EDGE_FLAG_ARRAY_BUFFER_BINDING: int
GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING: int
GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING: int
GL_FOG_COORD_ARRAY_BUFFER_BINDING: int
GL_WEIGHT_ARRAY_BUFFER_BINDING: int
GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: int
GL_READ_ONLY: int
GL_WRITE_ONLY: int
GL_READ_WRITE: int
GL_BUFFER_ACCESS: int
GL_BUFFER_MAPPED: int
GL_BUFFER_MAP_POINTER: int
GL_TIME_ELAPSED: int
GL_STREAM_DRAW: int
GL_STREAM_READ: int
GL_STREAM_COPY: int
GL_STATIC_DRAW: int
GL_STATIC_READ: int
GL_STATIC_COPY: int
GL_DYNAMIC_DRAW: int
GL_DYNAMIC_READ: int
GL_DYNAMIC_COPY: int
GL_PIXEL_PACK_BUFFER: int
GL_PIXEL_UNPACK_BUFFER: int
GL_PIXEL_PACK_BUFFER_BINDING: int
GL_PIXEL_UNPACK_BUFFER_BINDING: int
GL_DEPTH24_STENCIL8: int
GL_TEXTURE_STENCIL_SIZE: int
GL_SRC1_COLOR: int
GL_ONE_MINUS_SRC1_COLOR: int
GL_ONE_MINUS_SRC1_ALPHA: int
GL_MAX_DUAL_SOURCE_DRAW_BUFFERS: int
GL_VERTEX_ATTRIB_ARRAY_INTEGER: int
GL_VERTEX_ATTRIB_ARRAY_DIVISOR: int
GL_MAX_ARRAY_TEXTURE_LAYERS: int
GL_MIN_PROGRAM_TEXEL_OFFSET: int
GL_MAX_PROGRAM_TEXEL_OFFSET: int
GL_SAMPLES_PASSED: int
GL_GEOMETRY_VERTICES_OUT: int
GL_GEOMETRY_INPUT_TYPE: int
GL_GEOMETRY_OUTPUT_TYPE: int
GL_SAMPLER_BINDING: int
GL_CLAMP_VERTEX_COLOR: int
GL_CLAMP_FRAGMENT_COLOR: int
GL_CLAMP_READ_COLOR: int
GL_FIXED_ONLY: int
GL_UNIFORM_BUFFER: int
GL_UNIFORM_BUFFER_BINDING: int
GL_UNIFORM_BUFFER_START: int
GL_UNIFORM_BUFFER_SIZE: int
GL_MAX_VERTEX_UNIFORM_BLOCKS: int
GL_MAX_GEOMETRY_UNIFORM_BLOCKS: int
GL_MAX_FRAGMENT_UNIFORM_BLOCKS: int
GL_MAX_COMBINED_UNIFORM_BLOCKS: int
GL_MAX_UNIFORM_BUFFER_BINDINGS: int
GL_MAX_UNIFORM_BLOCK_SIZE: int
GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS: int
GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS: int
GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS: int
GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT: int
GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH: int
GL_ACTIVE_UNIFORM_BLOCKS: int
GL_UNIFORM_TYPE: int
GL_UNIFORM_SIZE: int
GL_UNIFORM_NAME_LENGTH: int
GL_UNIFORM_BLOCK_INDEX: int
GL_UNIFORM_OFFSET: int
GL_UNIFORM_ARRAY_STRIDE: int
GL_UNIFORM_MATRIX_STRIDE: int
GL_UNIFORM_IS_ROW_MAJOR: int
GL_UNIFORM_BLOCK_BINDING: int
GL_UNIFORM_BLOCK_DATA_SIZE: int
GL_UNIFORM_BLOCK_NAME_LENGTH: int
GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS: int
GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES: int
GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER: int
GL_UNIFORM_BLOCK_REFERENCED_BY_GEOMETRY_SHADER: int
GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER: int
GL_FRAGMENT_SHADER: int
GL_VERTEX_SHADER: int
GL_MAX_FRAGMENT_UNIFORM_COMPONENTS: int
GL_MAX_VERTEX_UNIFORM_COMPONENTS: int
GL_MAX_VARYING_FLOATS: int
GL_MAX_VARYING_COMPONENTS: int
GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS: int
GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS: int
GL_SHADER_TYPE: int
GL_FLOAT_VEC2: int
GL_FLOAT_VEC3: int
GL_FLOAT_VEC4: int
GL_INT_VEC2: int
GL_INT_VEC3: int
GL_INT_VEC4: int
GL_BOOL: int
GL_BOOL_VEC2: int
GL_BOOL_VEC3: int
GL_BOOL_VEC4: int
GL_FLOAT_MAT2: int
GL_FLOAT_MAT3: int
GL_FLOAT_MAT4: int
GL_SAMPLER_1D: int
GL_SAMPLER_2D: int
GL_SAMPLER_3D: int
GL_SAMPLER_CUBE: int
GL_SAMPLER_1D_SHADOW: int
GL_SAMPLER_2D_SHADOW: int
GL_SAMPLER_2D_RECT: int
GL_SAMPLER_2D_RECT_SHADOW: int
GL_FLOAT_MAT2x3: int
GL_FLOAT_MAT2x4: int
GL_FLOAT_MAT3x2: int
GL_FLOAT_MAT3x4: int
GL_FLOAT_MAT4x2: int
GL_FLOAT_MAT4x3: int
GL_DELETE_STATUS: int
GL_COMPILE_STATUS: int
GL_LINK_STATUS: int
GL_VALIDATE_STATUS: int
GL_INFO_LOG_LENGTH: int
GL_ATTACHED_SHADERS: int
GL_ACTIVE_UNIFORMS: int
GL_ACTIVE_UNIFORM_MAX_LENGTH: int
GL_SHADER_SOURCE_LENGTH: int
GL_ACTIVE_ATTRIBUTES: int
GL_ACTIVE_ATTRIBUTE_MAX_LENGTH: int
GL_FRAGMENT_SHADER_DERIVATIVE_HINT: int
GL_SHADING_LANGUAGE_VERSION: int
GL_CURRENT_PROGRAM: int
GL_IMPLEMENTATION_COLOR_READ_TYPE: int
GL_IMPLEMENTATION_COLOR_READ_FORMAT: int
GL_TEXTURE_RED_TYPE: int
GL_TEXTURE_GREEN_TYPE: int
GL_TEXTURE_BLUE_TYPE: int
GL_TEXTURE_ALPHA_TYPE: int
GL_TEXTURE_LUMINANCE_TYPE: int
GL_TEXTURE_INTENSITY_TYPE: int
GL_TEXTURE_DEPTH_TYPE: int
GL_UNSIGNED_NORMALIZED: int
GL_TEXTURE_1D_ARRAY: int
GL_PROXY_TEXTURE_1D_ARRAY: int
GL_TEXTURE_2D_ARRAY: int
GL_PROXY_TEXTURE_2D_ARRAY: int
GL_TEXTURE_BINDING_1D_ARRAY: int
GL_TEXTURE_BINDING_2D_ARRAY: int
GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS: int
GL_TEXTURE_BUFFER: int
GL_TEXTURE_BUFFER_BINDING: int
GL_MAX_TEXTURE_BUFFER_SIZE: int
GL_TEXTURE_BINDING_BUFFER: int
GL_TEXTURE_BUFFER_DATA_STORE_BINDING: int
GL_ANY_SAMPLES_PASSED: int
GL_SAMPLE_SHADING: int
GL_MIN_SAMPLE_SHADING_VALUE: int
GL_R11F_G11F_B10F: int
GL_UNSIGNED_INT_10F_11F_11F_REV: int
GL_RGB9_E5: int
GL_UNSIGNED_INT_5_9_9_9_REV: int
GL_TEXTURE_SHARED_SIZE: int
GL_SRGB: int
GL_SRGB8: int
GL_SRGB_ALPHA: int
GL_SRGB8_ALPHA8: int
GL_SLUMINANCE_ALPHA: int
GL_SLUMINANCE8_ALPHA8: int
GL_SLUMINANCE: int
GL_SLUMINANCE8: int
GL_COMPRESSED_SRGB: int
GL_COMPRESSED_SRGB_ALPHA: int
GL_COMPRESSED_SLUMINANCE: int
GL_COMPRESSED_SLUMINANCE_ALPHA: int
GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH: int
GL_TRANSFORM_FEEDBACK_BUFFER_MODE: int
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS: int
GL_TRANSFORM_FEEDBACK_VARYINGS: int
GL_TRANSFORM_FEEDBACK_BUFFER_START: int
GL_TRANSFORM_FEEDBACK_BUFFER_SIZE: int
GL_PRIMITIVES_GENERATED: int
GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN: int
GL_RASTERIZER_DISCARD: int
GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS: int
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS: int
GL_INTERLEAVED_ATTRIBS: int
GL_SEPARATE_ATTRIBS: int
GL_TRANSFORM_FEEDBACK_BUFFER: int
GL_TRANSFORM_FEEDBACK_BUFFER_BINDING: int
GL_POINT_SPRITE_COORD_ORIGIN: int
GL_LOWER_LEFT: int
GL_UPPER_LEFT: int
GL_STENCIL_BACK_REF: int
GL_STENCIL_BACK_VALUE_MASK: int
GL_STENCIL_BACK_WRITEMASK: int
GL_FRAMEBUFFER_BINDING: int
GL_DRAW_FRAMEBUFFER_BINDING: int
GL_FRAMEBUFFER_BINDING_EXT: int
GL_RENDERBUFFER_BINDING: int
GL_RENDERBUFFER_BINDING_EXT: int
GL_READ_FRAMEBUFFER: int
GL_DRAW_FRAMEBUFFER: int
GL_READ_FRAMEBUFFER_BINDING: int
GL_RENDERBUFFER_SAMPLES: int
GL_DEPTH_COMPONENT32F: int
GL_DEPTH32F_STENCIL8: int
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE: int
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT: int
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME: int
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT: int
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL: int
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT: int
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE: int
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT: int
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER: int
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT: int
GL_FRAMEBUFFER_COMPLETE: int
GL_FRAMEBUFFER_COMPLETE_EXT: int
GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT: int
GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT: int
GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT: int
GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT: int
GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT: int
GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT: int
GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER: int
GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT: int
GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER: int
GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT: int
GL_FRAMEBUFFER_UNSUPPORTED: int
GL_FRAMEBUFFER_UNSUPPORTED_EXT: int
GL_MAX_COLOR_ATTACHMENTS: int
GL_MAX_COLOR_ATTACHMENTS_EXT: int
GL_COLOR_ATTACHMENT0: int
GL_COLOR_ATTACHMENT0_EXT: int
GL_COLOR_ATTACHMENT1: int
GL_COLOR_ATTACHMENT1_EXT: int
GL_COLOR_ATTACHMENT2: int
GL_COLOR_ATTACHMENT2_EXT: int
GL_COLOR_ATTACHMENT3: int
GL_COLOR_ATTACHMENT3_EXT: int
GL_COLOR_ATTACHMENT4: int
GL_COLOR_ATTACHMENT4_EXT: int
GL_COLOR_ATTACHMENT5: int
GL_COLOR_ATTACHMENT5_EXT: int
GL_COLOR_ATTACHMENT6: int
GL_COLOR_ATTACHMENT6_EXT: int
GL_COLOR_ATTACHMENT7: int
GL_COLOR_ATTACHMENT7_EXT: int
GL_COLOR_ATTACHMENT8: int
GL_COLOR_ATTACHMENT8_EXT: int
GL_COLOR_ATTACHMENT9: int
GL_COLOR_ATTACHMENT9_EXT: int
GL_COLOR_ATTACHMENT10: int
GL_COLOR_ATTACHMENT10_EXT: int
GL_COLOR_ATTACHMENT11: int
GL_COLOR_ATTACHMENT11_EXT: int
GL_COLOR_ATTACHMENT12: int
GL_COLOR_ATTACHMENT12_EXT: int
GL_COLOR_ATTACHMENT13: int
GL_COLOR_ATTACHMENT13_EXT: int
GL_COLOR_ATTACHMENT14: int
GL_COLOR_ATTACHMENT14_EXT: int
GL_COLOR_ATTACHMENT15: int
GL_COLOR_ATTACHMENT15_EXT: int
GL_COLOR_ATTACHMENT16: int
GL_COLOR_ATTACHMENT17: int
GL_COLOR_ATTACHMENT18: int
GL_COLOR_ATTACHMENT19: int
GL_COLOR_ATTACHMENT20: int
GL_COLOR_ATTACHMENT21: int
GL_COLOR_ATTACHMENT22: int
GL_COLOR_ATTACHMENT23: int
GL_COLOR_ATTACHMENT24: int
GL_COLOR_ATTACHMENT25: int
GL_COLOR_ATTACHMENT26: int
GL_COLOR_ATTACHMENT27: int
GL_COLOR_ATTACHMENT28: int
GL_COLOR_ATTACHMENT29: int
GL_COLOR_ATTACHMENT30: int
GL_COLOR_ATTACHMENT31: int
GL_DEPTH_ATTACHMENT: int
GL_DEPTH_ATTACHMENT_EXT: int
GL_STENCIL_ATTACHMENT: int
GL_STENCIL_ATTACHMENT_EXT: int
GL_FRAMEBUFFER: int
GL_FRAMEBUFFER_EXT: int
GL_RENDERBUFFER: int
GL_RENDERBUFFER_EXT: int
GL_RENDERBUFFER_WIDTH: int
GL_RENDERBUFFER_WIDTH_EXT: int
GL_RENDERBUFFER_HEIGHT: int
GL_RENDERBUFFER_HEIGHT_EXT: int
GL_RENDERBUFFER_INTERNAL_FORMAT: int
GL_RENDERBUFFER_INTERNAL_FORMAT_EXT: int
GL_STENCIL_INDEX1: int
GL_STENCIL_INDEX1_EXT: int
GL_STENCIL_INDEX4: int
GL_STENCIL_INDEX4_EXT: int
GL_STENCIL_INDEX8: int
GL_STENCIL_INDEX8_EXT: int
GL_STENCIL_INDEX16: int
GL_STENCIL_INDEX16_EXT: int
GL_RENDERBUFFER_RED_SIZE: int
GL_RENDERBUFFER_RED_SIZE_EXT: int
GL_RENDERBUFFER_GREEN_SIZE: int
GL_RENDERBUFFER_GREEN_SIZE_EXT: int
GL_RENDERBUFFER_BLUE_SIZE: int
GL_RENDERBUFFER_BLUE_SIZE_EXT: int
GL_RENDERBUFFER_ALPHA_SIZE: int
GL_RENDERBUFFER_ALPHA_SIZE_EXT: int
GL_RENDERBUFFER_DEPTH_SIZE: int
GL_RENDERBUFFER_DEPTH_SIZE_EXT: int
GL_RENDERBUFFER_STENCIL_SIZE: int
GL_RENDERBUFFER_STENCIL_SIZE_EXT: int
GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE: int
GL_MAX_SAMPLES: int
GL_RGB565: int
GL_PRIMITIVE_RESTART_FIXED_INDEX: int
GL_ANY_SAMPLES_PASSED_CONSERVATIVE: int
GL_MAX_ELEMENT_INDEX: int
GL_RGBA32UI: int
GL_RGB32UI: int
GL_RGBA16UI: int
GL_RGB16UI: int
GL_RGBA8UI: int
GL_RGB8UI: int
GL_RGBA32I: int
GL_RGB32I: int
GL_RGBA16I: int
GL_RGB16I: int
GL_RGBA8I: int
GL_RGB8I: int
GL_RED_INTEGER: int
GL_GREEN_INTEGER: int
GL_BLUE_INTEGER: int
GL_ALPHA_INTEGER: int
GL_RGB_INTEGER: int
GL_RGBA_INTEGER: int
GL_BGR_INTEGER: int
GL_BGRA_INTEGER: int
GL_INT_2_10_10_10_REV: int
GL_FRAMEBUFFER_ATTACHMENT_LAYERED: int
GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS: int
GL_FLOAT_32_UNSIGNED_INT_24_8_REV: int
GL_FRAMEBUFFER_SRGB: int
GL_COMPRESSED_RED_RGTC1: int
GL_COMPRESSED_SIGNED_RED_RGTC1: int
GL_COMPRESSED_RG_RGTC2: int
GL_COMPRESSED_SIGNED_RG_RGTC2: int
GL_SAMPLER_1D_ARRAY: int
GL_SAMPLER_2D_ARRAY: int
GL_SAMPLER_BUFFER: int
GL_SAMPLER_1D_ARRAY_SHADOW: int
GL_SAMPLER_2D_ARRAY_SHADOW: int
GL_SAMPLER_CUBE_SHADOW: int
GL_UNSIGNED_INT_VEC2: int
GL_UNSIGNED_INT_VEC3: int
GL_UNSIGNED_INT_VEC4: int
GL_INT_SAMPLER_1D: int
GL_INT_SAMPLER_2D: int
GL_INT_SAMPLER_3D: int
GL_INT_SAMPLER_CUBE: int
GL_INT_SAMPLER_2D_RECT: int
GL_INT_SAMPLER_1D_ARRAY: int
GL_INT_SAMPLER_2D_ARRAY: int
GL_INT_SAMPLER_BUFFER: int
GL_UNSIGNED_INT_SAMPLER_1D: int
GL_UNSIGNED_INT_SAMPLER_2D: int
GL_UNSIGNED_INT_SAMPLER_3D: int
GL_UNSIGNED_INT_SAMPLER_CUBE: int
GL_UNSIGNED_INT_SAMPLER_2D_RECT: int
GL_UNSIGNED_INT_SAMPLER_1D_ARRAY: int
GL_UNSIGNED_INT_SAMPLER_2D_ARRAY: int
GL_UNSIGNED_INT_SAMPLER_BUFFER: int
GL_GEOMETRY_SHADER: int
GL_MAX_GEOMETRY_UNIFORM_COMPONENTS: int
GL_MAX_GEOMETRY_OUTPUT_VERTICES: int
GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS: int
GL_ACTIVE_SUBROUTINES: int
GL_ACTIVE_SUBROUTINE_UNIFORMS: int
GL_MAX_SUBROUTINES: int
GL_MAX_SUBROUTINE_UNIFORM_LOCATIONS: int
GL_LOW_FLOAT: int
GL_MEDIUM_FLOAT: int
GL_HIGH_FLOAT: int
GL_LOW_INT: int
GL_MEDIUM_INT: int
GL_HIGH_INT: int
GL_SHADER_BINARY_FORMATS: int
GL_NUM_SHADER_BINARY_FORMATS: int
GL_SHADER_COMPILER: int
GL_MAX_VERTEX_UNIFORM_VECTORS: int
GL_MAX_VARYING_VECTORS: int
GL_MAX_FRAGMENT_UNIFORM_VECTORS: int
GL_QUERY_WAIT: int
GL_QUERY_NO_WAIT: int
GL_QUERY_BY_REGION_WAIT: int
GL_QUERY_BY_REGION_NO_WAIT: int
GL_QUERY_WAIT_INVERTED: int
GL_QUERY_NO_WAIT_INVERTED: int
GL_QUERY_BY_REGION_WAIT_INVERTED: int
GL_QUERY_BY_REGION_NO_WAIT_INVERTED: int
GL_POLYGON_OFFSET_CLAMP: int
GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS: int
GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS: int
GL_TRANSFORM_FEEDBACK: int
GL_TRANSFORM_FEEDBACK_BUFFER_PAUSED: int
GL_TRANSFORM_FEEDBACK_PAUSED: int
GL_TRANSFORM_FEEDBACK_BUFFER_ACTIVE: int
GL_TRANSFORM_FEEDBACK_ACTIVE: int
GL_TRANSFORM_FEEDBACK_BINDING: int
GL_TIMESTAMP: int
GL_TEXTURE_SWIZZLE_R: int
GL_TEXTURE_SWIZZLE_G: int
GL_TEXTURE_SWIZZLE_B: int
GL_TEXTURE_SWIZZLE_A: int
GL_TEXTURE_SWIZZLE_RGBA: int
GL_ACTIVE_SUBROUTINE_UNIFORM_LOCATIONS: int
GL_ACTIVE_SUBROUTINE_MAX_LENGTH: int
GL_ACTIVE_SUBROUTINE_UNIFORM_MAX_LENGTH: int
GL_NUM_COMPATIBLE_SUBROUTINES: int
GL_COMPATIBLE_SUBROUTINES: int
GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION: int
GL_FIRST_VERTEX_CONVENTION: int
GL_LAST_VERTEX_CONVENTION: int
GL_PROVOKING_VERTEX: int
GL_SAMPLE_POSITION: int
GL_SAMPLE_MASK: int
GL_SAMPLE_MASK_VALUE: int
GL_MAX_SAMPLE_MASK_WORDS: int
GL_MAX_GEOMETRY_SHADER_INVOCATIONS: int
GL_MIN_FRAGMENT_INTERPOLATION_OFFSET: int
GL_MAX_FRAGMENT_INTERPOLATION_OFFSET: int
GL_FRAGMENT_INTERPOLATION_OFFSET_BITS: int
GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET: int
GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET: int
GL_MAX_MESH_UNIFORM_BLOCKS_NV: int
GL_MAX_MESH_TEXTURE_IMAGE_UNITS_NV: int
GL_MAX_MESH_IMAGE_UNIFORMS_NV: int
GL_MAX_MESH_UNIFORM_COMPONENTS_NV: int
GL_MAX_MESH_ATOMIC_COUNTER_BUFFERS_NV: int
GL_MAX_MESH_ATOMIC_COUNTERS_NV: int
GL_MAX_MESH_SHADER_STORAGE_BLOCKS_NV: int
GL_MAX_COMBINED_MESH_UNIFORM_COMPONENTS_NV: int
GL_MAX_TASK_UNIFORM_BLOCKS_NV: int
GL_MAX_TASK_TEXTURE_IMAGE_UNITS_NV: int
GL_MAX_TASK_IMAGE_UNIFORMS_NV: int
GL_MAX_TASK_UNIFORM_COMPONENTS_NV: int
GL_MAX_TASK_ATOMIC_COUNTER_BUFFERS_NV: int
GL_MAX_TASK_ATOMIC_COUNTERS_NV: int
GL_MAX_TASK_SHADER_STORAGE_BLOCKS_NV: int
GL_MAX_COMBINED_TASK_UNIFORM_COMPONENTS_NV: int
GL_MAX_TRANSFORM_FEEDBACK_BUFFERS: int
GL_MAX_VERTEX_STREAMS: int
GL_PATCH_VERTICES: int
GL_PATCH_DEFAULT_INNER_LEVEL: int
GL_PATCH_DEFAULT_OUTER_LEVEL: int
GL_TESS_CONTROL_OUTPUT_VERTICES: int
GL_TESS_GEN_MODE: int
GL_TESS_GEN_SPACING: int
GL_TESS_GEN_VERTEX_ORDER: int
GL_TESS_GEN_POINT_MODE: int
GL_ISOLINES: int
GL_FRACTIONAL_ODD: int
GL_FRACTIONAL_EVEN: int
GL_MAX_PATCH_VERTICES: int
GL_MAX_TESS_GEN_LEVEL: int
GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS: int
GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS: int
GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS: int
GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS: int
GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS: int
GL_MAX_TESS_PATCH_COMPONENTS: int
GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS: int
GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS: int
GL_TESS_EVALUATION_SHADER: int
GL_TESS_CONTROL_SHADER: int
GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS: int
GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS: int
GL_COMPRESSED_RGBA_BPTC_UNORM: int
GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM: int
GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT: int
GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT: int
GL_COPY_READ_BUFFER: int
GL_COPY_READ_BUFFER_BINDING: int
GL_COPY_WRITE_BUFFER: int
GL_COPY_WRITE_BUFFER_BINDING: int
GL_MAX_IMAGE_UNITS: int
GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS: int
GL_MAX_COMBINED_SHADER_OUTPUT_RESOURCES: int
GL_IMAGE_BINDING_NAME: int
GL_IMAGE_BINDING_LEVEL: int
GL_IMAGE_BINDING_LAYERED: int
GL_IMAGE_BINDING_LAYER: int
GL_IMAGE_BINDING_ACCESS: int
GL_DRAW_INDIRECT_BUFFER: int
GL_DRAW_INDIRECT_BUFFER_BINDING: int
GL_DOUBLE_MAT2: int
GL_DOUBLE_MAT3: int
GL_DOUBLE_MAT4: int
GL_DOUBLE_MAT2x3: int
GL_DOUBLE_MAT2x4: int
GL_DOUBLE_MAT3x2: int
GL_DOUBLE_MAT3x4: int
GL_DOUBLE_MAT4x2: int
GL_DOUBLE_MAT4x3: int
GL_VERTEX_BINDING_BUFFER: int
GL_R8_SNORM: int
GL_RG8_SNORM: int
GL_RGB8_SNORM: int
GL_RGBA8_SNORM: int
GL_R16_SNORM: int
GL_RG16_SNORM: int
GL_RGB16_SNORM: int
GL_RGBA16_SNORM: int
GL_SIGNED_NORMALIZED: int
GL_PRIMITIVE_RESTART: int
GL_PRIMITIVE_RESTART_INDEX: int
GL_INT64_VEC2_ARB: int
GL_INT64_VEC3_ARB: int
GL_INT64_VEC4_ARB: int
GL_UNSIGNED_INT64_VEC2_ARB: int
GL_UNSIGNED_INT64_VEC3_ARB: int
GL_UNSIGNED_INT64_VEC4_ARB: int
GL_DOUBLE_VEC2: int
GL_DOUBLE_VEC3: int
GL_DOUBLE_VEC4: int
GL_TEXTURE_CUBE_MAP_ARRAY: int
GL_TEXTURE_BINDING_CUBE_MAP_ARRAY: int
GL_PROXY_TEXTURE_CUBE_MAP_ARRAY: int
GL_SAMPLER_CUBE_MAP_ARRAY: int
GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW: int
GL_INT_SAMPLER_CUBE_MAP_ARRAY: int
GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY: int
GL_IMAGE_1D: int
GL_IMAGE_2D: int
GL_IMAGE_3D: int
GL_IMAGE_2D_RECT: int
GL_IMAGE_CUBE: int
GL_IMAGE_BUFFER: int
GL_IMAGE_1D_ARRAY: int
GL_IMAGE_2D_ARRAY: int
GL_IMAGE_CUBE_MAP_ARRAY: int
GL_IMAGE_2D_MULTISAMPLE: int
GL_IMAGE_2D_MULTISAMPLE_ARRAY: int
GL_INT_IMAGE_1D: int
GL_INT_IMAGE_2D: int
GL_INT_IMAGE_3D: int
GL_INT_IMAGE_2D_RECT: int
GL_INT_IMAGE_CUBE: int
GL_INT_IMAGE_BUFFER: int
GL_INT_IMAGE_1D_ARRAY: int
GL_INT_IMAGE_2D_ARRAY: int
GL_INT_IMAGE_CUBE_MAP_ARRAY: int
GL_INT_IMAGE_2D_MULTISAMPLE: int
GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY: int
GL_UNSIGNED_INT_IMAGE_1D: int
GL_UNSIGNED_INT_IMAGE_2D: int
GL_UNSIGNED_INT_IMAGE_3D: int
GL_UNSIGNED_INT_IMAGE_2D_RECT: int
GL_UNSIGNED_INT_IMAGE_CUBE: int
GL_UNSIGNED_INT_IMAGE_BUFFER: int
GL_UNSIGNED_INT_IMAGE_1D_ARRAY: int
GL_UNSIGNED_INT_IMAGE_2D_ARRAY: int
GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY: int
GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE: int
GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY: int
GL_MAX_IMAGE_SAMPLES: int
GL_IMAGE_BINDING_FORMAT: int
GL_RGB10_A2UI: int
GL_MIN_MAP_BUFFER_ALIGNMENT: int
GL_IMAGE_FORMAT_COMPATIBILITY_TYPE: int
GL_IMAGE_FORMAT_COMPATIBILITY_BY_SIZE: int
GL_IMAGE_FORMAT_COMPATIBILITY_BY_CLASS: int
GL_MAX_VERTEX_IMAGE_UNIFORMS: int
GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS: int
GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS: int
GL_MAX_GEOMETRY_IMAGE_UNIFORMS: int
GL_MAX_FRAGMENT_IMAGE_UNIFORMS: int
GL_MAX_COMBINED_IMAGE_UNIFORMS: int
GL_SHADER_STORAGE_BUFFER: int
GL_SHADER_STORAGE_BUFFER_BINDING: int
GL_SHADER_STORAGE_BUFFER_START: int
GL_SHADER_STORAGE_BUFFER_SIZE: int
GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS: int
GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS: int
GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS: int
GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS: int
GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS: int
GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS: int
GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS: int
GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS: int
GL_MAX_SHADER_STORAGE_BLOCK_SIZE: int
GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT: int
GL_DEPTH_STENCIL_TEXTURE_MODE: int
GL_MAX_COMPUTE_WORK_GROUP_INVOCATIONS: int
GL_UNIFORM_BLOCK_REFERENCED_BY_COMPUTE_SHADER: int
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_COMPUTE_SHADER: int
GL_DISPATCH_INDIRECT_BUFFER: int
GL_DISPATCH_INDIRECT_BUFFER_BINDING: int
GL_TEXTURE_2D_MULTISAMPLE: int
GL_PROXY_TEXTURE_2D_MULTISAMPLE: int
GL_TEXTURE_2D_MULTISAMPLE_ARRAY: int
GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY: int
GL_TEXTURE_BINDING_2D_MULTISAMPLE: int
GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY: int
GL_TEXTURE_SAMPLES: int
GL_TEXTURE_FIXED_SAMPLE_LOCATIONS: int
GL_SAMPLER_2D_MULTISAMPLE: int
GL_INT_SAMPLER_2D_MULTISAMPLE: int
GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE: int
GL_SAMPLER_2D_MULTISAMPLE_ARRAY: int
GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY: int
GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY: int
GL_MAX_COLOR_TEXTURE_SAMPLES: int
GL_MAX_DEPTH_TEXTURE_SAMPLES: int
GL_MAX_INTEGER_SAMPLES: int
GL_MAX_SERVER_WAIT_TIMEOUT: int
GL_OBJECT_TYPE: int
GL_SYNC_CONDITION: int
GL_SYNC_STATUS: int
GL_SYNC_FLAGS: int
GL_SYNC_FENCE: int
GL_SYNC_GPU_COMMANDS_COMPLETE: int
GL_UNSIGNALED: int
GL_SIGNALED: int
GL_ALREADY_SIGNALED: int
GL_TIMEOUT_EXPIRED: int
GL_CONDITION_SATISFIED: int
GL_WAIT_FAILED: int
GL_BUFFER_ACCESS_FLAGS: int
GL_BUFFER_MAP_LENGTH: int
GL_BUFFER_MAP_OFFSET: int
GL_MAX_VERTEX_OUTPUT_COMPONENTS: int
GL_MAX_GEOMETRY_INPUT_COMPONENTS: int
GL_MAX_GEOMETRY_OUTPUT_COMPONENTS: int
GL_MAX_FRAGMENT_INPUT_COMPONENTS: int
GL_CONTEXT_PROFILE_MASK: int
GL_UNPACK_COMPRESSED_BLOCK_WIDTH: int
GL_UNPACK_COMPRESSED_BLOCK_HEIGHT: int
GL_UNPACK_COMPRESSED_BLOCK_DEPTH: int
GL_UNPACK_COMPRESSED_BLOCK_SIZE: int
GL_PACK_COMPRESSED_BLOCK_WIDTH: int
GL_PACK_COMPRESSED_BLOCK_HEIGHT: int
GL_PACK_COMPRESSED_BLOCK_DEPTH: int
GL_PACK_COMPRESSED_BLOCK_SIZE: int
GL_TEXTURE_IMMUTABLE_FORMAT: int
GL_MAX_DEBUG_MESSAGE_LENGTH: int
GL_MAX_DEBUG_LOGGED_MESSAGES: int
GL_DEBUG_LOGGED_MESSAGES: int
GL_DEBUG_SEVERITY_HIGH: int
GL_DEBUG_SEVERITY_MEDIUM: int
GL_DEBUG_SEVERITY_LOW: int
GL_QUERY_BUFFER: int
GL_QUERY_BUFFER_BINDING: int
GL_QUERY_RESULT_NO_WAIT: int
GL_TEXTURE_BUFFER_OFFSET: int
GL_TEXTURE_BUFFER_SIZE: int
GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT: int
GL_COMPUTE_SHADER: int
GL_MAX_COMPUTE_UNIFORM_BLOCKS: int
GL_MAX_COMPUTE_TEXTURE_IMAGE_UNITS: int
GL_MAX_COMPUTE_IMAGE_UNIFORMS: int
GL_MAX_COMPUTE_WORK_GROUP_COUNT: int
GL_MAX_COMPUTE_WORK_GROUP_SIZE: int
GL_COMPRESSED_R11_EAC: int
GL_COMPRESSED_SIGNED_R11_EAC: int
GL_COMPRESSED_RG11_EAC: int
GL_COMPRESSED_SIGNED_RG11_EAC: int
GL_COMPRESSED_RGB8_ETC2: int
GL_COMPRESSED_SRGB8_ETC2: int
GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2: int
GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2: int
GL_COMPRESSED_RGBA8_ETC2_EAC: int
GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC: int
GL_ATOMIC_COUNTER_BUFFER: int
GL_ATOMIC_COUNTER_BUFFER_BINDING: int
GL_ATOMIC_COUNTER_BUFFER_START: int
GL_ATOMIC_COUNTER_BUFFER_SIZE: int
GL_ATOMIC_COUNTER_BUFFER_DATA_SIZE: int
GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS: int
GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTER_INDICES: int
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_VERTEX_SHADER: int
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_CONTROL_SHADER: int
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_EVALUATION_SHADER: int
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_GEOMETRY_SHADER: int
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_FRAGMENT_SHADER: int
GL_MAX_VERTEX_ATOMIC_COUNTER_BUFFERS: int
GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS: int
GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS: int
GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS: int
GL_MAX_FRAGMENT_ATOMIC_COUNTER_BUFFERS: int
GL_MAX_COMBINED_ATOMIC_COUNTER_BUFFERS: int
GL_MAX_VERTEX_ATOMIC_COUNTERS: int
GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS: int
GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS: int
GL_MAX_GEOMETRY_ATOMIC_COUNTERS: int
GL_MAX_FRAGMENT_ATOMIC_COUNTERS: int
GL_MAX_COMBINED_ATOMIC_COUNTERS: int
GL_MAX_ATOMIC_COUNTER_BUFFER_SIZE: int
GL_ACTIVE_ATOMIC_COUNTER_BUFFERS: int
GL_UNIFORM_ATOMIC_COUNTER_BUFFER_INDEX: int
GL_UNSIGNED_INT_ATOMIC_COUNTER: int
GL_MAX_ATOMIC_COUNTER_BUFFER_BINDINGS: int
GL_MESH_OUTPUT_PER_VERTEX_GRANULARITY_NV: int
GL_DEBUG_OUTPUT: int
GL_UNIFORM: int
GL_UNIFORM_BLOCK: int
GL_PROGRAM_INPUT: int
GL_PROGRAM_OUTPUT: int
GL_BUFFER_VARIABLE: int
GL_SHADER_STORAGE_BLOCK: int
GL_IS_PER_PATCH: int
GL_VERTEX_SUBROUTINE: int
GL_TESS_CONTROL_SUBROUTINE: int
GL_TESS_EVALUATION_SUBROUTINE: int
GL_GEOMETRY_SUBROUTINE: int
GL_FRAGMENT_SUBROUTINE: int
GL_COMPUTE_SUBROUTINE: int
GL_VERTEX_SUBROUTINE_UNIFORM: int
GL_TESS_CONTROL_SUBROUTINE_UNIFORM: int
GL_TESS_EVALUATION_SUBROUTINE_UNIFORM: int
GL_GEOMETRY_SUBROUTINE_UNIFORM: int
GL_FRAGMENT_SUBROUTINE_UNIFORM: int
GL_COMPUTE_SUBROUTINE_UNIFORM: int
GL_TRANSFORM_FEEDBACK_VARYING: int
GL_ACTIVE_RESOURCES: int
GL_MAX_NAME_LENGTH: int
GL_MAX_NUM_ACTIVE_VARIABLES: int
GL_MAX_NUM_COMPATIBLE_SUBROUTINES: int
GL_NAME_LENGTH: int
GL_TYPE: int
GL_ARRAY_SIZE: int
GL_OFFSET: int
GL_BLOCK_INDEX: int
GL_ARRAY_STRIDE: int
GL_MATRIX_STRIDE: int
GL_IS_ROW_MAJOR: int
GL_ATOMIC_COUNTER_BUFFER_INDEX: int
GL_BUFFER_BINDING: int
GL_BUFFER_DATA_SIZE: int
GL_NUM_ACTIVE_VARIABLES: int
GL_ACTIVE_VARIABLES: int
GL_REFERENCED_BY_VERTEX_SHADER: int
GL_REFERENCED_BY_TESS_CONTROL_SHADER: int
GL_REFERENCED_BY_TESS_EVALUATION_SHADER: int
GL_REFERENCED_BY_GEOMETRY_SHADER: int
GL_REFERENCED_BY_FRAGMENT_SHADER: int
GL_REFERENCED_BY_COMPUTE_SHADER: int
GL_TOP_LEVEL_ARRAY_SIZE: int
GL_TOP_LEVEL_ARRAY_STRIDE: int
GL_LOCATION: int
GL_LOCATION_INDEX: int
GL_FRAMEBUFFER_DEFAULT_WIDTH: int
GL_FRAMEBUFFER_DEFAULT_HEIGHT: int
GL_FRAMEBUFFER_DEFAULT_LAYERS: int
GL_FRAMEBUFFER_DEFAULT_SAMPLES: int
GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS: int
GL_MAX_FRAMEBUFFER_WIDTH: int
GL_MAX_FRAMEBUFFER_HEIGHT: int
GL_MAX_FRAMEBUFFER_LAYERS: int
GL_MAX_FRAMEBUFFER_SAMPLES: int
GL_LOCATION_COMPONENT: int
GL_TRANSFORM_FEEDBACK_BUFFER_INDEX: int
GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE: int
GL_CLIP_ORIGIN: int
GL_CLIP_DEPTH_MODE: int
GL_NEGATIVE_ONE_TO_ONE: int
GL_ZERO_TO_ONE: int
GL_CLEAR_TEXTURE: int
GL_NUM_SAMPLE_COUNTS: int
GL_MAX_MESH_TOTAL_MEMORY_SIZE_NV: int
GL_MAX_TASK_TOTAL_MEMORY_SIZE_NV: int
GL_MAX_MESH_OUTPUT_VERTICES_NV: int
GL_MAX_MESH_OUTPUT_PRIMITIVES_NV: int
GL_MAX_TASK_OUTPUT_COUNT_NV: int
GL_MAX_MESH_WORK_GROUP_SIZE_NV: int
GL_MAX_TASK_WORK_GROUP_SIZE_NV: int
GL_MAX_DRAW_MESH_TASKS_COUNT_NV: int
GL_MESH_WORK_GROUP_SIZE_NV: int
GL_TASK_WORK_GROUP_SIZE_NV: int
GL_MESH_OUTPUT_PER_PRIMITIVE_GRANULARITY_NV: int
GL_SHADER_BINARY_FORMAT_SPIR_V: int
GL_SPIR_V_BINARY: int
GL_SPIR_V_EXTENSIONS: int
GL_NUM_SPIR_V_EXTENSIONS: int
GL_MAX_MESH_VIEWS_NV: int
GL_MESH_SHADER_NV: int
GL_TASK_SHADER_NV: int
GL_MESH_VERTICES_OUT_NV: int
GL_MESH_PRIMITIVES_OUT_NV: int
GL_MESH_OUTPUT_TYPE_NV: int
GL_MESH_SUBROUTINE_NV: int
GL_TASK_SUBROUTINE_NV: int
GL_MESH_SUBROUTINE_UNIFORM_NV: int
GL_TASK_SUBROUTINE_UNIFORM_NV: int
GL_UNIFORM_BLOCK_REFERENCED_BY_MESH_SHADER_NV: int
GL_UNIFORM_BLOCK_REFERENCED_BY_TASK_SHADER_NV: int
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_MESH_SHADER_NV: int
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TASK_SHADER_NV: int
GL_REFERENCED_BY_MESH_SHADER_NV: int
GL_REFERENCED_BY_TASK_SHADER_NV: int
GL_MAX_MESH_WORK_GROUP_INVOCATIONS_NV: int
GL_MAX_TASK_WORK_GROUP_INVOCATIONS_NV: int
GL_EVAL_BIT: int
GL_LIST_BIT: int
GL_TEXTURE_BIT: int
GL_SCISSOR_BIT: int
GL_MULTISAMPLE_BIT: int
GL_MULTISAMPLE_BIT_ARB: int
GL_ALL_ATTRIB_BITS: int
GL_CLIENT_ALL_ATTRIB_BITS: int
GL_INVALID_INDEX: int
GL_ALL_SHADER_BITS: int
GL_ALL_BARRIER_BITS: int
GL_TIMEOUT_IGNORED: int

# GL command definitions
def glAccum(op: GLenum | int, value: GLfloat | float) -> None: ...
def glActiveShaderProgram(pipeline: GLuint | int, program: GLuint | int) -> None: ...
def glActiveTexture(texture: GLenum | int) -> None: ...
def glAlphaFunc(func: GLenum | int, ref: GLfloat | float) -> None: ...
def glAreTexturesResident(n: GLsizei | int, textures: _Pointer[GLuint] | Any, residences: _Pointer[GLboolean] | Any) -> int: ...
def glArrayElement(i: GLint | int) -> None: ...
def glAttachShader(program: GLuint | int, shader: GLuint | int) -> None: ...
def glBegin(mode: GLenum | int) -> None: ...
def glBeginConditionalRender(id: GLuint | int, mode: GLenum | int) -> None: ...
def glBeginQuery(target: GLenum | int, id: GLuint | int) -> None: ...
def glBeginQueryIndexed(target: GLenum | int, index: GLuint | int, id: GLuint | int) -> None: ...
def glBeginTransformFeedback(primitiveMode: GLenum | int) -> None: ...
def glBindAttribLocation(program: GLuint | int, index: GLuint | int, name: _Pointer[GLchar] | Any) -> None: ...
def glBindBuffer(target: GLenum | int, buffer: GLuint | int) -> None: ...
def glBindBufferBase(target: GLenum | int, index: GLuint | int, buffer: GLuint | int) -> None: ...
def glBindBufferRange(target: GLenum | int, index: GLuint | int, buffer: GLuint | int, offset: GLintptr, size: GLsizeiptr) -> None: ...
def glBindBuffersBase(target: GLenum | int, first: GLuint | int, count: GLsizei | int, buffers: _Pointer[GLuint] | Any) -> None: ...
def glBindBuffersRange(target: GLenum | int, first: GLuint | int, count: GLsizei | int, buffers: _Pointer[GLuint] | Any, offsets: _Pointer[GLintptr] | Any, sizes: _Pointer[GLsizeiptr] | Any) -> None: ...
def glBindFragDataLocation(program: GLuint | int, color: GLuint | int, name: _Pointer[GLchar] | Any) -> None: ...
def glBindFragDataLocationIndexed(program: GLuint | int, colorNumber: GLuint | int, index: GLuint | int, name: _Pointer[GLchar] | Any) -> None: ...
def glBindFramebuffer(target: GLenum | int, framebuffer: GLuint | int) -> None: ...
def glBindFramebufferEXT(target: GLenum | int, framebuffer: GLuint | int) -> None: ...
def glBindImageTexture(unit: GLuint | int, texture: GLuint | int, level: GLint | int, layered: GLboolean | int, layer: GLint | int, access: GLenum | int, format: GLenum | int) -> None: ...
def glBindImageTextures(first: GLuint | int, count: GLsizei | int, textures: _Pointer[GLuint] | Any) -> None: ...
def glBindProgramPipeline(pipeline: GLuint | int) -> None: ...
def glBindRenderbuffer(target: GLenum | int, renderbuffer: GLuint | int) -> None: ...
def glBindRenderbufferEXT(target: GLenum | int, renderbuffer: GLuint | int) -> None: ...
def glBindSampler(unit: GLuint | int, sampler: GLuint | int) -> None: ...
def glBindSamplers(first: GLuint | int, count: GLsizei | int, samplers: _Pointer[GLuint] | Any) -> None: ...
def glBindTexture(target: GLenum | int, texture: GLuint | int) -> None: ...
def glBindTextureUnit(unit: GLuint | int, texture: GLuint | int) -> None: ...
def glBindTextures(first: GLuint | int, count: GLsizei | int, textures: _Pointer[GLuint] | Any) -> None: ...
def glBindTransformFeedback(target: GLenum | int, id: GLuint | int) -> None: ...
def glBindVertexArray(array: GLuint | int) -> None: ...
def glBindVertexBuffer(bindingindex: GLuint | int, buffer: GLuint | int, offset: GLintptr, stride: GLsizei | int) -> None: ...
def glBindVertexBuffers(first: GLuint | int, count: GLsizei | int, buffers: _Pointer[GLuint] | Any, offsets: _Pointer[GLintptr] | Any, strides: _Pointer[GLsizei] | Any) -> None: ...
def glBitmap(width: GLsizei | int, height: GLsizei | int, xorig: GLfloat | float, yorig: GLfloat | float, xmove: GLfloat | float, ymove: GLfloat | float, bitmap: _Pointer[GLubyte] | Any) -> None: ...
def glBlendColor(red: GLfloat | float, green: GLfloat | float, blue: GLfloat | float, alpha: GLfloat | float) -> None: ...
def glBlendEquation(mode: GLenum | int) -> None: ...
def glBlendEquationSeparate(modeRGB: GLenum | int, modeAlpha: GLenum | int) -> None: ...
def glBlendEquationSeparatei(buf: GLuint | int, modeRGB: GLenum | int, modeAlpha: GLenum | int) -> None: ...
def glBlendEquationi(buf: GLuint | int, mode: GLenum | int) -> None: ...
def glBlendFunc(sfactor: GLenum | int, dfactor: GLenum | int) -> None: ...
def glBlendFuncSeparate(sfactorRGB: GLenum | int, dfactorRGB: GLenum | int, sfactorAlpha: GLenum | int, dfactorAlpha: GLenum | int) -> None: ...
def glBlendFuncSeparatei(buf: GLuint | int, srcRGB: GLenum | int, dstRGB: GLenum | int, srcAlpha: GLenum | int, dstAlpha: GLenum | int) -> None: ...
def glBlendFunci(buf: GLuint | int, src: GLenum | int, dst: GLenum | int) -> None: ...
def glBlitFramebuffer(srcX0: GLint | int, srcY0: GLint | int, srcX1: GLint | int, srcY1: GLint | int, dstX0: GLint | int, dstY0: GLint | int, dstX1: GLint | int, dstY1: GLint | int, mask: GLbitfield | int, filter: GLenum | int) -> None: ...
def glBlitNamedFramebuffer(readFramebuffer: GLuint | int, drawFramebuffer: GLuint | int, srcX0: GLint | int, srcY0: GLint | int, srcX1: GLint | int, srcY1: GLint | int, dstX0: GLint | int, dstY0: GLint | int, dstX1: GLint | int, dstY1: GLint | int, mask: GLbitfield | int, filter: GLenum | int) -> None: ...
def glBufferData(target: GLenum | int, size: GLsizeiptr, data: _Pointer[GLvoid] | Any, usage: GLenum | int) -> None: ...
def glBufferStorage(target: GLenum | int, size: GLsizeiptr, data: _Pointer[GLvoid] | Any, flags: GLbitfield | int) -> None: ...
def glBufferSubData(target: GLenum | int, offset: GLintptr, size: GLsizeiptr, data: _Pointer[GLvoid] | Any) -> None: ...
def glCallList(list: GLuint | int) -> None: ...
def glCallLists(n: GLsizei | int, type: GLenum | int, lists: _Pointer[GLvoid] | Any) -> None: ...
def glCheckFramebufferStatus(target: GLenum | int) -> int: ...
def glCheckFramebufferStatusEXT(target: GLenum | int) -> int: ...
def glCheckNamedFramebufferStatus(framebuffer: GLuint | int, target: GLenum | int) -> int: ...
def glClampColor(target: GLenum | int, clamp: GLenum | int) -> None: ...
def glClear(mask: GLbitfield | int) -> None: ...
def glClearAccum(red: GLfloat | float, green: GLfloat | float, blue: GLfloat | float, alpha: GLfloat | float) -> None: ...
def glClearBufferData(target: GLenum | int, internalformat: GLenum | int, format: GLenum | int, type: GLenum | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glClearBufferSubData(target: GLenum | int, internalformat: GLenum | int, offset: GLintptr, size: GLsizeiptr, format: GLenum | int, type: GLenum | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glClearBufferfi(buffer: GLenum | int, drawbuffer: GLint | int, depth: GLfloat | float, stencil: GLint | int) -> None: ...
def glClearBufferfv(buffer: GLenum | int, drawbuffer: GLint | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glClearBufferiv(buffer: GLenum | int, drawbuffer: GLint | int, value: _Pointer[GLint] | Any) -> None: ...
def glClearBufferuiv(buffer: GLenum | int, drawbuffer: GLint | int, value: _Pointer[GLuint] | Any) -> None: ...
def glClearColor(red: GLfloat | float, green: GLfloat | float, blue: GLfloat | float, alpha: GLfloat | float) -> None: ...
def glClearDepth(depth: GLdouble | float) -> None: ...
def glClearDepthf(d: GLfloat | float) -> None: ...
def glClearIndex(c: GLfloat | float) -> None: ...
def glClearNamedBufferData(buffer: GLuint | int, internalformat: GLenum | int, format: GLenum | int, type: GLenum | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glClearNamedBufferSubData(buffer: GLuint | int, internalformat: GLenum | int, offset: GLintptr, size: GLsizeiptr, format: GLenum | int, type: GLenum | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glClearNamedFramebufferfi(framebuffer: GLuint | int, buffer: GLenum | int, drawbuffer: GLint | int, depth: GLfloat | float, stencil: GLint | int) -> None: ...
def glClearNamedFramebufferfv(framebuffer: GLuint | int, buffer: GLenum | int, drawbuffer: GLint | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glClearNamedFramebufferiv(framebuffer: GLuint | int, buffer: GLenum | int, drawbuffer: GLint | int, value: _Pointer[GLint] | Any) -> None: ...
def glClearNamedFramebufferuiv(framebuffer: GLuint | int, buffer: GLenum | int, drawbuffer: GLint | int, value: _Pointer[GLuint] | Any) -> None: ...
def glClearStencil(s: GLint | int) -> None: ...
def glClearTexImage(texture: GLuint | int, level: GLint | int, format: GLenum | int, type: GLenum | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glClearTexSubImage(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, zoffset: GLint | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int, format: GLenum | int, type: GLenum | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glClientActiveTexture(texture: GLenum | int) -> None: ...
def glClientWaitSync(sync: GLsync, flags: GLbitfield | int, timeout: GLuint64 | int) -> int: ...
def glClipControl(origin: GLenum | int, depth: GLenum | int) -> None: ...
def glClipPlane(plane: GLenum | int, equation: _Pointer[GLdouble] | Any) -> None: ...
def glColor3b(red: GLbyte | bytes, green: GLbyte | bytes, blue: GLbyte | bytes) -> None: ...
def glColor3bv(v: _Pointer[GLbyte] | Any) -> None: ...
def glColor3d(red: GLdouble | float, green: GLdouble | float, blue: GLdouble | float) -> None: ...
def glColor3dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glColor3f(red: GLfloat | float, green: GLfloat | float, blue: GLfloat | float) -> None: ...
def glColor3fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glColor3i(red: GLint | int, green: GLint | int, blue: GLint | int) -> None: ...
def glColor3iv(v: _Pointer[GLint] | Any) -> None: ...
def glColor3s(red: GLshort | int, green: GLshort | int, blue: GLshort | int) -> None: ...
def glColor3sv(v: _Pointer[GLshort] | Any) -> None: ...
def glColor3ub(red: GLubyte | int, green: GLubyte | int, blue: GLubyte | int) -> None: ...
def glColor3ubv(v: _Pointer[GLubyte] | Any) -> None: ...
def glColor3ui(red: GLuint | int, green: GLuint | int, blue: GLuint | int) -> None: ...
def glColor3uiv(v: _Pointer[GLuint] | Any) -> None: ...
def glColor3us(red: GLushort | int, green: GLushort | int, blue: GLushort | int) -> None: ...
def glColor3usv(v: _Pointer[GLushort] | Any) -> None: ...
def glColor4b(red: GLbyte | bytes, green: GLbyte | bytes, blue: GLbyte | bytes, alpha: GLbyte | bytes) -> None: ...
def glColor4bv(v: _Pointer[GLbyte] | Any) -> None: ...
def glColor4d(red: GLdouble | float, green: GLdouble | float, blue: GLdouble | float, alpha: GLdouble | float) -> None: ...
def glColor4dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glColor4f(red: GLfloat | float, green: GLfloat | float, blue: GLfloat | float, alpha: GLfloat | float) -> None: ...
def glColor4fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glColor4i(red: GLint | int, green: GLint | int, blue: GLint | int, alpha: GLint | int) -> None: ...
def glColor4iv(v: _Pointer[GLint] | Any) -> None: ...
def glColor4s(red: GLshort | int, green: GLshort | int, blue: GLshort | int, alpha: GLshort | int) -> None: ...
def glColor4sv(v: _Pointer[GLshort] | Any) -> None: ...
def glColor4ub(red: GLubyte | int, green: GLubyte | int, blue: GLubyte | int, alpha: GLubyte | int) -> None: ...
def glColor4ubv(v: _Pointer[GLubyte] | Any) -> None: ...
def glColor4ui(red: GLuint | int, green: GLuint | int, blue: GLuint | int, alpha: GLuint | int) -> None: ...
def glColor4uiv(v: _Pointer[GLuint] | Any) -> None: ...
def glColor4us(red: GLushort | int, green: GLushort | int, blue: GLushort | int, alpha: GLushort | int) -> None: ...
def glColor4usv(v: _Pointer[GLushort] | Any) -> None: ...
def glColorMask(red: GLboolean | int, green: GLboolean | int, blue: GLboolean | int, alpha: GLboolean | int) -> None: ...
def glColorMaski(index: GLuint | int, r: GLboolean | int, g: GLboolean | int, b: GLboolean | int, a: GLboolean | int) -> None: ...
def glColorMaterial(face: GLenum | int, mode: GLenum | int) -> None: ...
def glColorP3ui(type: GLenum | int, color: GLuint | int) -> None: ...
def glColorP3uiv(type: GLenum | int, color: _Pointer[GLuint] | Any) -> None: ...
def glColorP4ui(type: GLenum | int, color: GLuint | int) -> None: ...
def glColorP4uiv(type: GLenum | int, color: _Pointer[GLuint] | Any) -> None: ...
def glColorPointer(size: GLint | int, type: GLenum | int, stride: GLsizei | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glCompileShader(shader: GLuint | int) -> None: ...
def glCompressedTexImage1D(target: GLenum | int, level: GLint | int, internalformat: GLenum | int, width: GLsizei | int, border: GLint | int, imageSize: GLsizei | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glCompressedTexImage2D(target: GLenum | int, level: GLint | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int, border: GLint | int, imageSize: GLsizei | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glCompressedTexImage3D(target: GLenum | int, level: GLint | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int, border: GLint | int, imageSize: GLsizei | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glCompressedTexSubImage1D(target: GLenum | int, level: GLint | int, xoffset: GLint | int, width: GLsizei | int, format: GLenum | int, imageSize: GLsizei | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glCompressedTexSubImage2D(target: GLenum | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, width: GLsizei | int, height: GLsizei | int, format: GLenum | int, imageSize: GLsizei | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glCompressedTexSubImage3D(target: GLenum | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, zoffset: GLint | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int, format: GLenum | int, imageSize: GLsizei | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glCompressedTextureSubImage1D(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, width: GLsizei | int, format: GLenum | int, imageSize: GLsizei | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glCompressedTextureSubImage2D(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, width: GLsizei | int, height: GLsizei | int, format: GLenum | int, imageSize: GLsizei | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glCompressedTextureSubImage3D(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, zoffset: GLint | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int, format: GLenum | int, imageSize: GLsizei | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glCopyBufferSubData(readTarget: GLenum | int, writeTarget: GLenum | int, readOffset: GLintptr, writeOffset: GLintptr, size: GLsizeiptr) -> None: ...
def glCopyImageSubData(srcName: GLuint | int, srcTarget: GLenum | int, srcLevel: GLint | int, srcX: GLint | int, srcY: GLint | int, srcZ: GLint | int, dstName: GLuint | int, dstTarget: GLenum | int, dstLevel: GLint | int, dstX: GLint | int, dstY: GLint | int, dstZ: GLint | int, srcWidth: GLsizei | int, srcHeight: GLsizei | int, srcDepth: GLsizei | int) -> None: ...
def glCopyNamedBufferSubData(readBuffer: GLuint | int, writeBuffer: GLuint | int, readOffset: GLintptr, writeOffset: GLintptr, size: GLsizeiptr) -> None: ...
def glCopyPixels(x: GLint | int, y: GLint | int, width: GLsizei | int, height: GLsizei | int, type: GLenum | int) -> None: ...
def glCopyTexImage1D(target: GLenum | int, level: GLint | int, internalformat: GLenum | int, x: GLint | int, y: GLint | int, width: GLsizei | int, border: GLint | int) -> None: ...
def glCopyTexImage2D(target: GLenum | int, level: GLint | int, internalformat: GLenum | int, x: GLint | int, y: GLint | int, width: GLsizei | int, height: GLsizei | int, border: GLint | int) -> None: ...
def glCopyTexSubImage1D(target: GLenum | int, level: GLint | int, xoffset: GLint | int, x: GLint | int, y: GLint | int, width: GLsizei | int) -> None: ...
def glCopyTexSubImage2D(target: GLenum | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, x: GLint | int, y: GLint | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glCopyTexSubImage3D(target: GLenum | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, zoffset: GLint | int, x: GLint | int, y: GLint | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glCopyTextureSubImage1D(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, x: GLint | int, y: GLint | int, width: GLsizei | int) -> None: ...
def glCopyTextureSubImage2D(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, x: GLint | int, y: GLint | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glCopyTextureSubImage3D(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, zoffset: GLint | int, x: GLint | int, y: GLint | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glCreateBuffers(n: GLsizei | int, buffers: _Pointer[GLuint] | Any) -> None: ...
def glCreateFramebuffers(n: GLsizei | int, framebuffers: _Pointer[GLuint] | Any) -> None: ...
def glCreateProgram() -> int: ...
def glCreateProgramPipelines(n: GLsizei | int, pipelines: _Pointer[GLuint] | Any) -> None: ...
def glCreateQueries(target: GLenum | int, n: GLsizei | int, ids: _Pointer[GLuint] | Any) -> None: ...
def glCreateRenderbuffers(n: GLsizei | int, renderbuffers: _Pointer[GLuint] | Any) -> None: ...
def glCreateSamplers(n: GLsizei | int, samplers: _Pointer[GLuint] | Any) -> None: ...
def glCreateShader(type: GLenum | int) -> int: ...
def glCreateShaderProgramv(type: GLenum | int, count: GLsizei | int, strings: _Pointer[_Pointer[GLchar]] | Any) -> int: ...
def glCreateTextures(target: GLenum | int, n: GLsizei | int, textures: _Pointer[GLuint] | Any) -> None: ...
def glCreateTransformFeedbacks(n: GLsizei | int, ids: _Pointer[GLuint] | Any) -> None: ...
def glCreateVertexArrays(n: GLsizei | int, arrays: _Pointer[GLuint] | Any) -> None: ...
def glCullFace(mode: GLenum | int) -> None: ...
def glDebugMessageCallback(callback: GLDEBUGPROC, userParam: _Pointer[GLvoid] | Any) -> None: ...
def glDebugMessageControl(source: GLenum | int, type: GLenum | int, severity: GLenum | int, count: GLsizei | int, ids: _Pointer[GLuint] | Any, enabled: GLboolean | int) -> None: ...
def glDebugMessageInsert(source: GLenum | int, type: GLenum | int, id: GLuint | int, severity: GLenum | int, length: GLsizei | int, buf: _Pointer[GLchar] | Any) -> None: ...
def glDeleteBuffers(n: GLsizei | int, buffers: _Pointer[GLuint] | Any) -> None: ...
def glDeleteFramebuffers(n: GLsizei | int, framebuffers: _Pointer[GLuint] | Any) -> None: ...
def glDeleteFramebuffersEXT(n: GLsizei | int, framebuffers: _Pointer[GLuint] | Any) -> None: ...
def glDeleteLists(list: GLuint | int, range: GLsizei | int) -> None: ...
def glDeleteProgram(program: GLuint | int) -> None: ...
def glDeleteProgramPipelines(n: GLsizei | int, pipelines: _Pointer[GLuint] | Any) -> None: ...
def glDeleteQueries(n: GLsizei | int, ids: _Pointer[GLuint] | Any) -> None: ...
def glDeleteRenderbuffers(n: GLsizei | int, renderbuffers: _Pointer[GLuint] | Any) -> None: ...
def glDeleteRenderbuffersEXT(n: GLsizei | int, renderbuffers: _Pointer[GLuint] | Any) -> None: ...
def glDeleteSamplers(count: GLsizei | int, samplers: _Pointer[GLuint] | Any) -> None: ...
def glDeleteShader(shader: GLuint | int) -> None: ...
def glDeleteSync(sync: GLsync) -> None: ...
def glDeleteTextures(n: GLsizei | int, textures: _Pointer[GLuint] | Any) -> None: ...
def glDeleteTransformFeedbacks(n: GLsizei | int, ids: _Pointer[GLuint] | Any) -> None: ...
def glDeleteVertexArrays(n: GLsizei | int, arrays: _Pointer[GLuint] | Any) -> None: ...
def glDepthFunc(func: GLenum | int) -> None: ...
def glDepthMask(flag: GLboolean | int) -> None: ...
def glDepthRange(n: GLdouble | float, f: GLdouble | float) -> None: ...
def glDepthRangeArrayv(first: GLuint | int, count: GLsizei | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glDepthRangeIndexed(index: GLuint | int, n: GLdouble | float, f: GLdouble | float) -> None: ...
def glDepthRangef(n: GLfloat | float, f: GLfloat | float) -> None: ...
def glDetachShader(program: GLuint | int, shader: GLuint | int) -> None: ...
def glDisable(cap: GLenum | int) -> None: ...
def glDisableClientState(array: GLenum | int) -> None: ...
def glDisableVertexArrayAttrib(vaobj: GLuint | int, index: GLuint | int) -> None: ...
def glDisableVertexAttribArray(index: GLuint | int) -> None: ...
def glDisablei(target: GLenum | int, index: GLuint | int) -> None: ...
def glDispatchCompute(num_groups_x: GLuint | int, num_groups_y: GLuint | int, num_groups_z: GLuint | int) -> None: ...
def glDispatchComputeIndirect(indirect: GLintptr) -> None: ...
def glDrawArrays(mode: GLenum | int, first: GLint | int, count: GLsizei | int) -> None: ...
def glDrawArraysIndirect(mode: GLenum | int, indirect: _Pointer[GLvoid] | Any) -> None: ...
def glDrawArraysInstanced(mode: GLenum | int, first: GLint | int, count: GLsizei | int, instancecount: GLsizei | int) -> None: ...
def glDrawArraysInstancedBaseInstance(mode: GLenum | int, first: GLint | int, count: GLsizei | int, instancecount: GLsizei | int, baseinstance: GLuint | int) -> None: ...
def glDrawBuffer(buf: GLenum | int) -> None: ...
def glDrawBuffers(n: GLsizei | int, bufs: _Pointer[GLenum] | Any) -> None: ...
def glDrawElements(mode: GLenum | int, count: GLsizei | int, type: GLenum | int, indices: _Pointer[GLvoid] | Any) -> None: ...
def glDrawElementsBaseVertex(mode: GLenum | int, count: GLsizei | int, type: GLenum | int, indices: _Pointer[GLvoid] | Any, basevertex: GLint | int) -> None: ...
def glDrawElementsIndirect(mode: GLenum | int, type: GLenum | int, indirect: _Pointer[GLvoid] | Any) -> None: ...
def glDrawElementsInstanced(mode: GLenum | int, count: GLsizei | int, type: GLenum | int, indices: _Pointer[GLvoid] | Any, instancecount: GLsizei | int) -> None: ...
def glDrawElementsInstancedBaseInstance(mode: GLenum | int, count: GLsizei | int, type: GLenum | int, indices: _Pointer[GLvoid] | Any, instancecount: GLsizei | int, baseinstance: GLuint | int) -> None: ...
def glDrawElementsInstancedBaseVertex(mode: GLenum | int, count: GLsizei | int, type: GLenum | int, indices: _Pointer[GLvoid] | Any, instancecount: GLsizei | int, basevertex: GLint | int) -> None: ...
def glDrawElementsInstancedBaseVertexBaseInstance(mode: GLenum | int, count: GLsizei | int, type: GLenum | int, indices: _Pointer[GLvoid] | Any, instancecount: GLsizei | int, basevertex: GLint | int, baseinstance: GLuint | int) -> None: ...
def glDrawMeshTasksIndirectNV(indirect: GLintptr) -> None: ...
def glDrawMeshTasksNV(first: GLuint | int, count: GLuint | int) -> None: ...
def glDrawPixels(width: GLsizei | int, height: GLsizei | int, format: GLenum | int, type: GLenum | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glDrawRangeElements(mode: GLenum | int, start: GLuint | int, end: GLuint | int, count: GLsizei | int, type: GLenum | int, indices: _Pointer[GLvoid] | Any) -> None: ...
def glDrawRangeElementsBaseVertex(mode: GLenum | int, start: GLuint | int, end: GLuint | int, count: GLsizei | int, type: GLenum | int, indices: _Pointer[GLvoid] | Any, basevertex: GLint | int) -> None: ...
def glDrawTransformFeedback(mode: GLenum | int, id: GLuint | int) -> None: ...
def glDrawTransformFeedbackInstanced(mode: GLenum | int, id: GLuint | int, instancecount: GLsizei | int) -> None: ...
def glDrawTransformFeedbackStream(mode: GLenum | int, id: GLuint | int, stream: GLuint | int) -> None: ...
def glDrawTransformFeedbackStreamInstanced(mode: GLenum | int, id: GLuint | int, stream: GLuint | int, instancecount: GLsizei | int) -> None: ...
def glEdgeFlag(flag: GLboolean | int) -> None: ...
def glEdgeFlagPointer(stride: GLsizei | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glEdgeFlagv(flag: _Pointer[GLboolean] | Any) -> None: ...
def glEnable(cap: GLenum | int) -> None: ...
def glEnableClientState(array: GLenum | int) -> None: ...
def glEnableVertexArrayAttrib(vaobj: GLuint | int, index: GLuint | int) -> None: ...
def glEnableVertexAttribArray(index: GLuint | int) -> None: ...
def glEnablei(target: GLenum | int, index: GLuint | int) -> None: ...
def glEnd() -> None: ...
def glEndConditionalRender() -> None: ...
def glEndList() -> None: ...
def glEndQuery(target: GLenum | int) -> None: ...
def glEndQueryIndexed(target: GLenum | int, index: GLuint | int) -> None: ...
def glEndTransformFeedback() -> None: ...
def glEvalCoord1d(u: GLdouble | float) -> None: ...
def glEvalCoord1dv(u: _Pointer[GLdouble] | Any) -> None: ...
def glEvalCoord1f(u: GLfloat | float) -> None: ...
def glEvalCoord1fv(u: _Pointer[GLfloat] | Any) -> None: ...
def glEvalCoord2d(u: GLdouble | float, v: GLdouble | float) -> None: ...
def glEvalCoord2dv(u: _Pointer[GLdouble] | Any) -> None: ...
def glEvalCoord2f(u: GLfloat | float, v: GLfloat | float) -> None: ...
def glEvalCoord2fv(u: _Pointer[GLfloat] | Any) -> None: ...
def glEvalMesh1(mode: GLenum | int, i1: GLint | int, i2: GLint | int) -> None: ...
def glEvalMesh2(mode: GLenum | int, i1: GLint | int, i2: GLint | int, j1: GLint | int, j2: GLint | int) -> None: ...
def glEvalPoint1(i: GLint | int) -> None: ...
def glEvalPoint2(i: GLint | int, j: GLint | int) -> None: ...
def glFeedbackBuffer(size: GLsizei | int, type: GLenum | int, buffer: _Pointer[GLfloat] | Any) -> None: ...
def glFenceSync(condition: GLenum | int, flags: GLbitfield | int) -> GLsync: ...
def glFinish() -> None: ...
def glFlush() -> None: ...
def glFlushMappedBufferRange(target: GLenum | int, offset: GLintptr, length: GLsizeiptr) -> None: ...
def glFlushMappedNamedBufferRange(buffer: GLuint | int, offset: GLintptr, length: GLsizeiptr) -> None: ...
def glFogCoordPointer(type: GLenum | int, stride: GLsizei | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glFogCoordd(coord: GLdouble | float) -> None: ...
def glFogCoorddv(coord: _Pointer[GLdouble] | Any) -> None: ...
def glFogCoordf(coord: GLfloat | float) -> None: ...
def glFogCoordfv(coord: _Pointer[GLfloat] | Any) -> None: ...
def glFogf(pname: GLenum | int, param: GLfloat | float) -> None: ...
def glFogfv(pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glFogi(pname: GLenum | int, param: GLint | int) -> None: ...
def glFogiv(pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glFramebufferParameteri(target: GLenum | int, pname: GLenum | int, param: GLint | int) -> None: ...
def glFramebufferRenderbuffer(target: GLenum | int, attachment: GLenum | int, renderbuffertarget: GLenum | int, renderbuffer: GLuint | int) -> None: ...
def glFramebufferRenderbufferEXT(target: GLenum | int, attachment: GLenum | int, renderbuffertarget: GLenum | int, renderbuffer: GLuint | int) -> None: ...
def glFramebufferTexture(target: GLenum | int, attachment: GLenum | int, texture: GLuint | int, level: GLint | int) -> None: ...
def glFramebufferTexture1D(target: GLenum | int, attachment: GLenum | int, textarget: GLenum | int, texture: GLuint | int, level: GLint | int) -> None: ...
def glFramebufferTexture1DEXT(target: GLenum | int, attachment: GLenum | int, textarget: GLenum | int, texture: GLuint | int, level: GLint | int) -> None: ...
def glFramebufferTexture2D(target: GLenum | int, attachment: GLenum | int, textarget: GLenum | int, texture: GLuint | int, level: GLint | int) -> None: ...
def glFramebufferTexture2DEXT(target: GLenum | int, attachment: GLenum | int, textarget: GLenum | int, texture: GLuint | int, level: GLint | int) -> None: ...
def glFramebufferTexture3D(target: GLenum | int, attachment: GLenum | int, textarget: GLenum | int, texture: GLuint | int, level: GLint | int, zoffset: GLint | int) -> None: ...
def glFramebufferTexture3DEXT(target: GLenum | int, attachment: GLenum | int, textarget: GLenum | int, texture: GLuint | int, level: GLint | int, zoffset: GLint | int) -> None: ...
def glFramebufferTextureLayer(target: GLenum | int, attachment: GLenum | int, texture: GLuint | int, level: GLint | int, layer: GLint | int) -> None: ...
def glFrontFace(mode: GLenum | int) -> None: ...
def glFrustum(left: GLdouble | float, right: GLdouble | float, bottom: GLdouble | float, top: GLdouble | float, zNear: GLdouble | float, zFar: GLdouble | float) -> None: ...
def glGenBuffers(n: GLsizei | int, buffers: _Pointer[GLuint] | Any) -> None: ...
def glGenFramebuffers(n: GLsizei | int, framebuffers: _Pointer[GLuint] | Any) -> None: ...
def glGenFramebuffersEXT(n: GLsizei | int, framebuffers: _Pointer[GLuint] | Any) -> None: ...
def glGenLists(range: GLsizei | int) -> int: ...
def glGenProgramPipelines(n: GLsizei | int, pipelines: _Pointer[GLuint] | Any) -> None: ...
def glGenQueries(n: GLsizei | int, ids: _Pointer[GLuint] | Any) -> None: ...
def glGenRenderbuffers(n: GLsizei | int, renderbuffers: _Pointer[GLuint] | Any) -> None: ...
def glGenRenderbuffersEXT(n: GLsizei | int, renderbuffers: _Pointer[GLuint] | Any) -> None: ...
def glGenSamplers(count: GLsizei | int, samplers: _Pointer[GLuint] | Any) -> None: ...
def glGenTextures(n: GLsizei | int, textures: _Pointer[GLuint] | Any) -> None: ...
def glGenTransformFeedbacks(n: GLsizei | int, ids: _Pointer[GLuint] | Any) -> None: ...
def glGenVertexArrays(n: GLsizei | int, arrays: _Pointer[GLuint] | Any) -> None: ...
def glGenerateMipmap(target: GLenum | int) -> None: ...
def glGenerateMipmapEXT(target: GLenum | int) -> None: ...
def glGenerateTextureMipmap(texture: GLuint | int) -> None: ...
def glGetActiveAtomicCounterBufferiv(program: GLuint | int, bufferIndex: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetActiveAttrib(program: GLuint | int, index: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, size: _Pointer[GLint] | Any, type: _Pointer[GLenum] | Any, name: _Pointer[GLchar] | Any) -> None: ...
def glGetActiveSubroutineName(program: GLuint | int, shadertype: GLenum | int, index: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, name: _Pointer[GLchar] | Any) -> None: ...
def glGetActiveSubroutineUniformName(program: GLuint | int, shadertype: GLenum | int, index: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, name: _Pointer[GLchar] | Any) -> None: ...
def glGetActiveSubroutineUniformiv(program: GLuint | int, shadertype: GLenum | int, index: GLuint | int, pname: GLenum | int, values: _Pointer[GLint] | Any) -> None: ...
def glGetActiveUniform(program: GLuint | int, index: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, size: _Pointer[GLint] | Any, type: _Pointer[GLenum] | Any, name: _Pointer[GLchar] | Any) -> None: ...
def glGetActiveUniformBlockName(program: GLuint | int, uniformBlockIndex: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, uniformBlockName: _Pointer[GLchar] | Any) -> None: ...
def glGetActiveUniformBlockiv(program: GLuint | int, uniformBlockIndex: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetActiveUniformName(program: GLuint | int, uniformIndex: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, uniformName: _Pointer[GLchar] | Any) -> None: ...
def glGetActiveUniformsiv(program: GLuint | int, uniformCount: GLsizei | int, uniformIndices: _Pointer[GLuint] | Any, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetAttachedShaders(program: GLuint | int, maxCount: GLsizei | int, count: _Pointer[GLsizei] | Any, shaders: _Pointer[GLuint] | Any) -> None: ...
def glGetAttribLocation(program: GLuint | int, name: _Pointer[GLchar] | Any) -> int: ...
def glGetBooleani_v(target: GLenum | int, index: GLuint | int, data: _Pointer[GLboolean] | Any) -> None: ...
def glGetBooleanv(pname: GLenum | int, data: _Pointer[GLboolean] | Any) -> None: ...
def glGetBufferParameteri64v(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLint64] | Any) -> None: ...
def glGetBufferParameteriv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetBufferPointerv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLvoid] | Any) -> None: ...
def glGetBufferSubData(target: GLenum | int, offset: GLintptr, size: GLsizeiptr, data: _Pointer[GLvoid] | Any) -> None: ...
def glGetClipPlane(plane: GLenum | int, equation: _Pointer[GLdouble] | Any) -> None: ...
def glGetCompressedTexImage(target: GLenum | int, level: GLint | int, img: _Pointer[GLvoid] | Any) -> None: ...
def glGetCompressedTextureImage(texture: GLuint | int, level: GLint | int, bufSize: GLsizei | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glGetCompressedTextureSubImage(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, zoffset: GLint | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int, bufSize: GLsizei | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glGetDebugMessageLog(count: GLuint | int, bufSize: GLsizei | int, sources: _Pointer[GLenum] | Any, types: _Pointer[GLenum] | Any, ids: _Pointer[GLuint] | Any, severities: _Pointer[GLenum] | Any, lengths: _Pointer[GLsizei] | Any, messageLog: _Pointer[GLchar] | Any) -> int: ...
def glGetDoublei_v(target: GLenum | int, index: GLuint | int, data: _Pointer[GLdouble] | Any) -> None: ...
def glGetDoublev(pname: GLenum | int, data: _Pointer[GLdouble] | Any) -> None: ...
def glGetError() -> int: ...
def glGetFloati_v(target: GLenum | int, index: GLuint | int, data: _Pointer[GLfloat] | Any) -> None: ...
def glGetFloatv(pname: GLenum | int, data: _Pointer[GLfloat] | Any) -> None: ...
def glGetFragDataIndex(program: GLuint | int, name: _Pointer[GLchar] | Any) -> int: ...
def glGetFragDataLocation(program: GLuint | int, name: _Pointer[GLchar] | Any) -> int: ...
def glGetFramebufferAttachmentParameteriv(target: GLenum | int, attachment: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetFramebufferAttachmentParameterivEXT(target: GLenum | int, attachment: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetFramebufferParameteriv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetGraphicsResetStatus() -> int: ...
def glGetImageHandleARB(texture: GLuint | int, level: GLint | int, layered: GLboolean | int, layer: GLint | int, format: GLenum | int) -> int: ...
def glGetInteger64i_v(target: GLenum | int, index: GLuint | int, data: _Pointer[GLint64] | Any) -> None: ...
def glGetInteger64v(pname: GLenum | int, data: _Pointer[GLint64] | Any) -> None: ...
def glGetIntegeri_v(target: GLenum | int, index: GLuint | int, data: _Pointer[GLint] | Any) -> None: ...
def glGetIntegerv(pname: GLenum | int, data: _Pointer[GLint] | Any) -> None: ...
def glGetInternalformati64v(target: GLenum | int, internalformat: GLenum | int, pname: GLenum | int, count: GLsizei | int, params: _Pointer[GLint64] | Any) -> None: ...
def glGetInternalformativ(target: GLenum | int, internalformat: GLenum | int, pname: GLenum | int, count: GLsizei | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetLightfv(light: GLenum | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glGetLightiv(light: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetMapdv(target: GLenum | int, query: GLenum | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glGetMapfv(target: GLenum | int, query: GLenum | int, v: _Pointer[GLfloat] | Any) -> None: ...
def glGetMapiv(target: GLenum | int, query: GLenum | int, v: _Pointer[GLint] | Any) -> None: ...
def glGetMaterialfv(face: GLenum | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glGetMaterialiv(face: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetMultisamplefv(pname: GLenum | int, index: GLuint | int, val: _Pointer[GLfloat] | Any) -> None: ...
def glGetNamedBufferParameteri64v(buffer: GLuint | int, pname: GLenum | int, params: _Pointer[GLint64] | Any) -> None: ...
def glGetNamedBufferParameteriv(buffer: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetNamedBufferPointerv(buffer: GLuint | int, pname: GLenum | int, params: _Pointer[GLvoid] | Any) -> None: ...
def glGetNamedBufferSubData(buffer: GLuint | int, offset: GLintptr, size: GLsizeiptr, data: _Pointer[GLvoid] | Any) -> None: ...
def glGetNamedFramebufferAttachmentParameteriv(framebuffer: GLuint | int, attachment: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetNamedFramebufferParameteriv(framebuffer: GLuint | int, pname: GLenum | int, param: _Pointer[GLint] | Any) -> None: ...
def glGetNamedRenderbufferParameteriv(renderbuffer: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetObjectLabel(identifier: GLenum | int, name: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, label: _Pointer[GLchar] | Any) -> None: ...
def glGetObjectPtrLabel(ptr: _Pointer[GLvoid] | Any, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, label: _Pointer[GLchar] | Any) -> None: ...
def glGetPixelMapfv(map: GLenum | int, values: _Pointer[GLfloat] | Any) -> None: ...
def glGetPixelMapuiv(map: GLenum | int, values: _Pointer[GLuint] | Any) -> None: ...
def glGetPixelMapusv(map: GLenum | int, values: _Pointer[GLushort] | Any) -> None: ...
def glGetPointerv(pname: GLenum | int, params: _Pointer[GLvoid] | Any) -> None: ...
def glGetPolygonStipple(mask: _Pointer[GLubyte] | Any) -> None: ...
def glGetProgramBinary(program: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, binaryFormat: _Pointer[GLenum] | Any, binary: _Pointer[GLvoid] | Any) -> None: ...
def glGetProgramInfoLog(program: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, infoLog: _Pointer[GLchar] | Any) -> None: ...
def glGetProgramInterfaceiv(program: GLuint | int, programInterface: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetProgramPipelineInfoLog(pipeline: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, infoLog: _Pointer[GLchar] | Any) -> None: ...
def glGetProgramPipelineiv(pipeline: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetProgramResourceIndex(program: GLuint | int, programInterface: GLenum | int, name: _Pointer[GLchar] | Any) -> int: ...
def glGetProgramResourceLocation(program: GLuint | int, programInterface: GLenum | int, name: _Pointer[GLchar] | Any) -> int: ...
def glGetProgramResourceLocationIndex(program: GLuint | int, programInterface: GLenum | int, name: _Pointer[GLchar] | Any) -> int: ...
def glGetProgramResourceName(program: GLuint | int, programInterface: GLenum | int, index: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, name: _Pointer[GLchar] | Any) -> None: ...
def glGetProgramResourceiv(program: GLuint | int, programInterface: GLenum | int, index: GLuint | int, propCount: GLsizei | int, props: _Pointer[GLenum] | Any, count: GLsizei | int, length: _Pointer[GLsizei] | Any, params: _Pointer[GLint] | Any) -> None: ...
def glGetProgramStageiv(program: GLuint | int, shadertype: GLenum | int, pname: GLenum | int, values: _Pointer[GLint] | Any) -> None: ...
def glGetProgramiv(program: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetQueryBufferObjecti64v(id: GLuint | int, buffer: GLuint | int, pname: GLenum | int, offset: GLintptr) -> None: ...
def glGetQueryBufferObjectiv(id: GLuint | int, buffer: GLuint | int, pname: GLenum | int, offset: GLintptr) -> None: ...
def glGetQueryBufferObjectui64v(id: GLuint | int, buffer: GLuint | int, pname: GLenum | int, offset: GLintptr) -> None: ...
def glGetQueryBufferObjectuiv(id: GLuint | int, buffer: GLuint | int, pname: GLenum | int, offset: GLintptr) -> None: ...
def glGetQueryIndexediv(target: GLenum | int, index: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetQueryObjecti64v(id: GLuint | int, pname: GLenum | int, params: _Pointer[GLint64] | Any) -> None: ...
def glGetQueryObjectiv(id: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetQueryObjectui64v(id: GLuint | int, pname: GLenum | int, params: _Pointer[GLuint64] | Any) -> None: ...
def glGetQueryObjectuiv(id: GLuint | int, pname: GLenum | int, params: _Pointer[GLuint] | Any) -> None: ...
def glGetQueryiv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetRenderbufferParameteriv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetRenderbufferParameterivEXT(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetSamplerParameterIiv(sampler: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetSamplerParameterIuiv(sampler: GLuint | int, pname: GLenum | int, params: _Pointer[GLuint] | Any) -> None: ...
def glGetSamplerParameterfv(sampler: GLuint | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glGetSamplerParameteriv(sampler: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetShaderInfoLog(shader: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, infoLog: _Pointer[GLchar] | Any) -> None: ...
def glGetShaderPrecisionFormat(shadertype: GLenum | int, precisiontype: GLenum | int, range: _Pointer[GLint] | Any, precision: _Pointer[GLint] | Any) -> None: ...
def glGetShaderSource(shader: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, source: _Pointer[GLchar] | Any) -> None: ...
def glGetShaderiv(shader: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetString(name: GLenum | int) -> _Pointer[GLubyte]: ...
def glGetStringi(name: GLenum | int, index: GLuint | int) -> _Pointer[GLubyte]: ...
def glGetSubroutineIndex(program: GLuint | int, shadertype: GLenum | int, name: _Pointer[GLchar] | Any) -> int: ...
def glGetSubroutineUniformLocation(program: GLuint | int, shadertype: GLenum | int, name: _Pointer[GLchar] | Any) -> int: ...
def glGetSynciv(sync: GLsync, pname: GLenum | int, count: GLsizei | int, length: _Pointer[GLsizei] | Any, values: _Pointer[GLint] | Any) -> None: ...
def glGetTexEnvfv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glGetTexEnviv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetTexGendv(coord: GLenum | int, pname: GLenum | int, params: _Pointer[GLdouble] | Any) -> None: ...
def glGetTexGenfv(coord: GLenum | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glGetTexGeniv(coord: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetTexImage(target: GLenum | int, level: GLint | int, format: GLenum | int, type: GLenum | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glGetTexLevelParameterfv(target: GLenum | int, level: GLint | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glGetTexLevelParameteriv(target: GLenum | int, level: GLint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetTexParameterIiv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetTexParameterIuiv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLuint] | Any) -> None: ...
def glGetTexParameterfv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glGetTexParameteriv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetTextureHandleARB(texture: GLuint | int) -> int: ...
def glGetTextureImage(texture: GLuint | int, level: GLint | int, format: GLenum | int, type: GLenum | int, bufSize: GLsizei | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glGetTextureLevelParameterfv(texture: GLuint | int, level: GLint | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glGetTextureLevelParameteriv(texture: GLuint | int, level: GLint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetTextureParameterIiv(texture: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetTextureParameterIuiv(texture: GLuint | int, pname: GLenum | int, params: _Pointer[GLuint] | Any) -> None: ...
def glGetTextureParameterfv(texture: GLuint | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glGetTextureParameteriv(texture: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetTextureSamplerHandleARB(texture: GLuint | int, sampler: GLuint | int) -> int: ...
def glGetTextureSubImage(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, zoffset: GLint | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int, format: GLenum | int, type: GLenum | int, bufSize: GLsizei | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glGetTransformFeedbackVarying(program: GLuint | int, index: GLuint | int, bufSize: GLsizei | int, length: _Pointer[GLsizei] | Any, size: _Pointer[GLsizei] | Any, type: _Pointer[GLenum] | Any, name: _Pointer[GLchar] | Any) -> None: ...
def glGetTransformFeedbacki64_v(xfb: GLuint | int, pname: GLenum | int, index: GLuint | int, param: _Pointer[GLint64] | Any) -> None: ...
def glGetTransformFeedbacki_v(xfb: GLuint | int, pname: GLenum | int, index: GLuint | int, param: _Pointer[GLint] | Any) -> None: ...
def glGetTransformFeedbackiv(xfb: GLuint | int, pname: GLenum | int, param: _Pointer[GLint] | Any) -> None: ...
def glGetUniformBlockIndex(program: GLuint | int, uniformBlockName: _Pointer[GLchar] | Any) -> int: ...
def glGetUniformIndices(program: GLuint | int, uniformCount: GLsizei | int, uniformNames: _Pointer[_Pointer[GLchar]] | Any, uniformIndices: _Pointer[GLuint] | Any) -> None: ...
def glGetUniformLocation(program: GLuint | int, name: _Pointer[GLchar] | Any) -> int: ...
def glGetUniformSubroutineuiv(shadertype: GLenum | int, location: GLint | int, params: _Pointer[GLuint] | Any) -> None: ...
def glGetUniformdv(program: GLuint | int, location: GLint | int, params: _Pointer[GLdouble] | Any) -> None: ...
def glGetUniformfv(program: GLuint | int, location: GLint | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glGetUniformi64vARB(program: GLuint | int, location: GLint | int, params: _Pointer[GLint64] | Any) -> None: ...
def glGetUniformiv(program: GLuint | int, location: GLint | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetUniformui64vARB(program: GLuint | int, location: GLint | int, params: _Pointer[GLuint64] | Any) -> None: ...
def glGetUniformuiv(program: GLuint | int, location: GLint | int, params: _Pointer[GLuint] | Any) -> None: ...
def glGetVertexArrayIndexed64iv(vaobj: GLuint | int, index: GLuint | int, pname: GLenum | int, param: _Pointer[GLint64] | Any) -> None: ...
def glGetVertexArrayIndexediv(vaobj: GLuint | int, index: GLuint | int, pname: GLenum | int, param: _Pointer[GLint] | Any) -> None: ...
def glGetVertexArrayiv(vaobj: GLuint | int, pname: GLenum | int, param: _Pointer[GLint] | Any) -> None: ...
def glGetVertexAttribIiv(index: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetVertexAttribIuiv(index: GLuint | int, pname: GLenum | int, params: _Pointer[GLuint] | Any) -> None: ...
def glGetVertexAttribLdv(index: GLuint | int, pname: GLenum | int, params: _Pointer[GLdouble] | Any) -> None: ...
def glGetVertexAttribLui64vARB(index: GLuint | int, pname: GLenum | int, params: _Pointer[GLuint64EXT] | Any) -> None: ...
def glGetVertexAttribPointerv(index: GLuint | int, pname: GLenum | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glGetVertexAttribdv(index: GLuint | int, pname: GLenum | int, params: _Pointer[GLdouble] | Any) -> None: ...
def glGetVertexAttribfv(index: GLuint | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glGetVertexAttribiv(index: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetnColorTable(target: GLenum | int, format: GLenum | int, type: GLenum | int, bufSize: GLsizei | int, table: _Pointer[GLvoid] | Any) -> None: ...
def glGetnCompressedTexImage(target: GLenum | int, lod: GLint | int, bufSize: GLsizei | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glGetnConvolutionFilter(target: GLenum | int, format: GLenum | int, type: GLenum | int, bufSize: GLsizei | int, image: _Pointer[GLvoid] | Any) -> None: ...
def glGetnHistogram(target: GLenum | int, reset: GLboolean | int, format: GLenum | int, type: GLenum | int, bufSize: GLsizei | int, values: _Pointer[GLvoid] | Any) -> None: ...
def glGetnMapdv(target: GLenum | int, query: GLenum | int, bufSize: GLsizei | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glGetnMapfv(target: GLenum | int, query: GLenum | int, bufSize: GLsizei | int, v: _Pointer[GLfloat] | Any) -> None: ...
def glGetnMapiv(target: GLenum | int, query: GLenum | int, bufSize: GLsizei | int, v: _Pointer[GLint] | Any) -> None: ...
def glGetnMinmax(target: GLenum | int, reset: GLboolean | int, format: GLenum | int, type: GLenum | int, bufSize: GLsizei | int, values: _Pointer[GLvoid] | Any) -> None: ...
def glGetnPixelMapfv(map: GLenum | int, bufSize: GLsizei | int, values: _Pointer[GLfloat] | Any) -> None: ...
def glGetnPixelMapuiv(map: GLenum | int, bufSize: GLsizei | int, values: _Pointer[GLuint] | Any) -> None: ...
def glGetnPixelMapusv(map: GLenum | int, bufSize: GLsizei | int, values: _Pointer[GLushort] | Any) -> None: ...
def glGetnPolygonStipple(bufSize: GLsizei | int, pattern: _Pointer[GLubyte] | Any) -> None: ...
def glGetnSeparableFilter(target: GLenum | int, format: GLenum | int, type: GLenum | int, rowBufSize: GLsizei | int, row: _Pointer[GLvoid] | Any, columnBufSize: GLsizei | int, column: _Pointer[GLvoid] | Any, span: _Pointer[GLvoid] | Any) -> None: ...
def glGetnTexImage(target: GLenum | int, level: GLint | int, format: GLenum | int, type: GLenum | int, bufSize: GLsizei | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glGetnUniformdv(program: GLuint | int, location: GLint | int, bufSize: GLsizei | int, params: _Pointer[GLdouble] | Any) -> None: ...
def glGetnUniformfv(program: GLuint | int, location: GLint | int, bufSize: GLsizei | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glGetnUniformi64vARB(program: GLuint | int, location: GLint | int, bufSize: GLsizei | int, params: _Pointer[GLint64] | Any) -> None: ...
def glGetnUniformiv(program: GLuint | int, location: GLint | int, bufSize: GLsizei | int, params: _Pointer[GLint] | Any) -> None: ...
def glGetnUniformui64vARB(program: GLuint | int, location: GLint | int, bufSize: GLsizei | int, params: _Pointer[GLuint64] | Any) -> None: ...
def glGetnUniformuiv(program: GLuint | int, location: GLint | int, bufSize: GLsizei | int, params: _Pointer[GLuint] | Any) -> None: ...
def glHint(target: GLenum | int, mode: GLenum | int) -> None: ...
def glIndexMask(mask: GLuint | int) -> None: ...
def glIndexPointer(type: GLenum | int, stride: GLsizei | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glIndexd(c: GLdouble | float) -> None: ...
def glIndexdv(c: _Pointer[GLdouble] | Any) -> None: ...
def glIndexf(c: GLfloat | float) -> None: ...
def glIndexfv(c: _Pointer[GLfloat] | Any) -> None: ...
def glIndexi(c: GLint | int) -> None: ...
def glIndexiv(c: _Pointer[GLint] | Any) -> None: ...
def glIndexs(c: GLshort | int) -> None: ...
def glIndexsv(c: _Pointer[GLshort] | Any) -> None: ...
def glIndexub(c: GLubyte | int) -> None: ...
def glIndexubv(c: _Pointer[GLubyte] | Any) -> None: ...
def glInitNames() -> None: ...
def glInterleavedArrays(format: GLenum | int, stride: GLsizei | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glInvalidateBufferData(buffer: GLuint | int) -> None: ...
def glInvalidateBufferSubData(buffer: GLuint | int, offset: GLintptr, length: GLsizeiptr) -> None: ...
def glInvalidateFramebuffer(target: GLenum | int, numAttachments: GLsizei | int, attachments: _Pointer[GLenum] | Any) -> None: ...
def glInvalidateNamedFramebufferData(framebuffer: GLuint | int, numAttachments: GLsizei | int, attachments: _Pointer[GLenum] | Any) -> None: ...
def glInvalidateNamedFramebufferSubData(framebuffer: GLuint | int, numAttachments: GLsizei | int, attachments: _Pointer[GLenum] | Any, x: GLint | int, y: GLint | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glInvalidateSubFramebuffer(target: GLenum | int, numAttachments: GLsizei | int, attachments: _Pointer[GLenum] | Any, x: GLint | int, y: GLint | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glInvalidateTexImage(texture: GLuint | int, level: GLint | int) -> None: ...
def glInvalidateTexSubImage(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, zoffset: GLint | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int) -> None: ...
def glIsBuffer(buffer: GLuint | int) -> int: ...
def glIsEnabled(cap: GLenum | int) -> int: ...
def glIsEnabledi(target: GLenum | int, index: GLuint | int) -> int: ...
def glIsFramebuffer(framebuffer: GLuint | int) -> int: ...
def glIsFramebufferEXT(framebuffer: GLuint | int) -> int: ...
def glIsImageHandleResidentARB(handle: GLuint64 | int) -> int: ...
def glIsList(list: GLuint | int) -> int: ...
def glIsProgram(program: GLuint | int) -> int: ...
def glIsProgramPipeline(pipeline: GLuint | int) -> int: ...
def glIsQuery(id: GLuint | int) -> int: ...
def glIsRenderbuffer(renderbuffer: GLuint | int) -> int: ...
def glIsRenderbufferEXT(renderbuffer: GLuint | int) -> int: ...
def glIsSampler(sampler: GLuint | int) -> int: ...
def glIsShader(shader: GLuint | int) -> int: ...
def glIsSync(sync: GLsync) -> int: ...
def glIsTexture(texture: GLuint | int) -> int: ...
def glIsTextureHandleResidentARB(handle: GLuint64 | int) -> int: ...
def glIsTransformFeedback(id: GLuint | int) -> int: ...
def glIsVertexArray(array: GLuint | int) -> int: ...
def glLightModelf(pname: GLenum | int, param: GLfloat | float) -> None: ...
def glLightModelfv(pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glLightModeli(pname: GLenum | int, param: GLint | int) -> None: ...
def glLightModeliv(pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glLightf(light: GLenum | int, pname: GLenum | int, param: GLfloat | float) -> None: ...
def glLightfv(light: GLenum | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glLighti(light: GLenum | int, pname: GLenum | int, param: GLint | int) -> None: ...
def glLightiv(light: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glLineStipple(factor: GLint | int, pattern: GLushort | int) -> None: ...
def glLineWidth(width: GLfloat | float) -> None: ...
def glLinkProgram(program: GLuint | int) -> None: ...
def glListBase(base: GLuint | int) -> None: ...
def glLoadIdentity() -> None: ...
def glLoadMatrixd(m: _Pointer[GLdouble] | Any) -> None: ...
def glLoadMatrixf(m: _Pointer[GLfloat] | Any) -> None: ...
def glLoadName(name: GLuint | int) -> None: ...
def glLoadTransposeMatrixd(m: _Pointer[GLdouble] | Any) -> None: ...
def glLoadTransposeMatrixf(m: _Pointer[GLfloat] | Any) -> None: ...
def glLogicOp(opcode: GLenum | int) -> None: ...
def glMakeImageHandleNonResidentARB(handle: GLuint64 | int) -> None: ...
def glMakeImageHandleResidentARB(handle: GLuint64 | int, access: GLenum | int) -> None: ...
def glMakeTextureHandleNonResidentARB(handle: GLuint64 | int) -> None: ...
def glMakeTextureHandleResidentARB(handle: GLuint64 | int) -> None: ...
def glMap1d(target: GLenum | int, u1: GLdouble | float, u2: GLdouble | float, stride: GLint | int, order: GLint | int, points: _Pointer[GLdouble] | Any) -> None: ...
def glMap1f(target: GLenum | int, u1: GLfloat | float, u2: GLfloat | float, stride: GLint | int, order: GLint | int, points: _Pointer[GLfloat] | Any) -> None: ...
def glMap2d(target: GLenum | int, u1: GLdouble | float, u2: GLdouble | float, ustride: GLint | int, uorder: GLint | int, v1: GLdouble | float, v2: GLdouble | float, vstride: GLint | int, vorder: GLint | int, points: _Pointer[GLdouble] | Any) -> None: ...
def glMap2f(target: GLenum | int, u1: GLfloat | float, u2: GLfloat | float, ustride: GLint | int, uorder: GLint | int, v1: GLfloat | float, v2: GLfloat | float, vstride: GLint | int, vorder: GLint | int, points: _Pointer[GLfloat] | Any) -> None: ...
def glMapBuffer(target: GLenum | int, access: GLenum | int) -> _Pointer[None]: ...
def glMapBufferRange(target: GLenum | int, offset: GLintptr, length: GLsizeiptr, access: GLbitfield | int) -> _Pointer[None]: ...
def glMapGrid1d(un: GLint | int, u1: GLdouble | float, u2: GLdouble | float) -> None: ...
def glMapGrid1f(un: GLint | int, u1: GLfloat | float, u2: GLfloat | float) -> None: ...
def glMapGrid2d(un: GLint | int, u1: GLdouble | float, u2: GLdouble | float, vn: GLint | int, v1: GLdouble | float, v2: GLdouble | float) -> None: ...
def glMapGrid2f(un: GLint | int, u1: GLfloat | float, u2: GLfloat | float, vn: GLint | int, v1: GLfloat | float, v2: GLfloat | float) -> None: ...
def glMapNamedBuffer(buffer: GLuint | int, access: GLenum | int) -> _Pointer[None]: ...
def glMapNamedBufferRange(buffer: GLuint | int, offset: GLintptr, length: GLsizeiptr, access: GLbitfield | int) -> _Pointer[None]: ...
def glMaterialf(face: GLenum | int, pname: GLenum | int, param: GLfloat | float) -> None: ...
def glMaterialfv(face: GLenum | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glMateriali(face: GLenum | int, pname: GLenum | int, param: GLint | int) -> None: ...
def glMaterialiv(face: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glMatrixMode(mode: GLenum | int) -> None: ...
def glMemoryBarrier(barriers: GLbitfield | int) -> None: ...
def glMemoryBarrierByRegion(barriers: GLbitfield | int) -> None: ...
def glMinSampleShading(value: GLfloat | float) -> None: ...
def glMultMatrixd(m: _Pointer[GLdouble] | Any) -> None: ...
def glMultMatrixf(m: _Pointer[GLfloat] | Any) -> None: ...
def glMultTransposeMatrixd(m: _Pointer[GLdouble] | Any) -> None: ...
def glMultTransposeMatrixf(m: _Pointer[GLfloat] | Any) -> None: ...
def glMultiDrawArrays(mode: GLenum | int, first: _Pointer[GLint] | Any, count: _Pointer[GLsizei] | Any, drawcount: GLsizei | int) -> None: ...
def glMultiDrawArraysIndirect(mode: GLenum | int, indirect: _Pointer[GLvoid] | Any, drawcount: GLsizei | int, stride: GLsizei | int) -> None: ...
def glMultiDrawArraysIndirectCount(mode: GLenum | int, indirect: _Pointer[GLvoid] | Any, drawcount: GLintptr, maxdrawcount: GLsizei | int, stride: GLsizei | int) -> None: ...
def glMultiDrawElements(mode: GLenum | int, count: _Pointer[GLsizei] | Any, type: GLenum | int, indices: _Pointer[GLvoid] | Any, drawcount: GLsizei | int) -> None: ...
def glMultiDrawElementsBaseVertex(mode: GLenum | int, count: _Pointer[GLsizei] | Any, type: GLenum | int, indices: _Pointer[GLvoid] | Any, drawcount: GLsizei | int, basevertex: _Pointer[GLint] | Any) -> None: ...
def glMultiDrawElementsIndirect(mode: GLenum | int, type: GLenum | int, indirect: _Pointer[GLvoid] | Any, drawcount: GLsizei | int, stride: GLsizei | int) -> None: ...
def glMultiDrawElementsIndirectCount(mode: GLenum | int, type: GLenum | int, indirect: _Pointer[GLvoid] | Any, drawcount: GLintptr, maxdrawcount: GLsizei | int, stride: GLsizei | int) -> None: ...
def glMultiDrawMeshTasksIndirectCountNV(indirect: GLintptr, drawcount: GLintptr, maxdrawcount: GLsizei | int, stride: GLsizei | int) -> None: ...
def glMultiDrawMeshTasksIndirectNV(indirect: GLintptr, drawcount: GLsizei | int, stride: GLsizei | int) -> None: ...
def glMultiTexCoord1d(target: GLenum | int, s: GLdouble | float) -> None: ...
def glMultiTexCoord1dv(target: GLenum | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glMultiTexCoord1f(target: GLenum | int, s: GLfloat | float) -> None: ...
def glMultiTexCoord1fv(target: GLenum | int, v: _Pointer[GLfloat] | Any) -> None: ...
def glMultiTexCoord1i(target: GLenum | int, s: GLint | int) -> None: ...
def glMultiTexCoord1iv(target: GLenum | int, v: _Pointer[GLint] | Any) -> None: ...
def glMultiTexCoord1s(target: GLenum | int, s: GLshort | int) -> None: ...
def glMultiTexCoord1sv(target: GLenum | int, v: _Pointer[GLshort] | Any) -> None: ...
def glMultiTexCoord2d(target: GLenum | int, s: GLdouble | float, t: GLdouble | float) -> None: ...
def glMultiTexCoord2dv(target: GLenum | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glMultiTexCoord2f(target: GLenum | int, s: GLfloat | float, t: GLfloat | float) -> None: ...
def glMultiTexCoord2fv(target: GLenum | int, v: _Pointer[GLfloat] | Any) -> None: ...
def glMultiTexCoord2i(target: GLenum | int, s: GLint | int, t: GLint | int) -> None: ...
def glMultiTexCoord2iv(target: GLenum | int, v: _Pointer[GLint] | Any) -> None: ...
def glMultiTexCoord2s(target: GLenum | int, s: GLshort | int, t: GLshort | int) -> None: ...
def glMultiTexCoord2sv(target: GLenum | int, v: _Pointer[GLshort] | Any) -> None: ...
def glMultiTexCoord3d(target: GLenum | int, s: GLdouble | float, t: GLdouble | float, r: GLdouble | float) -> None: ...
def glMultiTexCoord3dv(target: GLenum | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glMultiTexCoord3f(target: GLenum | int, s: GLfloat | float, t: GLfloat | float, r: GLfloat | float) -> None: ...
def glMultiTexCoord3fv(target: GLenum | int, v: _Pointer[GLfloat] | Any) -> None: ...
def glMultiTexCoord3i(target: GLenum | int, s: GLint | int, t: GLint | int, r: GLint | int) -> None: ...
def glMultiTexCoord3iv(target: GLenum | int, v: _Pointer[GLint] | Any) -> None: ...
def glMultiTexCoord3s(target: GLenum | int, s: GLshort | int, t: GLshort | int, r: GLshort | int) -> None: ...
def glMultiTexCoord3sv(target: GLenum | int, v: _Pointer[GLshort] | Any) -> None: ...
def glMultiTexCoord4d(target: GLenum | int, s: GLdouble | float, t: GLdouble | float, r: GLdouble | float, q: GLdouble | float) -> None: ...
def glMultiTexCoord4dv(target: GLenum | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glMultiTexCoord4f(target: GLenum | int, s: GLfloat | float, t: GLfloat | float, r: GLfloat | float, q: GLfloat | float) -> None: ...
def glMultiTexCoord4fv(target: GLenum | int, v: _Pointer[GLfloat] | Any) -> None: ...
def glMultiTexCoord4i(target: GLenum | int, s: GLint | int, t: GLint | int, r: GLint | int, q: GLint | int) -> None: ...
def glMultiTexCoord4iv(target: GLenum | int, v: _Pointer[GLint] | Any) -> None: ...
def glMultiTexCoord4s(target: GLenum | int, s: GLshort | int, t: GLshort | int, r: GLshort | int, q: GLshort | int) -> None: ...
def glMultiTexCoord4sv(target: GLenum | int, v: _Pointer[GLshort] | Any) -> None: ...
def glMultiTexCoordP1ui(texture: GLenum | int, type: GLenum | int, coords: GLuint | int) -> None: ...
def glMultiTexCoordP1uiv(texture: GLenum | int, type: GLenum | int, coords: _Pointer[GLuint] | Any) -> None: ...
def glMultiTexCoordP2ui(texture: GLenum | int, type: GLenum | int, coords: GLuint | int) -> None: ...
def glMultiTexCoordP2uiv(texture: GLenum | int, type: GLenum | int, coords: _Pointer[GLuint] | Any) -> None: ...
def glMultiTexCoordP3ui(texture: GLenum | int, type: GLenum | int, coords: GLuint | int) -> None: ...
def glMultiTexCoordP3uiv(texture: GLenum | int, type: GLenum | int, coords: _Pointer[GLuint] | Any) -> None: ...
def glMultiTexCoordP4ui(texture: GLenum | int, type: GLenum | int, coords: GLuint | int) -> None: ...
def glMultiTexCoordP4uiv(texture: GLenum | int, type: GLenum | int, coords: _Pointer[GLuint] | Any) -> None: ...
def glNamedBufferData(buffer: GLuint | int, size: GLsizeiptr, data: _Pointer[GLvoid] | Any, usage: GLenum | int) -> None: ...
def glNamedBufferStorage(buffer: GLuint | int, size: GLsizeiptr, data: _Pointer[GLvoid] | Any, flags: GLbitfield | int) -> None: ...
def glNamedBufferSubData(buffer: GLuint | int, offset: GLintptr, size: GLsizeiptr, data: _Pointer[GLvoid] | Any) -> None: ...
def glNamedFramebufferDrawBuffer(framebuffer: GLuint | int, buf: GLenum | int) -> None: ...
def glNamedFramebufferDrawBuffers(framebuffer: GLuint | int, n: GLsizei | int, bufs: _Pointer[GLenum] | Any) -> None: ...
def glNamedFramebufferParameteri(framebuffer: GLuint | int, pname: GLenum | int, param: GLint | int) -> None: ...
def glNamedFramebufferReadBuffer(framebuffer: GLuint | int, src: GLenum | int) -> None: ...
def glNamedFramebufferRenderbuffer(framebuffer: GLuint | int, attachment: GLenum | int, renderbuffertarget: GLenum | int, renderbuffer: GLuint | int) -> None: ...
def glNamedFramebufferTexture(framebuffer: GLuint | int, attachment: GLenum | int, texture: GLuint | int, level: GLint | int) -> None: ...
def glNamedFramebufferTextureLayer(framebuffer: GLuint | int, attachment: GLenum | int, texture: GLuint | int, level: GLint | int, layer: GLint | int) -> None: ...
def glNamedRenderbufferStorage(renderbuffer: GLuint | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glNamedRenderbufferStorageMultisample(renderbuffer: GLuint | int, samples: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glNewList(list: GLuint | int, mode: GLenum | int) -> None: ...
def glNormal3b(nx: GLbyte | bytes, ny: GLbyte | bytes, nz: GLbyte | bytes) -> None: ...
def glNormal3bv(v: _Pointer[GLbyte] | Any) -> None: ...
def glNormal3d(nx: GLdouble | float, ny: GLdouble | float, nz: GLdouble | float) -> None: ...
def glNormal3dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glNormal3f(nx: GLfloat | float, ny: GLfloat | float, nz: GLfloat | float) -> None: ...
def glNormal3fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glNormal3i(nx: GLint | int, ny: GLint | int, nz: GLint | int) -> None: ...
def glNormal3iv(v: _Pointer[GLint] | Any) -> None: ...
def glNormal3s(nx: GLshort | int, ny: GLshort | int, nz: GLshort | int) -> None: ...
def glNormal3sv(v: _Pointer[GLshort] | Any) -> None: ...
def glNormalP3ui(type: GLenum | int, coords: GLuint | int) -> None: ...
def glNormalP3uiv(type: GLenum | int, coords: _Pointer[GLuint] | Any) -> None: ...
def glNormalPointer(type: GLenum | int, stride: GLsizei | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glObjectLabel(identifier: GLenum | int, name: GLuint | int, length: GLsizei | int, label: _Pointer[GLchar] | Any) -> None: ...
def glObjectPtrLabel(ptr: _Pointer[GLvoid] | Any, length: GLsizei | int, label: _Pointer[GLchar] | Any) -> None: ...
def glOrtho(left: GLdouble | float, right: GLdouble | float, bottom: GLdouble | float, top: GLdouble | float, zNear: GLdouble | float, zFar: GLdouble | float) -> None: ...
def glPassThrough(token: GLfloat | float) -> None: ...
def glPatchParameterfv(pname: GLenum | int, values: _Pointer[GLfloat] | Any) -> None: ...
def glPatchParameteri(pname: GLenum | int, value: GLint | int) -> None: ...
def glPauseTransformFeedback() -> None: ...
def glPixelMapfv(map: GLenum | int, mapsize: GLsizei | int, values: _Pointer[GLfloat] | Any) -> None: ...
def glPixelMapuiv(map: GLenum | int, mapsize: GLsizei | int, values: _Pointer[GLuint] | Any) -> None: ...
def glPixelMapusv(map: GLenum | int, mapsize: GLsizei | int, values: _Pointer[GLushort] | Any) -> None: ...
def glPixelStoref(pname: GLenum | int, param: GLfloat | float) -> None: ...
def glPixelStorei(pname: GLenum | int, param: GLint | int) -> None: ...
def glPixelTransferf(pname: GLenum | int, param: GLfloat | float) -> None: ...
def glPixelTransferi(pname: GLenum | int, param: GLint | int) -> None: ...
def glPixelZoom(xfactor: GLfloat | float, yfactor: GLfloat | float) -> None: ...
def glPointParameterf(pname: GLenum | int, param: GLfloat | float) -> None: ...
def glPointParameterfv(pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glPointParameteri(pname: GLenum | int, param: GLint | int) -> None: ...
def glPointParameteriv(pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glPointSize(size: GLfloat | float) -> None: ...
def glPolygonMode(face: GLenum | int, mode: GLenum | int) -> None: ...
def glPolygonOffset(factor: GLfloat | float, units: GLfloat | float) -> None: ...
def glPolygonOffsetClamp(factor: GLfloat | float, units: GLfloat | float, clamp: GLfloat | float) -> None: ...
def glPolygonStipple(mask: _Pointer[GLubyte] | Any) -> None: ...
def glPopAttrib() -> None: ...
def glPopClientAttrib() -> None: ...
def glPopDebugGroup() -> None: ...
def glPopMatrix() -> None: ...
def glPopName() -> None: ...
def glPrimitiveRestartIndex(index: GLuint | int) -> None: ...
def glPrioritizeTextures(n: GLsizei | int, textures: _Pointer[GLuint] | Any, priorities: _Pointer[GLfloat] | Any) -> None: ...
def glProgramBinary(program: GLuint | int, binaryFormat: GLenum | int, binary: _Pointer[GLvoid] | Any, length: GLsizei | int) -> None: ...
def glProgramParameteri(program: GLuint | int, pname: GLenum | int, value: GLint | int) -> None: ...
def glProgramUniform1d(program: GLuint | int, location: GLint | int, v0: GLdouble | float) -> None: ...
def glProgramUniform1dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniform1f(program: GLuint | int, location: GLint | int, v0: GLfloat | float) -> None: ...
def glProgramUniform1fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProgramUniform1i(program: GLuint | int, location: GLint | int, v0: GLint | int) -> None: ...
def glProgramUniform1i64ARB(program: GLuint | int, location: GLint | int, x: GLint64 | int) -> None: ...
def glProgramUniform1i64vARB(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLint64] | Any) -> None: ...
def glProgramUniform1iv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLint] | Any) -> None: ...
def glProgramUniform1ui(program: GLuint | int, location: GLint | int, v0: GLuint | int) -> None: ...
def glProgramUniform1ui64ARB(program: GLuint | int, location: GLint | int, x: GLuint64 | int) -> None: ...
def glProgramUniform1ui64vARB(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint64] | Any) -> None: ...
def glProgramUniform1uiv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint] | Any) -> None: ...
def glProgramUniform2d(program: GLuint | int, location: GLint | int, v0: GLdouble | float, v1: GLdouble | float) -> None: ...
def glProgramUniform2dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniform2f(program: GLuint | int, location: GLint | int, v0: GLfloat | float, v1: GLfloat | float) -> None: ...
def glProgramUniform2fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProgramUniform2i(program: GLuint | int, location: GLint | int, v0: GLint | int, v1: GLint | int) -> None: ...
def glProgramUniform2i64ARB(program: GLuint | int, location: GLint | int, x: GLint64 | int, y: GLint64 | int) -> None: ...
def glProgramUniform2i64vARB(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLint64] | Any) -> None: ...
def glProgramUniform2iv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLint] | Any) -> None: ...
def glProgramUniform2ui(program: GLuint | int, location: GLint | int, v0: GLuint | int, v1: GLuint | int) -> None: ...
def glProgramUniform2ui64ARB(program: GLuint | int, location: GLint | int, x: GLuint64 | int, y: GLuint64 | int) -> None: ...
def glProgramUniform2ui64vARB(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint64] | Any) -> None: ...
def glProgramUniform2uiv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint] | Any) -> None: ...
def glProgramUniform3d(program: GLuint | int, location: GLint | int, v0: GLdouble | float, v1: GLdouble | float, v2: GLdouble | float) -> None: ...
def glProgramUniform3dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniform3f(program: GLuint | int, location: GLint | int, v0: GLfloat | float, v1: GLfloat | float, v2: GLfloat | float) -> None: ...
def glProgramUniform3fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProgramUniform3i(program: GLuint | int, location: GLint | int, v0: GLint | int, v1: GLint | int, v2: GLint | int) -> None: ...
def glProgramUniform3i64ARB(program: GLuint | int, location: GLint | int, x: GLint64 | int, y: GLint64 | int, z: GLint64 | int) -> None: ...
def glProgramUniform3i64vARB(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLint64] | Any) -> None: ...
def glProgramUniform3iv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLint] | Any) -> None: ...
def glProgramUniform3ui(program: GLuint | int, location: GLint | int, v0: GLuint | int, v1: GLuint | int, v2: GLuint | int) -> None: ...
def glProgramUniform3ui64ARB(program: GLuint | int, location: GLint | int, x: GLuint64 | int, y: GLuint64 | int, z: GLuint64 | int) -> None: ...
def glProgramUniform3ui64vARB(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint64] | Any) -> None: ...
def glProgramUniform3uiv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint] | Any) -> None: ...
def glProgramUniform4d(program: GLuint | int, location: GLint | int, v0: GLdouble | float, v1: GLdouble | float, v2: GLdouble | float, v3: GLdouble | float) -> None: ...
def glProgramUniform4dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniform4f(program: GLuint | int, location: GLint | int, v0: GLfloat | float, v1: GLfloat | float, v2: GLfloat | float, v3: GLfloat | float) -> None: ...
def glProgramUniform4fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProgramUniform4i(program: GLuint | int, location: GLint | int, v0: GLint | int, v1: GLint | int, v2: GLint | int, v3: GLint | int) -> None: ...
def glProgramUniform4i64ARB(program: GLuint | int, location: GLint | int, x: GLint64 | int, y: GLint64 | int, z: GLint64 | int, w: GLint64 | int) -> None: ...
def glProgramUniform4i64vARB(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLint64] | Any) -> None: ...
def glProgramUniform4iv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLint] | Any) -> None: ...
def glProgramUniform4ui(program: GLuint | int, location: GLint | int, v0: GLuint | int, v1: GLuint | int, v2: GLuint | int, v3: GLuint | int) -> None: ...
def glProgramUniform4ui64ARB(program: GLuint | int, location: GLint | int, x: GLuint64 | int, y: GLuint64 | int, z: GLuint64 | int, w: GLuint64 | int) -> None: ...
def glProgramUniform4ui64vARB(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint64] | Any) -> None: ...
def glProgramUniform4uiv(program: GLuint | int, location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint] | Any) -> None: ...
def glProgramUniformHandleui64ARB(program: GLuint | int, location: GLint | int, value: GLuint64 | int) -> None: ...
def glProgramUniformHandleui64vARB(program: GLuint | int, location: GLint | int, count: GLsizei | int, values: _Pointer[GLuint64] | Any) -> None: ...
def glProgramUniformMatrix2dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniformMatrix2fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProgramUniformMatrix2x3dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniformMatrix2x3fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProgramUniformMatrix2x4dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniformMatrix2x4fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProgramUniformMatrix3dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniformMatrix3fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProgramUniformMatrix3x2dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniformMatrix3x2fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProgramUniformMatrix3x4dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniformMatrix3x4fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProgramUniformMatrix4dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniformMatrix4fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProgramUniformMatrix4x2dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniformMatrix4x2fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProgramUniformMatrix4x3dv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glProgramUniformMatrix4x3fv(program: GLuint | int, location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glProvokingVertex(mode: GLenum | int) -> None: ...
def glPushAttrib(mask: GLbitfield | int) -> None: ...
def glPushClientAttrib(mask: GLbitfield | int) -> None: ...
def glPushDebugGroup(source: GLenum | int, id: GLuint | int, length: GLsizei | int, message: _Pointer[GLchar] | Any) -> None: ...
def glPushMatrix() -> None: ...
def glPushName(name: GLuint | int) -> None: ...
def glQueryCounter(id: GLuint | int, target: GLenum | int) -> None: ...
def glRasterPos2d(x: GLdouble | float, y: GLdouble | float) -> None: ...
def glRasterPos2dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glRasterPos2f(x: GLfloat | float, y: GLfloat | float) -> None: ...
def glRasterPos2fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glRasterPos2i(x: GLint | int, y: GLint | int) -> None: ...
def glRasterPos2iv(v: _Pointer[GLint] | Any) -> None: ...
def glRasterPos2s(x: GLshort | int, y: GLshort | int) -> None: ...
def glRasterPos2sv(v: _Pointer[GLshort] | Any) -> None: ...
def glRasterPos3d(x: GLdouble | float, y: GLdouble | float, z: GLdouble | float) -> None: ...
def glRasterPos3dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glRasterPos3f(x: GLfloat | float, y: GLfloat | float, z: GLfloat | float) -> None: ...
def glRasterPos3fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glRasterPos3i(x: GLint | int, y: GLint | int, z: GLint | int) -> None: ...
def glRasterPos3iv(v: _Pointer[GLint] | Any) -> None: ...
def glRasterPos3s(x: GLshort | int, y: GLshort | int, z: GLshort | int) -> None: ...
def glRasterPos3sv(v: _Pointer[GLshort] | Any) -> None: ...
def glRasterPos4d(x: GLdouble | float, y: GLdouble | float, z: GLdouble | float, w: GLdouble | float) -> None: ...
def glRasterPos4dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glRasterPos4f(x: GLfloat | float, y: GLfloat | float, z: GLfloat | float, w: GLfloat | float) -> None: ...
def glRasterPos4fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glRasterPos4i(x: GLint | int, y: GLint | int, z: GLint | int, w: GLint | int) -> None: ...
def glRasterPos4iv(v: _Pointer[GLint] | Any) -> None: ...
def glRasterPos4s(x: GLshort | int, y: GLshort | int, z: GLshort | int, w: GLshort | int) -> None: ...
def glRasterPos4sv(v: _Pointer[GLshort] | Any) -> None: ...
def glReadBuffer(src: GLenum | int) -> None: ...
def glReadPixels(x: GLint | int, y: GLint | int, width: GLsizei | int, height: GLsizei | int, format: GLenum | int, type: GLenum | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glReadnPixels(x: GLint | int, y: GLint | int, width: GLsizei | int, height: GLsizei | int, format: GLenum | int, type: GLenum | int, bufSize: GLsizei | int, data: _Pointer[GLvoid] | Any) -> None: ...
def glRectd(x1: GLdouble | float, y1: GLdouble | float, x2: GLdouble | float, y2: GLdouble | float) -> None: ...
def glRectdv(v1: _Pointer[GLdouble] | Any, v2: _Pointer[GLdouble] | Any) -> None: ...
def glRectf(x1: GLfloat | float, y1: GLfloat | float, x2: GLfloat | float, y2: GLfloat | float) -> None: ...
def glRectfv(v1: _Pointer[GLfloat] | Any, v2: _Pointer[GLfloat] | Any) -> None: ...
def glRecti(x1: GLint | int, y1: GLint | int, x2: GLint | int, y2: GLint | int) -> None: ...
def glRectiv(v1: _Pointer[GLint] | Any, v2: _Pointer[GLint] | Any) -> None: ...
def glRects(x1: GLshort | int, y1: GLshort | int, x2: GLshort | int, y2: GLshort | int) -> None: ...
def glRectsv(v1: _Pointer[GLshort] | Any, v2: _Pointer[GLshort] | Any) -> None: ...
def glReleaseShaderCompiler() -> None: ...
def glRenderMode(mode: GLenum | int) -> int: ...
def glRenderbufferStorage(target: GLenum | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glRenderbufferStorageEXT(target: GLenum | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glRenderbufferStorageMultisample(target: GLenum | int, samples: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glResumeTransformFeedback() -> None: ...
def glRotated(angle: GLdouble | float, x: GLdouble | float, y: GLdouble | float, z: GLdouble | float) -> None: ...
def glRotatef(angle: GLfloat | float, x: GLfloat | float, y: GLfloat | float, z: GLfloat | float) -> None: ...
def glSampleCoverage(value: GLfloat | float, invert: GLboolean | int) -> None: ...
def glSampleCoverageARB(value: GLfloat | float, invert: GLboolean | int) -> None: ...
def glSampleMaski(maskNumber: GLuint | int, mask: GLbitfield | int) -> None: ...
def glSamplerParameterIiv(sampler: GLuint | int, pname: GLenum | int, param: _Pointer[GLint] | Any) -> None: ...
def glSamplerParameterIuiv(sampler: GLuint | int, pname: GLenum | int, param: _Pointer[GLuint] | Any) -> None: ...
def glSamplerParameterf(sampler: GLuint | int, pname: GLenum | int, param: GLfloat | float) -> None: ...
def glSamplerParameterfv(sampler: GLuint | int, pname: GLenum | int, param: _Pointer[GLfloat] | Any) -> None: ...
def glSamplerParameteri(sampler: GLuint | int, pname: GLenum | int, param: GLint | int) -> None: ...
def glSamplerParameteriv(sampler: GLuint | int, pname: GLenum | int, param: _Pointer[GLint] | Any) -> None: ...
def glScaled(x: GLdouble | float, y: GLdouble | float, z: GLdouble | float) -> None: ...
def glScalef(x: GLfloat | float, y: GLfloat | float, z: GLfloat | float) -> None: ...
def glScissor(x: GLint | int, y: GLint | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glScissorArrayv(first: GLuint | int, count: GLsizei | int, v: _Pointer[GLint] | Any) -> None: ...
def glScissorIndexed(index: GLuint | int, left: GLint | int, bottom: GLint | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glScissorIndexedv(index: GLuint | int, v: _Pointer[GLint] | Any) -> None: ...
def glSecondaryColor3b(red: GLbyte | bytes, green: GLbyte | bytes, blue: GLbyte | bytes) -> None: ...
def glSecondaryColor3bv(v: _Pointer[GLbyte] | Any) -> None: ...
def glSecondaryColor3d(red: GLdouble | float, green: GLdouble | float, blue: GLdouble | float) -> None: ...
def glSecondaryColor3dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glSecondaryColor3f(red: GLfloat | float, green: GLfloat | float, blue: GLfloat | float) -> None: ...
def glSecondaryColor3fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glSecondaryColor3i(red: GLint | int, green: GLint | int, blue: GLint | int) -> None: ...
def glSecondaryColor3iv(v: _Pointer[GLint] | Any) -> None: ...
def glSecondaryColor3s(red: GLshort | int, green: GLshort | int, blue: GLshort | int) -> None: ...
def glSecondaryColor3sv(v: _Pointer[GLshort] | Any) -> None: ...
def glSecondaryColor3ub(red: GLubyte | int, green: GLubyte | int, blue: GLubyte | int) -> None: ...
def glSecondaryColor3ubv(v: _Pointer[GLubyte] | Any) -> None: ...
def glSecondaryColor3ui(red: GLuint | int, green: GLuint | int, blue: GLuint | int) -> None: ...
def glSecondaryColor3uiv(v: _Pointer[GLuint] | Any) -> None: ...
def glSecondaryColor3us(red: GLushort | int, green: GLushort | int, blue: GLushort | int) -> None: ...
def glSecondaryColor3usv(v: _Pointer[GLushort] | Any) -> None: ...
def glSecondaryColorP3ui(type: GLenum | int, color: GLuint | int) -> None: ...
def glSecondaryColorP3uiv(type: GLenum | int, color: _Pointer[GLuint] | Any) -> None: ...
def glSecondaryColorPointer(size: GLint | int, type: GLenum | int, stride: GLsizei | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glSelectBuffer(size: GLsizei | int, buffer: _Pointer[GLuint] | Any) -> None: ...
def glShadeModel(mode: GLenum | int) -> None: ...
def glShaderBinary(count: GLsizei | int, shaders: _Pointer[GLuint] | Any, binaryFormat: GLenum | int, binary: _Pointer[GLvoid] | Any, length: GLsizei | int) -> None: ...
def glShaderSource(shader: GLuint | int, count: GLsizei | int, string: _Pointer[_Pointer[GLchar]] | Any, length: _Pointer[GLint] | Any) -> None: ...
def glShaderStorageBlockBinding(program: GLuint | int, storageBlockIndex: GLuint | int, storageBlockBinding: GLuint | int) -> None: ...
def glSpecializeShader(shader: GLuint | int, pEntryPoint: _Pointer[GLchar] | Any, numSpecializationConstants: GLuint | int, pConstantIndex: _Pointer[GLuint] | Any, pConstantValue: _Pointer[GLuint] | Any) -> None: ...
def glStencilFunc(func: GLenum | int, ref: GLint | int, mask: GLuint | int) -> None: ...
def glStencilFuncSeparate(face: GLenum | int, func: GLenum | int, ref: GLint | int, mask: GLuint | int) -> None: ...
def glStencilMask(mask: GLuint | int) -> None: ...
def glStencilMaskSeparate(face: GLenum | int, mask: GLuint | int) -> None: ...
def glStencilOp(fail: GLenum | int, zfail: GLenum | int, zpass: GLenum | int) -> None: ...
def glStencilOpSeparate(face: GLenum | int, sfail: GLenum | int, dpfail: GLenum | int, dppass: GLenum | int) -> None: ...
def glTexBuffer(target: GLenum | int, internalformat: GLenum | int, buffer: GLuint | int) -> None: ...
def glTexBufferRange(target: GLenum | int, internalformat: GLenum | int, buffer: GLuint | int, offset: GLintptr, size: GLsizeiptr) -> None: ...
def glTexCoord1d(s: GLdouble | float) -> None: ...
def glTexCoord1dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glTexCoord1f(s: GLfloat | float) -> None: ...
def glTexCoord1fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glTexCoord1i(s: GLint | int) -> None: ...
def glTexCoord1iv(v: _Pointer[GLint] | Any) -> None: ...
def glTexCoord1s(s: GLshort | int) -> None: ...
def glTexCoord1sv(v: _Pointer[GLshort] | Any) -> None: ...
def glTexCoord2d(s: GLdouble | float, t: GLdouble | float) -> None: ...
def glTexCoord2dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glTexCoord2f(s: GLfloat | float, t: GLfloat | float) -> None: ...
def glTexCoord2fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glTexCoord2i(s: GLint | int, t: GLint | int) -> None: ...
def glTexCoord2iv(v: _Pointer[GLint] | Any) -> None: ...
def glTexCoord2s(s: GLshort | int, t: GLshort | int) -> None: ...
def glTexCoord2sv(v: _Pointer[GLshort] | Any) -> None: ...
def glTexCoord3d(s: GLdouble | float, t: GLdouble | float, r: GLdouble | float) -> None: ...
def glTexCoord3dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glTexCoord3f(s: GLfloat | float, t: GLfloat | float, r: GLfloat | float) -> None: ...
def glTexCoord3fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glTexCoord3i(s: GLint | int, t: GLint | int, r: GLint | int) -> None: ...
def glTexCoord3iv(v: _Pointer[GLint] | Any) -> None: ...
def glTexCoord3s(s: GLshort | int, t: GLshort | int, r: GLshort | int) -> None: ...
def glTexCoord3sv(v: _Pointer[GLshort] | Any) -> None: ...
def glTexCoord4d(s: GLdouble | float, t: GLdouble | float, r: GLdouble | float, q: GLdouble | float) -> None: ...
def glTexCoord4dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glTexCoord4f(s: GLfloat | float, t: GLfloat | float, r: GLfloat | float, q: GLfloat | float) -> None: ...
def glTexCoord4fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glTexCoord4i(s: GLint | int, t: GLint | int, r: GLint | int, q: GLint | int) -> None: ...
def glTexCoord4iv(v: _Pointer[GLint] | Any) -> None: ...
def glTexCoord4s(s: GLshort | int, t: GLshort | int, r: GLshort | int, q: GLshort | int) -> None: ...
def glTexCoord4sv(v: _Pointer[GLshort] | Any) -> None: ...
def glTexCoordP1ui(type: GLenum | int, coords: GLuint | int) -> None: ...
def glTexCoordP1uiv(type: GLenum | int, coords: _Pointer[GLuint] | Any) -> None: ...
def glTexCoordP2ui(type: GLenum | int, coords: GLuint | int) -> None: ...
def glTexCoordP2uiv(type: GLenum | int, coords: _Pointer[GLuint] | Any) -> None: ...
def glTexCoordP3ui(type: GLenum | int, coords: GLuint | int) -> None: ...
def glTexCoordP3uiv(type: GLenum | int, coords: _Pointer[GLuint] | Any) -> None: ...
def glTexCoordP4ui(type: GLenum | int, coords: GLuint | int) -> None: ...
def glTexCoordP4uiv(type: GLenum | int, coords: _Pointer[GLuint] | Any) -> None: ...
def glTexCoordPointer(size: GLint | int, type: GLenum | int, stride: GLsizei | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glTexEnvf(target: GLenum | int, pname: GLenum | int, param: GLfloat | float) -> None: ...
def glTexEnvfv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glTexEnvi(target: GLenum | int, pname: GLenum | int, param: GLint | int) -> None: ...
def glTexEnviv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glTexGend(coord: GLenum | int, pname: GLenum | int, param: GLdouble | float) -> None: ...
def glTexGendv(coord: GLenum | int, pname: GLenum | int, params: _Pointer[GLdouble] | Any) -> None: ...
def glTexGenf(coord: GLenum | int, pname: GLenum | int, param: GLfloat | float) -> None: ...
def glTexGenfv(coord: GLenum | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glTexGeni(coord: GLenum | int, pname: GLenum | int, param: GLint | int) -> None: ...
def glTexGeniv(coord: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glTexImage1D(target: GLenum | int, level: GLint | int, internalformat: GLint | int, width: GLsizei | int, border: GLint | int, format: GLenum | int, type: GLenum | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glTexImage2D(target: GLenum | int, level: GLint | int, internalformat: GLint | int, width: GLsizei | int, height: GLsizei | int, border: GLint | int, format: GLenum | int, type: GLenum | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glTexImage2DMultisample(target: GLenum | int, samples: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int, fixedsamplelocations: GLboolean | int) -> None: ...
def glTexImage3D(target: GLenum | int, level: GLint | int, internalformat: GLint | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int, border: GLint | int, format: GLenum | int, type: GLenum | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glTexImage3DMultisample(target: GLenum | int, samples: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int, fixedsamplelocations: GLboolean | int) -> None: ...
def glTexParameterIiv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glTexParameterIuiv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLuint] | Any) -> None: ...
def glTexParameterf(target: GLenum | int, pname: GLenum | int, param: GLfloat | float) -> None: ...
def glTexParameterfv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLfloat] | Any) -> None: ...
def glTexParameteri(target: GLenum | int, pname: GLenum | int, param: GLint | int) -> None: ...
def glTexParameteriv(target: GLenum | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glTexStorage1D(target: GLenum | int, levels: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int) -> None: ...
def glTexStorage2D(target: GLenum | int, levels: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glTexStorage2DMultisample(target: GLenum | int, samples: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int, fixedsamplelocations: GLboolean | int) -> None: ...
def glTexStorage3D(target: GLenum | int, levels: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int) -> None: ...
def glTexStorage3DMultisample(target: GLenum | int, samples: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int, fixedsamplelocations: GLboolean | int) -> None: ...
def glTexSubImage1D(target: GLenum | int, level: GLint | int, xoffset: GLint | int, width: GLsizei | int, format: GLenum | int, type: GLenum | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glTexSubImage2D(target: GLenum | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, width: GLsizei | int, height: GLsizei | int, format: GLenum | int, type: GLenum | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glTexSubImage3D(target: GLenum | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, zoffset: GLint | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int, format: GLenum | int, type: GLenum | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glTextureBarrier() -> None: ...
def glTextureBuffer(texture: GLuint | int, internalformat: GLenum | int, buffer: GLuint | int) -> None: ...
def glTextureBufferRange(texture: GLuint | int, internalformat: GLenum | int, buffer: GLuint | int, offset: GLintptr, size: GLsizeiptr) -> None: ...
def glTextureParameterIiv(texture: GLuint | int, pname: GLenum | int, params: _Pointer[GLint] | Any) -> None: ...
def glTextureParameterIuiv(texture: GLuint | int, pname: GLenum | int, params: _Pointer[GLuint] | Any) -> None: ...
def glTextureParameterf(texture: GLuint | int, pname: GLenum | int, param: GLfloat | float) -> None: ...
def glTextureParameterfv(texture: GLuint | int, pname: GLenum | int, param: _Pointer[GLfloat] | Any) -> None: ...
def glTextureParameteri(texture: GLuint | int, pname: GLenum | int, param: GLint | int) -> None: ...
def glTextureParameteriv(texture: GLuint | int, pname: GLenum | int, param: _Pointer[GLint] | Any) -> None: ...
def glTextureStorage1D(texture: GLuint | int, levels: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int) -> None: ...
def glTextureStorage2D(texture: GLuint | int, levels: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glTextureStorage2DMultisample(texture: GLuint | int, samples: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int, fixedsamplelocations: GLboolean | int) -> None: ...
def glTextureStorage3D(texture: GLuint | int, levels: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int) -> None: ...
def glTextureStorage3DMultisample(texture: GLuint | int, samples: GLsizei | int, internalformat: GLenum | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int, fixedsamplelocations: GLboolean | int) -> None: ...
def glTextureSubImage1D(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, width: GLsizei | int, format: GLenum | int, type: GLenum | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glTextureSubImage2D(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, width: GLsizei | int, height: GLsizei | int, format: GLenum | int, type: GLenum | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glTextureSubImage3D(texture: GLuint | int, level: GLint | int, xoffset: GLint | int, yoffset: GLint | int, zoffset: GLint | int, width: GLsizei | int, height: GLsizei | int, depth: GLsizei | int, format: GLenum | int, type: GLenum | int, pixels: _Pointer[GLvoid] | Any) -> None: ...
def glTextureView(texture: GLuint | int, target: GLenum | int, origtexture: GLuint | int, internalformat: GLenum | int, minlevel: GLuint | int, numlevels: GLuint | int, minlayer: GLuint | int, numlayers: GLuint | int) -> None: ...
def glTransformFeedbackBufferBase(xfb: GLuint | int, index: GLuint | int, buffer: GLuint | int) -> None: ...
def glTransformFeedbackBufferRange(xfb: GLuint | int, index: GLuint | int, buffer: GLuint | int, offset: GLintptr, size: GLsizeiptr) -> None: ...
def glTransformFeedbackVaryings(program: GLuint | int, count: GLsizei | int, varyings: _Pointer[_Pointer[GLchar]] | Any, bufferMode: GLenum | int) -> None: ...
def glTranslated(x: GLdouble | float, y: GLdouble | float, z: GLdouble | float) -> None: ...
def glTranslatef(x: GLfloat | float, y: GLfloat | float, z: GLfloat | float) -> None: ...
def glUniform1d(location: GLint | int, x: GLdouble | float) -> None: ...
def glUniform1dv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniform1f(location: GLint | int, v0: GLfloat | float) -> None: ...
def glUniform1fv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniform1i(location: GLint | int, v0: GLint | int) -> None: ...
def glUniform1i64ARB(location: GLint | int, x: GLint64 | int) -> None: ...
def glUniform1i64vARB(location: GLint | int, count: GLsizei | int, value: _Pointer[GLint64] | Any) -> None: ...
def glUniform1iv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLint] | Any) -> None: ...
def glUniform1ui(location: GLint | int, v0: GLuint | int) -> None: ...
def glUniform1ui64ARB(location: GLint | int, x: GLuint64 | int) -> None: ...
def glUniform1ui64vARB(location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint64] | Any) -> None: ...
def glUniform1uiv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint] | Any) -> None: ...
def glUniform2d(location: GLint | int, x: GLdouble | float, y: GLdouble | float) -> None: ...
def glUniform2dv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniform2f(location: GLint | int, v0: GLfloat | float, v1: GLfloat | float) -> None: ...
def glUniform2fv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniform2i(location: GLint | int, v0: GLint | int, v1: GLint | int) -> None: ...
def glUniform2i64ARB(location: GLint | int, x: GLint64 | int, y: GLint64 | int) -> None: ...
def glUniform2i64vARB(location: GLint | int, count: GLsizei | int, value: _Pointer[GLint64] | Any) -> None: ...
def glUniform2iv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLint] | Any) -> None: ...
def glUniform2ui(location: GLint | int, v0: GLuint | int, v1: GLuint | int) -> None: ...
def glUniform2ui64ARB(location: GLint | int, x: GLuint64 | int, y: GLuint64 | int) -> None: ...
def glUniform2ui64vARB(location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint64] | Any) -> None: ...
def glUniform2uiv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint] | Any) -> None: ...
def glUniform3d(location: GLint | int, x: GLdouble | float, y: GLdouble | float, z: GLdouble | float) -> None: ...
def glUniform3dv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniform3f(location: GLint | int, v0: GLfloat | float, v1: GLfloat | float, v2: GLfloat | float) -> None: ...
def glUniform3fv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniform3i(location: GLint | int, v0: GLint | int, v1: GLint | int, v2: GLint | int) -> None: ...
def glUniform3i64ARB(location: GLint | int, x: GLint64 | int, y: GLint64 | int, z: GLint64 | int) -> None: ...
def glUniform3i64vARB(location: GLint | int, count: GLsizei | int, value: _Pointer[GLint64] | Any) -> None: ...
def glUniform3iv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLint] | Any) -> None: ...
def glUniform3ui(location: GLint | int, v0: GLuint | int, v1: GLuint | int, v2: GLuint | int) -> None: ...
def glUniform3ui64ARB(location: GLint | int, x: GLuint64 | int, y: GLuint64 | int, z: GLuint64 | int) -> None: ...
def glUniform3ui64vARB(location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint64] | Any) -> None: ...
def glUniform3uiv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint] | Any) -> None: ...
def glUniform4d(location: GLint | int, x: GLdouble | float, y: GLdouble | float, z: GLdouble | float, w: GLdouble | float) -> None: ...
def glUniform4dv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniform4f(location: GLint | int, v0: GLfloat | float, v1: GLfloat | float, v2: GLfloat | float, v3: GLfloat | float) -> None: ...
def glUniform4fv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniform4i(location: GLint | int, v0: GLint | int, v1: GLint | int, v2: GLint | int, v3: GLint | int) -> None: ...
def glUniform4i64ARB(location: GLint | int, x: GLint64 | int, y: GLint64 | int, z: GLint64 | int, w: GLint64 | int) -> None: ...
def glUniform4i64vARB(location: GLint | int, count: GLsizei | int, value: _Pointer[GLint64] | Any) -> None: ...
def glUniform4iv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLint] | Any) -> None: ...
def glUniform4ui(location: GLint | int, v0: GLuint | int, v1: GLuint | int, v2: GLuint | int, v3: GLuint | int) -> None: ...
def glUniform4ui64ARB(location: GLint | int, x: GLuint64 | int, y: GLuint64 | int, z: GLuint64 | int, w: GLuint64 | int) -> None: ...
def glUniform4ui64vARB(location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint64] | Any) -> None: ...
def glUniform4uiv(location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint] | Any) -> None: ...
def glUniformBlockBinding(program: GLuint | int, uniformBlockIndex: GLuint | int, uniformBlockBinding: GLuint | int) -> None: ...
def glUniformHandleui64ARB(location: GLint | int, value: GLuint64 | int) -> None: ...
def glUniformHandleui64vARB(location: GLint | int, count: GLsizei | int, value: _Pointer[GLuint64] | Any) -> None: ...
def glUniformMatrix2dv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniformMatrix2fv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniformMatrix2x3dv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniformMatrix2x3fv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniformMatrix2x4dv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniformMatrix2x4fv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniformMatrix3dv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniformMatrix3fv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniformMatrix3x2dv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniformMatrix3x2fv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniformMatrix3x4dv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniformMatrix3x4fv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniformMatrix4dv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniformMatrix4fv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniformMatrix4x2dv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniformMatrix4x2fv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniformMatrix4x3dv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLdouble] | Any) -> None: ...
def glUniformMatrix4x3fv(location: GLint | int, count: GLsizei | int, transpose: GLboolean | int, value: _Pointer[GLfloat] | Any) -> None: ...
def glUniformSubroutinesuiv(shadertype: GLenum | int, count: GLsizei | int, indices: _Pointer[GLuint] | Any) -> None: ...
def glUnmapBuffer(target: GLenum | int) -> int: ...
def glUnmapNamedBuffer(buffer: GLuint | int) -> int: ...
def glUseProgram(program: GLuint | int) -> None: ...
def glUseProgramStages(pipeline: GLuint | int, stages: GLbitfield | int, program: GLuint | int) -> None: ...
def glValidateProgram(program: GLuint | int) -> None: ...
def glValidateProgramPipeline(pipeline: GLuint | int) -> None: ...
def glVertex2d(x: GLdouble | float, y: GLdouble | float) -> None: ...
def glVertex2dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glVertex2f(x: GLfloat | float, y: GLfloat | float) -> None: ...
def glVertex2fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glVertex2i(x: GLint | int, y: GLint | int) -> None: ...
def glVertex2iv(v: _Pointer[GLint] | Any) -> None: ...
def glVertex2s(x: GLshort | int, y: GLshort | int) -> None: ...
def glVertex2sv(v: _Pointer[GLshort] | Any) -> None: ...
def glVertex3d(x: GLdouble | float, y: GLdouble | float, z: GLdouble | float) -> None: ...
def glVertex3dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glVertex3f(x: GLfloat | float, y: GLfloat | float, z: GLfloat | float) -> None: ...
def glVertex3fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glVertex3i(x: GLint | int, y: GLint | int, z: GLint | int) -> None: ...
def glVertex3iv(v: _Pointer[GLint] | Any) -> None: ...
def glVertex3s(x: GLshort | int, y: GLshort | int, z: GLshort | int) -> None: ...
def glVertex3sv(v: _Pointer[GLshort] | Any) -> None: ...
def glVertex4d(x: GLdouble | float, y: GLdouble | float, z: GLdouble | float, w: GLdouble | float) -> None: ...
def glVertex4dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glVertex4f(x: GLfloat | float, y: GLfloat | float, z: GLfloat | float, w: GLfloat | float) -> None: ...
def glVertex4fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glVertex4i(x: GLint | int, y: GLint | int, z: GLint | int, w: GLint | int) -> None: ...
def glVertex4iv(v: _Pointer[GLint] | Any) -> None: ...
def glVertex4s(x: GLshort | int, y: GLshort | int, z: GLshort | int, w: GLshort | int) -> None: ...
def glVertex4sv(v: _Pointer[GLshort] | Any) -> None: ...
def glVertexArrayAttribBinding(vaobj: GLuint | int, attribindex: GLuint | int, bindingindex: GLuint | int) -> None: ...
def glVertexArrayAttribFormat(vaobj: GLuint | int, attribindex: GLuint | int, size: GLint | int, type: GLenum | int, normalized: GLboolean | int, relativeoffset: GLuint | int) -> None: ...
def glVertexArrayAttribIFormat(vaobj: GLuint | int, attribindex: GLuint | int, size: GLint | int, type: GLenum | int, relativeoffset: GLuint | int) -> None: ...
def glVertexArrayAttribLFormat(vaobj: GLuint | int, attribindex: GLuint | int, size: GLint | int, type: GLenum | int, relativeoffset: GLuint | int) -> None: ...
def glVertexArrayBindingDivisor(vaobj: GLuint | int, bindingindex: GLuint | int, divisor: GLuint | int) -> None: ...
def glVertexArrayElementBuffer(vaobj: GLuint | int, buffer: GLuint | int) -> None: ...
def glVertexArrayVertexBuffer(vaobj: GLuint | int, bindingindex: GLuint | int, buffer: GLuint | int, offset: GLintptr, stride: GLsizei | int) -> None: ...
def glVertexArrayVertexBuffers(vaobj: GLuint | int, first: GLuint | int, count: GLsizei | int, buffers: _Pointer[GLuint] | Any, offsets: _Pointer[GLintptr] | Any, strides: _Pointer[GLsizei] | Any) -> None: ...
def glVertexAttrib1d(index: GLuint | int, x: GLdouble | float) -> None: ...
def glVertexAttrib1dv(index: GLuint | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glVertexAttrib1f(index: GLuint | int, x: GLfloat | float) -> None: ...
def glVertexAttrib1fv(index: GLuint | int, v: _Pointer[GLfloat] | Any) -> None: ...
def glVertexAttrib1s(index: GLuint | int, x: GLshort | int) -> None: ...
def glVertexAttrib1sv(index: GLuint | int, v: _Pointer[GLshort] | Any) -> None: ...
def glVertexAttrib2d(index: GLuint | int, x: GLdouble | float, y: GLdouble | float) -> None: ...
def glVertexAttrib2dv(index: GLuint | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glVertexAttrib2f(index: GLuint | int, x: GLfloat | float, y: GLfloat | float) -> None: ...
def glVertexAttrib2fv(index: GLuint | int, v: _Pointer[GLfloat] | Any) -> None: ...
def glVertexAttrib2s(index: GLuint | int, x: GLshort | int, y: GLshort | int) -> None: ...
def glVertexAttrib2sv(index: GLuint | int, v: _Pointer[GLshort] | Any) -> None: ...
def glVertexAttrib3d(index: GLuint | int, x: GLdouble | float, y: GLdouble | float, z: GLdouble | float) -> None: ...
def glVertexAttrib3dv(index: GLuint | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glVertexAttrib3f(index: GLuint | int, x: GLfloat | float, y: GLfloat | float, z: GLfloat | float) -> None: ...
def glVertexAttrib3fv(index: GLuint | int, v: _Pointer[GLfloat] | Any) -> None: ...
def glVertexAttrib3s(index: GLuint | int, x: GLshort | int, y: GLshort | int, z: GLshort | int) -> None: ...
def glVertexAttrib3sv(index: GLuint | int, v: _Pointer[GLshort] | Any) -> None: ...
def glVertexAttrib4Nbv(index: GLuint | int, v: _Pointer[GLbyte] | Any) -> None: ...
def glVertexAttrib4Niv(index: GLuint | int, v: _Pointer[GLint] | Any) -> None: ...
def glVertexAttrib4Nsv(index: GLuint | int, v: _Pointer[GLshort] | Any) -> None: ...
def glVertexAttrib4Nub(index: GLuint | int, x: GLubyte | int, y: GLubyte | int, z: GLubyte | int, w: GLubyte | int) -> None: ...
def glVertexAttrib4Nubv(index: GLuint | int, v: _Pointer[GLubyte] | Any) -> None: ...
def glVertexAttrib4Nuiv(index: GLuint | int, v: _Pointer[GLuint] | Any) -> None: ...
def glVertexAttrib4Nusv(index: GLuint | int, v: _Pointer[GLushort] | Any) -> None: ...
def glVertexAttrib4bv(index: GLuint | int, v: _Pointer[GLbyte] | Any) -> None: ...
def glVertexAttrib4d(index: GLuint | int, x: GLdouble | float, y: GLdouble | float, z: GLdouble | float, w: GLdouble | float) -> None: ...
def glVertexAttrib4dv(index: GLuint | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glVertexAttrib4f(index: GLuint | int, x: GLfloat | float, y: GLfloat | float, z: GLfloat | float, w: GLfloat | float) -> None: ...
def glVertexAttrib4fv(index: GLuint | int, v: _Pointer[GLfloat] | Any) -> None: ...
def glVertexAttrib4iv(index: GLuint | int, v: _Pointer[GLint] | Any) -> None: ...
def glVertexAttrib4s(index: GLuint | int, x: GLshort | int, y: GLshort | int, z: GLshort | int, w: GLshort | int) -> None: ...
def glVertexAttrib4sv(index: GLuint | int, v: _Pointer[GLshort] | Any) -> None: ...
def glVertexAttrib4ubv(index: GLuint | int, v: _Pointer[GLubyte] | Any) -> None: ...
def glVertexAttrib4uiv(index: GLuint | int, v: _Pointer[GLuint] | Any) -> None: ...
def glVertexAttrib4usv(index: GLuint | int, v: _Pointer[GLushort] | Any) -> None: ...
def glVertexAttribBinding(attribindex: GLuint | int, bindingindex: GLuint | int) -> None: ...
def glVertexAttribDivisor(index: GLuint | int, divisor: GLuint | int) -> None: ...
def glVertexAttribFormat(attribindex: GLuint | int, size: GLint | int, type: GLenum | int, normalized: GLboolean | int, relativeoffset: GLuint | int) -> None: ...
def glVertexAttribI1i(index: GLuint | int, x: GLint | int) -> None: ...
def glVertexAttribI1iv(index: GLuint | int, v: _Pointer[GLint] | Any) -> None: ...
def glVertexAttribI1ui(index: GLuint | int, x: GLuint | int) -> None: ...
def glVertexAttribI1uiv(index: GLuint | int, v: _Pointer[GLuint] | Any) -> None: ...
def glVertexAttribI2i(index: GLuint | int, x: GLint | int, y: GLint | int) -> None: ...
def glVertexAttribI2iv(index: GLuint | int, v: _Pointer[GLint] | Any) -> None: ...
def glVertexAttribI2ui(index: GLuint | int, x: GLuint | int, y: GLuint | int) -> None: ...
def glVertexAttribI2uiv(index: GLuint | int, v: _Pointer[GLuint] | Any) -> None: ...
def glVertexAttribI3i(index: GLuint | int, x: GLint | int, y: GLint | int, z: GLint | int) -> None: ...
def glVertexAttribI3iv(index: GLuint | int, v: _Pointer[GLint] | Any) -> None: ...
def glVertexAttribI3ui(index: GLuint | int, x: GLuint | int, y: GLuint | int, z: GLuint | int) -> None: ...
def glVertexAttribI3uiv(index: GLuint | int, v: _Pointer[GLuint] | Any) -> None: ...
def glVertexAttribI4bv(index: GLuint | int, v: _Pointer[GLbyte] | Any) -> None: ...
def glVertexAttribI4i(index: GLuint | int, x: GLint | int, y: GLint | int, z: GLint | int, w: GLint | int) -> None: ...
def glVertexAttribI4iv(index: GLuint | int, v: _Pointer[GLint] | Any) -> None: ...
def glVertexAttribI4sv(index: GLuint | int, v: _Pointer[GLshort] | Any) -> None: ...
def glVertexAttribI4ubv(index: GLuint | int, v: _Pointer[GLubyte] | Any) -> None: ...
def glVertexAttribI4ui(index: GLuint | int, x: GLuint | int, y: GLuint | int, z: GLuint | int, w: GLuint | int) -> None: ...
def glVertexAttribI4uiv(index: GLuint | int, v: _Pointer[GLuint] | Any) -> None: ...
def glVertexAttribI4usv(index: GLuint | int, v: _Pointer[GLushort] | Any) -> None: ...
def glVertexAttribIFormat(attribindex: GLuint | int, size: GLint | int, type: GLenum | int, relativeoffset: GLuint | int) -> None: ...
def glVertexAttribIPointer(index: GLuint | int, size: GLint | int, type: GLenum | int, stride: GLsizei | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glVertexAttribL1d(index: GLuint | int, x: GLdouble | float) -> None: ...
def glVertexAttribL1dv(index: GLuint | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glVertexAttribL1ui64ARB(index: GLuint | int, x: GLuint64EXT | int) -> None: ...
def glVertexAttribL1ui64vARB(index: GLuint | int, v: _Pointer[GLuint64EXT] | Any) -> None: ...
def glVertexAttribL2d(index: GLuint | int, x: GLdouble | float, y: GLdouble | float) -> None: ...
def glVertexAttribL2dv(index: GLuint | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glVertexAttribL3d(index: GLuint | int, x: GLdouble | float, y: GLdouble | float, z: GLdouble | float) -> None: ...
def glVertexAttribL3dv(index: GLuint | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glVertexAttribL4d(index: GLuint | int, x: GLdouble | float, y: GLdouble | float, z: GLdouble | float, w: GLdouble | float) -> None: ...
def glVertexAttribL4dv(index: GLuint | int, v: _Pointer[GLdouble] | Any) -> None: ...
def glVertexAttribLFormat(attribindex: GLuint | int, size: GLint | int, type: GLenum | int, relativeoffset: GLuint | int) -> None: ...
def glVertexAttribLPointer(index: GLuint | int, size: GLint | int, type: GLenum | int, stride: GLsizei | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glVertexAttribP1ui(index: GLuint | int, type: GLenum | int, normalized: GLboolean | int, value: GLuint | int) -> None: ...
def glVertexAttribP1uiv(index: GLuint | int, type: GLenum | int, normalized: GLboolean | int, value: _Pointer[GLuint] | Any) -> None: ...
def glVertexAttribP2ui(index: GLuint | int, type: GLenum | int, normalized: GLboolean | int, value: GLuint | int) -> None: ...
def glVertexAttribP2uiv(index: GLuint | int, type: GLenum | int, normalized: GLboolean | int, value: _Pointer[GLuint] | Any) -> None: ...
def glVertexAttribP3ui(index: GLuint | int, type: GLenum | int, normalized: GLboolean | int, value: GLuint | int) -> None: ...
def glVertexAttribP3uiv(index: GLuint | int, type: GLenum | int, normalized: GLboolean | int, value: _Pointer[GLuint] | Any) -> None: ...
def glVertexAttribP4ui(index: GLuint | int, type: GLenum | int, normalized: GLboolean | int, value: GLuint | int) -> None: ...
def glVertexAttribP4uiv(index: GLuint | int, type: GLenum | int, normalized: GLboolean | int, value: _Pointer[GLuint] | Any) -> None: ...
def glVertexAttribPointer(index: GLuint | int, size: GLint | int, type: GLenum | int, normalized: GLboolean | int, stride: GLsizei | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glVertexBindingDivisor(bindingindex: GLuint | int, divisor: GLuint | int) -> None: ...
def glVertexP2ui(type: GLenum | int, value: GLuint | int) -> None: ...
def glVertexP2uiv(type: GLenum | int, value: _Pointer[GLuint] | Any) -> None: ...
def glVertexP3ui(type: GLenum | int, value: GLuint | int) -> None: ...
def glVertexP3uiv(type: GLenum | int, value: _Pointer[GLuint] | Any) -> None: ...
def glVertexP4ui(type: GLenum | int, value: GLuint | int) -> None: ...
def glVertexP4uiv(type: GLenum | int, value: _Pointer[GLuint] | Any) -> None: ...
def glVertexPointer(size: GLint | int, type: GLenum | int, stride: GLsizei | int, pointer: _Pointer[GLvoid] | Any) -> None: ...
def glViewport(x: GLint | int, y: GLint | int, width: GLsizei | int, height: GLsizei | int) -> None: ...
def glViewportArrayv(first: GLuint | int, count: GLsizei | int, v: _Pointer[GLfloat] | Any) -> None: ...
def glViewportIndexedf(index: GLuint | int, x: GLfloat | float, y: GLfloat | float, w: GLfloat | float, h: GLfloat | float) -> None: ...
def glViewportIndexedfv(index: GLuint | int, v: _Pointer[GLfloat] | Any) -> None: ...
def glWaitSync(sync: GLsync, flags: GLbitfield | int, timeout: GLuint64 | int) -> None: ...
def glWindowPos2d(x: GLdouble | float, y: GLdouble | float) -> None: ...
def glWindowPos2dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glWindowPos2f(x: GLfloat | float, y: GLfloat | float) -> None: ...
def glWindowPos2fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glWindowPos2i(x: GLint | int, y: GLint | int) -> None: ...
def glWindowPos2iv(v: _Pointer[GLint] | Any) -> None: ...
def glWindowPos2s(x: GLshort | int, y: GLshort | int) -> None: ...
def glWindowPos2sv(v: _Pointer[GLshort] | Any) -> None: ...
def glWindowPos3d(x: GLdouble | float, y: GLdouble | float, z: GLdouble | float) -> None: ...
def glWindowPos3dv(v: _Pointer[GLdouble] | Any) -> None: ...
def glWindowPos3f(x: GLfloat | float, y: GLfloat | float, z: GLfloat | float) -> None: ...
def glWindowPos3fv(v: _Pointer[GLfloat] | Any) -> None: ...
def glWindowPos3i(x: GLint | int, y: GLint | int, z: GLint | int) -> None: ...
def glWindowPos3iv(v: _Pointer[GLint] | Any) -> None: ...
def glWindowPos3s(x: GLshort | int, y: GLshort | int, z: GLshort | int) -> None: ...
def glWindowPos3sv(v: _Pointer[GLshort] | Any) -> None: ...
